//-----------------------------------------------------
// name: "Advanced Crossfeed"
// author: "Radoslaw Szkodzinski"
// version: "1.1"
//
// Code generated with Faust 0.9.62 (http://faust.grame.fr)
//-----------------------------------------------------
/* link with  */
#include <math.h>
#include <cmath>
template <int N> inline float faustpower(float x)          { return powf(x,N); } 
template <int N> inline double faustpower(double x)        { return pow(x,N); }
template <int N> inline long double faustpower(long double x) 	{ return powl(x,N); }
template <int N> inline int faustpower(int x)              { return faustpower<N/2>(x) * faustpower<N-N/2>(x); } 
template <> 	 inline int faustpower<0>(int x)            { return 1; }
template <> 	 inline int faustpower<1>(int x)            { return x; }
/************************************************************************

	IMPORTANT NOTE : this file contains two clearly delimited sections : 
	the ARCHITECTURE section (in two parts) and the USER section. Each section 
	is governed by its own copyright and license. Please check individually 
	each section for license and copyright information.
*************************************************************************/

/*******************BEGIN ARCHITECTURE SECTION (part 1/2)****************/

/************************************************************************
    FAUST Architecture File
	Copyright (C) 2003-2011 Thomas Charbonnel and GRAME
    ---------------------------------------------------------------------
    This Architecture section is free software; you can redistribute it 
    and/or modify it under the terms of the GNU General Public License 
	as published by the Free Software Foundation; either version 3 of 
	the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License 
	along with this program; If not, see <http://www.gnu.org/licenses/>.

	EXCEPTION : As a special exception, you may create a larger work 
	that contains this FAUST architecture section and distribute  
	that work under terms of your choice, so long as this FAUST 
	architecture section is not modified. 


 ************************************************************************
 ************************************************************************/

#include <libgen.h>
#include <stdlib.h>
#include <iostream>
#include <list>

#ifndef FAUST_FUI_H
#define FAUST_FUI_H

#ifndef FAUST_UI_H
#define FAUST_UI_H

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif

/*******************************************************************************
 * UI : Faust User Interface
 * This abstract class contains only the method that the faust compiler can
 * generate to describe a DSP interface.
 ******************************************************************************/

class UI
{

 public:

	UI() {}

	virtual ~UI() {}

    // -- widget's layouts

    virtual void openTabBox(const char* label) = 0;
    virtual void openHorizontalBox(const char* label) = 0;
    virtual void openVerticalBox(const char* label) = 0;
    virtual void closeBox() = 0;

    // -- active widgets

    virtual void addButton(const char* label, FAUSTFLOAT* zone) = 0;
    virtual void addCheckButton(const char* label, FAUSTFLOAT* zone) = 0;
    virtual void addVerticalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step) = 0;
    virtual void addHorizontalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step) = 0;
    virtual void addNumEntry(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step) = 0;

    // -- passive widgets

    virtual void addHorizontalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT min, FAUSTFLOAT max) = 0;
    virtual void addVerticalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT min, FAUSTFLOAT max) = 0;

	// -- metadata declarations

    virtual void declare(FAUSTFLOAT*, const char*, const char*) {}
};

#endif

#include <string>
#include <map>
#include <set>
#include <vector>
#include <stack>

#include <iostream>
#include <fstream>

//using namespace std;

#if 1

/*******************************************************************************
 * FUI : used to save and recall the state of the user interface
 * This class provides essentially two new methods saveState() and recallState()
 * used to save on file and recall from file the state of the user interface.
 * The file is human readble and editable
 ******************************************************************************/

class FUI : public UI
{
    
    std::stack<std::string>             fGroupStack;
	std::vector<std::string>            fNameList;
	std::map<std::string, FAUSTFLOAT*>	fName2Zone;

 protected:

 	// labels are normalized by replacing white spaces by underscores and by
 	// removing parenthesis
	std::string normalizeLabel(const char* label)
	{
		std::string 	s;
		char 	c;

		while ((c=*label++)) {
			if (isspace(c)) 				{ s += '_'; }
			//else if ((c == '(') | (c == ')') ) 	{ }
			else 							{ s += c; }
		}
		return s;
	}

	// add an element by relating its full name and memory zone
	virtual void addElement(const char* label, FAUSTFLOAT* zone)
	{
		std::string fullname (fGroupStack.top() + '/' + normalizeLabel(label));
		fNameList.push_back(fullname);
		fName2Zone[fullname] = zone;
	}

	// keep track of full group names in a stack
	virtual void pushGroupLabel(const char* label)
	{
		if (fGroupStack.empty()) {
			fGroupStack.push(normalizeLabel(label));
		} else {
			fGroupStack.push(fGroupStack.top() + '/' + normalizeLabel(label));
		}
	}

	virtual void popGroupLabel()
	{
		fGroupStack.pop();
	};

 public:

	FUI() 			{}
	virtual ~FUI() 	{}

	// -- Save and recall methods

	// save the zones values and full names
	virtual void saveState(const char* filename)
	{
		std::ofstream f(filename);

		for (unsigned int i=0; i<fNameList.size(); i++) {
			std::string	n = fNameList[i];
			FAUSTFLOAT*	z = fName2Zone[n];
			f << *z << ' ' << n.c_str() << std::endl;
		}

		f << std::endl;
		f.close();
	}

	// recall the zones values and full names
	virtual void recallState(const char* filename)
	{
		std::ifstream f(filename);
		FAUSTFLOAT	v;
		std::string	n;

		while (f.good()) {
			f >> v >> n;
			if (fName2Zone.count(n)>0) {
				*(fName2Zone[n]) = v;
			} else {
				std::cerr << "recallState : parameter not found : " << n.c_str() << " with value : " << v << std::endl;
			}
		}
		f.close();
	}


    // -- widget's layouts (just keep track of group labels)

    virtual void openTabBox(const char* label) 			{ pushGroupLabel(label); }
    virtual void openHorizontalBox(const char* label) 	{ pushGroupLabel(label); }
    virtual void openVerticalBox(const char* label)  	{ pushGroupLabel(label); }
    virtual void closeBox() 							{ popGroupLabel(); };

    // -- active widgets (just add an element)

    virtual void addButton(const char* label, FAUSTFLOAT* zone) 		{ addElement(label, zone); }
    virtual void addCheckButton(const char* label, FAUSTFLOAT* zone) 	{ addElement(label, zone); }
    virtual void addVerticalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT , FAUSTFLOAT , FAUSTFLOAT , FAUSTFLOAT)
    																{ addElement(label, zone); }
    virtual void addHorizontalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT , FAUSTFLOAT , FAUSTFLOAT , FAUSTFLOAT)
    																{ addElement(label, zone); }
    virtual void addNumEntry(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT , FAUSTFLOAT , FAUSTFLOAT , FAUSTFLOAT)
    																{ addElement(label, zone); }

    // -- passive widgets (are ignored)

    virtual void addHorizontalBargraph(const char*, FAUSTFLOAT*, FAUSTFLOAT, FAUSTFLOAT) {};
    virtual void addVerticalBargraph(const char*, FAUSTFLOAT*, FAUSTFLOAT, FAUSTFLOAT) {};

	// -- metadata are not used

    virtual void declare(FAUSTFLOAT*, const char*, const char*) {}
};
#endif

#endif

/************************************************************************
 ************************************************************************
    FAUST Architecture File
	Copyright (C) 2003-2011 GRAME, Centre National de Creation Musicale
    ---------------------------------------------------------------------
    This Architecture section is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3 of
	the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
	along with this program; If not, see <http://www.gnu.org/licenses/>.

 ************************************************************************
 ************************************************************************/
 
#ifndef __misc__
#define __misc__

#include <algorithm>
#include <map>
#include <string.h>
#include <stdlib.h>

/************************************************************************
 ************************************************************************
    FAUST Architecture File
	Copyright (C) 2003-2011 GRAME, Centre National de Creation Musicale
    ---------------------------------------------------------------------
    This Architecture section is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3 of
	the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
	along with this program; If not, see <http://www.gnu.org/licenses/>.

 ************************************************************************
 ************************************************************************/
 
#ifndef __meta__
#define __meta__

struct Meta
{
    virtual void declare(const char* key, const char* value) = 0;
};

#endif


using std::max;
using std::min;

struct XXXX_Meta : std::map<const char*, const char*>
{
    void declare(const char* key, const char* value) { (*this)[key]=value; }
};

struct MY_Meta : Meta, std::map<const char*, const char*>
{
    void declare(const char* key, const char* value) { (*this)[key]=value; }
};

inline int	lsr(int x, int n)	{ return int(((unsigned int)x) >> n); }
inline int 	int2pow2(int x)		{ int r=0; while ((1<<r)<x) r++; return r; }

long lopt(char *argv[], const char *name, long def)
{
	int	i;
	for (i = 0; argv[i]; i++) if (!strcmp(argv[i], name)) return atoi(argv[i+1]);
	return def;
}

const char* lopts(char *argv[], const char *name, const char* def)
{
	int	i;
	for (i = 0; argv[i]; i++) if (!strcmp(argv[i], name)) return argv[i+1];
	return def;
}
#endif

#ifndef FAUST_GTKUI_H
#define FAUST_GTKUI_H

#ifndef FAUST_GUI_H
#define FAUST_GUI_H

#include <list>
#include <map>


/*******************************************************************************
 * GUI : Abstract Graphic User Interface
 * Provides additional macchanismes to synchronize widgets and zones. Widgets
 * should both reflect the value of a zone and allow to change this value.
 ******************************************************************************/

struct uiItem;
typedef void (*uiCallback)(FAUSTFLOAT val, void* data);

class GUI : public UI
{
    
	typedef std::list<uiItem*> clist;
	typedef std::map<FAUSTFLOAT*, clist*> zmap;
	
 private:
 	static std::list<GUI*>	fGuiList;
	zmap                    fZoneMap;
	bool                    fStopped;
	
 public:
		
    GUI() : fStopped(false) 
    {	
		fGuiList.push_back(this);
	}
	
    virtual ~GUI() 
    {
		// suppression de this dans fGuiList
	}

	// -- registerZone(z,c) : zone management
	
	void registerZone(FAUSTFLOAT* z, uiItem* c)
	{
		if (fZoneMap.find(z) == fZoneMap.end()) fZoneMap[z] = new clist();
		fZoneMap[z]->push_back(c);
	} 	

	void updateAllZones();
	
	void updateZone(FAUSTFLOAT* z);
	
	static void updateAllGuis()
	{
		std::list<GUI*>::iterator g;
		for (g = fGuiList.begin(); g != fGuiList.end(); g++) {
			(*g)->updateAllZones();
		}
	}
    void addCallback(FAUSTFLOAT* zone, uiCallback foo, void* data);
    virtual void show() {};	
    virtual void run() {};
	
	void stop()		{ fStopped = true; }
	bool stopped() 	{ return fStopped; }

    virtual void declare(FAUSTFLOAT* , const char* , const char* ) {}
};

/**
 * User Interface Item: abstract definition
 */

class uiItem
{
  protected :
		  
	GUI*            fGUI;
	FAUSTFLOAT*		fZone;
	FAUSTFLOAT		fCache;
	
	uiItem (GUI* ui, FAUSTFLOAT* zone) : fGUI(ui), fZone(zone), fCache(-123456.654321) 
	{ 
		ui->registerZone(zone, this); 
	}
	
  public :
  
	virtual ~uiItem() {}
	
	void modifyZone(FAUSTFLOAT v) 	
	{ 
		fCache = v;
		if (*fZone != v) {
			*fZone = v;
			fGUI->updateZone(fZone);
		}
	}
		  	
	FAUSTFLOAT			cache()			{ return fCache; }
	virtual void 	reflectZone() 	= 0;	
};

/**
 * Callback Item
 */

struct uiCallbackItem : public uiItem
{
	uiCallback	fCallback;
	void*		fData;
	
	uiCallbackItem(GUI* ui, FAUSTFLOAT* zone, uiCallback foo, void* data) 
			: uiItem(ui, zone), fCallback(foo), fData(data) {}
	
	virtual void 	reflectZone() {		
		FAUSTFLOAT 	v = *fZone;
		fCache = v; 
		fCallback(v, fData);	
	}
};

// en cours d'installation de call back. a finir!!!!!

/**
 * Update all user items reflecting zone z
 */

inline void GUI::updateZone(FAUSTFLOAT* z)
{
	FAUSTFLOAT 	v = *z;
	clist* 	l = fZoneMap[z];
	for (clist::iterator c = l->begin(); c != l->end(); c++) {
		if ((*c)->cache() != v) (*c)->reflectZone();
	}
}

/**
 * Update all user items not up to date
 */

inline void GUI::updateAllZones()
{
	for (zmap::iterator m = fZoneMap.begin(); m != fZoneMap.end(); m++) {
		FAUSTFLOAT* 	z = m->first;
		clist*	l = m->second;
		FAUSTFLOAT	v = *z;
		for (clist::iterator c = l->begin(); c != l->end(); c++) {
			if ((*c)->cache() != v) (*c)->reflectZone();
		}
	}
}

inline void GUI::addCallback(FAUSTFLOAT* zone, uiCallback foo, void* data) 
{ 
	new uiCallbackItem(this, zone, foo, data); 
};

#endif

/******************************************************************************
*******************************************************************************

                                GRAPHIC USER INTERFACE
                                  gtk interface

*******************************************************************************
*******************************************************************************/
#include <string>
#include <set>

#include <math.h>
#include <stdlib.h>
#include <string.h>

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>
#include <assert.h>

//using namespace std;


#define stackSize 256

// Insertion modes

#define kSingleMode 0
#define kBoxMode 1
#define kTabMode 2

//------------ calculate needed precision
static int precision(double n)
{
	if (n < 0.009999) return 3;
	else if (n < 0.099999) return 2;
	else if (n < 0.999999) return 1;
	else return 0;
}

namespace gtk_knob
{

class GtkKnob
{
private:
	double start_x, start_y, max_value;
public:
	GtkRange parent;
	int last_quadrant;
	GtkKnob();
	~GtkKnob();
	GtkWidget *gtk_knob_new_with_adjustment(GtkAdjustment *_adjustment);
	
};

#define GTK_TYPE_KNOB          (gtk_knob_get_type())
#define GTK_KNOB(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_KNOB, GtkKnob))
#define GTK_IS_KNOB(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_KNOB))
#define GTK_KNOB_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass),  GTK_TYPE_KNOB, GtkKnobClass))
#define GTK_IS_KNOB_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GTK_TYPE_KNOB))

GtkKnob::GtkKnob()
// GtkKnob constructor
{}

GtkKnob::~GtkKnob()
{
	// Nothing specific to do...
}

struct GtkKnobClass {
	GtkRangeClass parent_class;
	int knob_x;
	int knob_y;
	int knob_step;
	int button_is;

};

//------forward declaration
GType gtk_knob_get_type ();

/****************************************************************
 ** calculate the knop pointer with dead zone
 */

const double scale_zero = 20 * (M_PI/180); // defines "dead zone" for knobs

static void knob_expose(GtkWidget *widget, int knob_x, int knob_y, GdkEventExpose *event, int arc_offset)
{
	/** check resize **/
	int grow;
	if(widget->allocation.width > widget->allocation.height) {
		grow = widget->allocation.height;
	} else {
		grow =  widget->allocation.width;
	}
	knob_x = grow-4;
	knob_y = grow-4;
	/** get values for the knob **/
	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
	int knobx = (widget->allocation.x+2 + (widget->allocation.width-4 - knob_x) * 0.5);
	int knoby = (widget->allocation.y+2 + (widget->allocation.height-4 - knob_y) * 0.5);
	int knobx1 = (widget->allocation.x+2 + (widget->allocation.width-4)* 0.5);
	int knoby1 = (widget->allocation.y+2 + (widget->allocation.height-4) * 0.5);
	double knobstate = (adj->value - adj->lower) / (adj->upper - adj->lower);
	double angle = scale_zero + knobstate * 2 * (M_PI - scale_zero);
	double knobstate1 = (0. - adj->lower) / (adj->upper - adj->lower);
	double pointer_off = knob_x/6;
	double radius = min(knob_x-pointer_off, knob_y-pointer_off) / 2;
	double lengh_x = (knobx+radius+pointer_off/2) - radius * sin(angle);
	double lengh_y = (knoby+radius+pointer_off/2) + radius * cos(angle);
	double radius1 = min(knob_x, knob_y) / 2 ;

	/** get widget forground color convert to cairo **/
	GtkStyle *style = gtk_widget_get_style (widget);
	double r = min(0.6,style->fg[gtk_widget_get_state(widget)].red/65535.0),
		   g = min(0.6,style->fg[gtk_widget_get_state(widget)].green/65535.0),
		   b = min(0.6,style->fg[gtk_widget_get_state(widget)].blue/65535.0);

	/** paint focus **/
	if (GTK_WIDGET_HAS_FOCUS(widget)== TRUE) {
		gtk_paint_focus(widget->style, widget->window, GTK_STATE_NORMAL, NULL, widget, NULL,
		                knobx-2, knoby-2, knob_x+4, knob_y+4);
	}
	/** create clowing knobs with cairo **/
	cairo_t *cr = gdk_cairo_create(GDK_DRAWABLE(widget->window));
	GdkRegion *region;
	region = gdk_region_rectangle (&widget->allocation);
	gdk_region_intersect (region, event->region);
	gdk_cairo_region (cr, region);
	cairo_clip (cr);
	
	cairo_arc(cr,knobx1+arc_offset, knoby1+arc_offset, knob_x/2.1, 0, 2 * M_PI );
	cairo_pattern_t*pat =
		cairo_pattern_create_radial (knobx1+arc_offset-knob_x/6,knoby1+arc_offset-knob_x/6, 1,knobx1+arc_offset,knoby1+arc_offset,knob_x/2.1 );
	if(adj->lower<0 && adj->value>0.) {
		cairo_pattern_add_color_stop_rgb (pat, 0, r+0.4, g+0.4 + knobstate-knobstate1, b+0.4);
		cairo_pattern_add_color_stop_rgb (pat, 0.7, r+0.15, g+0.15 + (knobstate-knobstate1)*0.5, b+0.15);
		cairo_pattern_add_color_stop_rgb (pat, 1, r, g, b);
	} else if(adj->lower<0 && adj->value<=0.) {
		cairo_pattern_add_color_stop_rgb (pat, 0, r+0.4 +knobstate1- knobstate, g+0.4, b+0.4);
		cairo_pattern_add_color_stop_rgb (pat, 0.7, r+0.15 +(knobstate1- knobstate)*0.5, g+0.15, b+0.15);
		cairo_pattern_add_color_stop_rgb (pat, 1, r, g, b);
	} else {
		cairo_pattern_add_color_stop_rgb (pat, 0, r+0.4, g+0.4 +knobstate, b+0.4);
		cairo_pattern_add_color_stop_rgb (pat, 0.7, r+0.15, g+0.15 + knobstate*0.5, b+0.15);
		cairo_pattern_add_color_stop_rgb (pat, 1, r, g, b);
	}
	cairo_set_source (cr, pat);
	cairo_fill_preserve (cr);
	gdk_cairo_set_source_color(cr, gtk_widget_get_style (widget)->fg);
	cairo_set_line_width(cr, 2.0);
	cairo_stroke(cr);

	/** create a rotating pointer on the kob**/
	cairo_set_source_rgb(cr,  0.1, 0.1, 0.1);
	cairo_set_line_width(cr,max(3, min(7, knob_x/15)));
	cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND); 
	cairo_set_line_join(cr, CAIRO_LINE_JOIN_BEVEL);
	cairo_move_to(cr, knobx+radius1, knoby+radius1);
	cairo_line_to(cr,lengh_x,lengh_y);
	cairo_stroke(cr);
	cairo_set_source_rgb(cr,  0.9, 0.9, 0.9);
	cairo_set_line_width(cr,min(5, max(1,knob_x/30)));
	cairo_move_to(cr, knobx+radius1, knoby+radius1);
	cairo_line_to(cr,lengh_x,lengh_y);
	cairo_stroke(cr);
	cairo_pattern_destroy (pat);
	gdk_region_destroy (region);
	cairo_destroy(cr);
}

/****************************************************************
 ** general expose events for all "knob" controllers
 */

//----------- draw the Knob when moved
static gboolean gtk_knob_expose (GtkWidget *widget, GdkEventExpose *event)
{
	g_assert(GTK_IS_KNOB(widget));
	GtkKnobClass *klass =  GTK_KNOB_CLASS(GTK_OBJECT_GET_CLASS(widget));
	knob_expose(widget, klass->knob_x, klass->knob_y, event, 0);
	return TRUE;
}

/****************************************************************
 ** set initial size for GdkDrawable per type
 */

static void gtk_knob_size_request (GtkWidget *widget, GtkRequisition *requisition)
{
	g_assert(GTK_IS_KNOB(widget));
	GtkKnobClass *klass =  GTK_KNOB_CLASS(GTK_OBJECT_GET_CLASS(widget));
	requisition->width = klass->knob_x;
	requisition->height = klass->knob_y;
}

/****************************************************************
 ** set value from key bindings
 */

static void gtk_knob_set_value (GtkWidget *widget, int dir_down)
{
	g_assert(GTK_IS_KNOB(widget));

	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));

	int oldstep = (int)(0.5f + (adj->value - adj->lower) / adj->step_increment);
	int step;
	int nsteps = (int)(0.5f + (adj->upper - adj->lower) / adj->step_increment);
	if (dir_down)
		step = oldstep - 1;
	else
		step = oldstep + 1;
	FAUSTFLOAT value = adj->lower + step * double(adj->upper - adj->lower) / nsteps;
	gtk_widget_grab_focus(widget);
	gtk_range_set_value(GTK_RANGE(widget), value);
}

/****************************************************************
 ** keyboard bindings
 */

static gboolean gtk_knob_key_press (GtkWidget *widget, GdkEventKey *event)
{
	g_assert(GTK_IS_KNOB(widget));

	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
	switch (event->keyval) {
	case GDK_Home:
		gtk_range_set_value(GTK_RANGE(widget), adj->lower);
		return TRUE;
	case GDK_End:
		gtk_range_set_value(GTK_RANGE(widget), adj->upper);
		return TRUE;
	case GDK_Up:
		gtk_knob_set_value(widget, 0);
		return TRUE;
	case GDK_Right:
		gtk_knob_set_value(widget, 0);
		return TRUE;
	case GDK_Down:
		gtk_knob_set_value(widget, 1);
		return TRUE;
	case GDK_Left:
		gtk_knob_set_value(widget, 1);
		return TRUE;
	}

	return FALSE;
}

/****************************************************************
 ** alternative (radial) knob motion mode (ctrl + mouse pressed)
 */

static void knob_pointer_event(GtkWidget *widget, gdouble x, gdouble y, int knob_x, int knob_y,
                               bool drag, int state)
{
	static double last_y = 2e20;
	GtkKnob *knob = GTK_KNOB(widget);
	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
	double radius =  min(knob_x, knob_y) / 2;
	int  knobx = (widget->allocation.width - knob_x) / 2;
	int  knoby = (widget->allocation.height - knob_y) / 2;
	double posx = (knobx + radius) - x; // x axis right -> left
	double posy = (knoby + radius) - y; // y axis top -> bottom
	double value;
	if (!drag) {
		if (state & GDK_CONTROL_MASK) {
			last_y = 2e20;
			return;
		} else {
			last_y = posy;
		}
	}
	if (last_y < 1e20) { // in drag started with Control Key
		const double scaling = 0.005;
		double scal = (state & GDK_SHIFT_MASK ? scaling*0.1 : scaling);
		value = (last_y - posy) * scal;
		last_y = posy;
		gtk_range_set_value(GTK_RANGE(widget), adj->value - value * (adj->upper - adj->lower));
		return;
	}

	double angle = atan2(-posx, posy) + M_PI; // clockwise, zero at 6 o'clock, 0 .. 2*M_PI
	if (drag) {
		// block "forbidden zone" and direct moves between quadrant 1 and 4
		int quadrant = 1 + int(angle/M_PI_2);
		if (knob->last_quadrant == 1 && (quadrant == 3 || quadrant == 4)) {
			angle = scale_zero;
		} else if (knob->last_quadrant == 4 && (quadrant == 1 || quadrant == 2)) {
			angle = 2*M_PI - scale_zero;
		} else {
			if (angle < scale_zero) {
				angle = scale_zero;
			} else if (angle > 2*M_PI - scale_zero) {
				angle = 2*M_PI - scale_zero;
			}
			knob->last_quadrant = quadrant;
		}
	} else {
		if (angle < scale_zero) {
			angle = scale_zero;
		} else if (angle > 2*M_PI - scale_zero) {
			angle = 2*M_PI - scale_zero;
		}
		knob->last_quadrant = 0;
	}
	angle = (angle - scale_zero) / (2 * (M_PI-scale_zero)); // normalize to 0..1
	gtk_range_set_value(GTK_RANGE(widget), adj->lower + angle * (adj->upper - adj->lower));
}

/****************************************************************
 ** mouse button pressed set value
 */

static gboolean gtk_knob_button_press (GtkWidget *widget, GdkEventButton *event)
{
	g_assert(GTK_IS_KNOB(widget));
	
	GtkKnobClass *klass =  GTK_KNOB_CLASS(GTK_OBJECT_GET_CLASS(widget));
	

	switch (event->button) {
	case 1:  // left button
		gtk_widget_grab_focus(widget);
		gtk_widget_grab_default (widget);
		gtk_grab_add(widget);
		klass->button_is = 1;
		knob_pointer_event(widget, event->x, event->y, klass->knob_x, klass->knob_y,
						   false, event->state);
		break;
	case 2: //wheel
		klass->button_is = 2;
		break;
	case 3:  // right button 
		klass->button_is = 3;
		break;
	default: // do nothing
		break;
	}
	return TRUE;
}

/****************************************************************
 ** mouse button release
 */

static gboolean gtk_knob_button_release (GtkWidget *widget, GdkEventButton *event)
{
	g_assert(GTK_IS_KNOB(widget));
	GTK_KNOB_CLASS(GTK_OBJECT_GET_CLASS(widget))->button_is = 0;
	if (GTK_WIDGET_HAS_GRAB(widget))
		gtk_grab_remove(widget);
	return FALSE;
}

/****************************************************************
 ** set the value from mouse movement
 */

static gboolean gtk_knob_pointer_motion (GtkWidget *widget, GdkEventMotion *event)
{
	g_assert(GTK_IS_KNOB(widget));
	GtkKnobClass *klass =  GTK_KNOB_CLASS(GTK_OBJECT_GET_CLASS(widget));
	
	gdk_event_request_motions (event);
	
	if (GTK_WIDGET_HAS_GRAB(widget)) {
		knob_pointer_event(widget, event->x, event->y, klass->knob_x, klass->knob_y,
						   true, event->state);
	}
	return FALSE;
}

/****************************************************************
 ** set value from mouseweel
 */

static gboolean gtk_knob_scroll (GtkWidget *widget, GdkEventScroll *event)
{
	usleep(5000);
	gtk_knob_set_value(widget, event->direction);
	return FALSE;
}

/****************************************************************
 ** init the GtkKnobClass
 */

static void gtk_knob_class_init (GtkKnobClass *klass)
{
	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);

	/** set here the sizes and steps for the used knob **/
//--------- small knob size and steps
	
	klass->knob_x = 30;
	klass->knob_y = 30;
	klass->knob_step = 86;

//--------- event button
	klass->button_is = 0;

//--------- connect the events with funktions
	widget_class->expose_event = gtk_knob_expose;
	widget_class->size_request = gtk_knob_size_request;
	widget_class->button_press_event = gtk_knob_button_press;
	widget_class->button_release_event = gtk_knob_button_release;
	widget_class->motion_notify_event = gtk_knob_pointer_motion;
	widget_class->key_press_event = gtk_knob_key_press;
	widget_class->scroll_event = gtk_knob_scroll;
}

/****************************************************************
 ** init the Knob type/size
 */

static void gtk_knob_init (GtkKnob *knob)
{
	GtkWidget *widget = GTK_WIDGET(knob);
	GtkKnobClass *klass =  GTK_KNOB_CLASS(GTK_OBJECT_GET_CLASS(widget));

	GTK_WIDGET_SET_FLAGS (GTK_WIDGET(knob), GTK_CAN_FOCUS);
	GTK_WIDGET_SET_FLAGS (GTK_WIDGET(knob), GTK_CAN_DEFAULT);

	widget->requisition.width = klass->knob_x;
	widget->requisition.height = klass->knob_y;
}

/****************************************************************
 ** redraw when value changed
 */

static gboolean gtk_knob_value_changed(gpointer obj)
{
	GtkWidget *widget = (GtkWidget *)obj;
	gtk_widget_queue_draw(widget);
	return FALSE;
}

/****************************************************************
 ** create small knob
 */

GtkWidget *GtkKnob::gtk_knob_new_with_adjustment(GtkAdjustment *_adjustment)
{
	GtkWidget *widget = GTK_WIDGET( g_object_new (GTK_TYPE_KNOB, NULL ));
	GtkKnob *knob = GTK_KNOB(widget);
	knob->last_quadrant = 0;
	if (widget) {
		gtk_range_set_adjustment(GTK_RANGE(widget), _adjustment);
		g_signal_connect(GTK_OBJECT(widget), "value-changed",
		                 G_CALLBACK(gtk_knob_value_changed), widget);
	}
	return widget;
}

/****************************************************************
 ** get the Knob type
 */

GType gtk_knob_get_type (void)
{
	static GType kn_type = 0;
	if (!kn_type) {
		static const GTypeInfo kn_info = {
			sizeof(GtkKnobClass), NULL,  NULL, (GClassInitFunc)gtk_knob_class_init, NULL, NULL, sizeof(GtkKnob), 0, (GInstanceInitFunc)gtk_knob_init, NULL
		};
		kn_type = g_type_register_static(GTK_TYPE_RANGE,  "GtkKnob", &kn_info, (GTypeFlags)0);
	}
	return kn_type;
}
}/* end of gtk_knob namespace */

gtk_knob::GtkKnob myGtkKnob;

/**
 * rmWhiteSpaces(): Remove the leading and trailing white spaces of a string
 * (but not those in the middle of the string)
 */
static std::string rmWhiteSpaces(const std::string& s)
{
    size_t i = s.find_first_not_of(" \t");
    size_t j = s.find_last_not_of(" \t");

    if (i != std::string::npos & j != std::string::npos) {
        return s.substr(i, 1+j-i);
    } else {
        return "";
    }
}

/**
 * Extracts metdata from a label : 'vol [unit: dB]' -> 'vol' + metadata
 */
static void extractMetadata(const std::string& fulllabel, std::string& label, std::map<std::string, std::string>& metadata)
{
    enum {kLabel, kEscape1, kEscape2, kEscape3, kKey, kValue};
    int state = kLabel; int deep = 0;
    std::string key, value;

    for (unsigned int i=0; i < fulllabel.size(); i++) {
        char c = fulllabel[i];
        switch (state) {
            case kLabel :
                assert (deep == 0);
                switch (c) {
                    case '\\' : state = kEscape1; break;
                    case '[' : state = kKey; deep++; break;
                    default : label += c;
                }
                break;

            case kEscape1 :
                label += c;
                state = kLabel;
                break;

            case kEscape2 :
                key += c;
                state = kKey;
                break;

            case kEscape3 :
                value += c;
                state = kValue;
                break;

            case kKey :
                assert (deep > 0);
                switch (c) {
                    case '\\' :  state = kEscape2;
                                break;

                    case '[' :  deep++;
                                key += c;
                                break;

                    case ':' :  if (deep == 1) {
                                    state = kValue;
                                } else {
                                    key += c;
                                }
                                break;
                    case ']' :  deep--;
                                if (deep < 1) {
                                    metadata[rmWhiteSpaces(key)] = "";
                                    state = kLabel;
                                    key="";
                                    value="";
                                } else {
                                    key += c;
                                }
                                break;
                    default :   key += c;
                }
                break;

            case kValue :
                assert (deep > 0);
                switch (c) {
                    case '\\' : state = kEscape3;
                                break;

                    case '[' :  deep++;
                                value += c;
                                break;

                    case ']' :  deep--;
                                if (deep < 1) {
                                    metadata[rmWhiteSpaces(key)]=rmWhiteSpaces(value);
                                    state = kLabel;
                                    key="";
                                    value="";
                                } else {
                                    value += c;
                                }
                                break;
                    default :   value += c;
                }
                break;

            default :
                std::cerr << "ERROR unrecognized state " << state << std::endl;
        }
    }
    label = rmWhiteSpaces(label);
}

class GTKUI : public GUI
{
 private :
    static bool                         		fInitialized;
    static std::map<FAUSTFLOAT*, FAUSTFLOAT> 	fGuiSize;       // map widget zone with widget size coef
    static std::map<FAUSTFLOAT*, std::string>   fTooltip;       // map widget zone with tooltip strings
    static std::set<FAUSTFLOAT*>             	fKnobSet;       // set of widget zone to be knobs
	std::string									gGroupTooltip;
    
    bool isKnob(FAUSTFLOAT* zone) {return fKnobSet.count(zone) > 0;}
    
 protected :
    GtkWidget*  fWindow;
    int         fTop;
    GtkWidget*  fBox[stackSize];
    int         fMode[stackSize];
    bool        fStopped;

    GtkWidget* addWidget(const char* label, GtkWidget* w);
    virtual void pushBox(int mode, GtkWidget* w);

        
 public :
    static const gboolean expand = TRUE;
    static const gboolean fill = TRUE;
    static const gboolean homogene = FALSE;
         
    GTKUI(char * name, int* pargc, char*** pargv);

    // -- Labels and metadata

    virtual void declare(FAUSTFLOAT* zone, const char* key, const char* value);
    virtual int  checkLabelOptions(GtkWidget* widget, const std::string& fullLabel, std::string& simplifiedLabel);
    virtual void checkForTooltip(FAUSTFLOAT* zone, GtkWidget* widget);
    
    // -- layout groups
    
    virtual void openTabBox(const char* label = "");
    virtual void openHorizontalBox(const char* label = "");
    virtual void openVerticalBox(const char* label = "");
    virtual void closeBox();

    // -- active widgets
    
    virtual void addButton(const char* label, FAUSTFLOAT* zone);
    virtual void addCheckButton(const char* label, FAUSTFLOAT* zone);
    virtual void addVerticalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step);   
    virtual void addHorizontalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step); 
    virtual void addNumEntry(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step);

    // -- passive display widgets
    
    virtual void addHorizontalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT min, FAUSTFLOAT max);
    virtual void addVerticalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT min, FAUSTFLOAT max);
    
    // -- layout groups - internal
    
    virtual void openFrameBox(const char* label);   
   
    // -- extra widget's layouts

    virtual void openDialogBox(const char* label, FAUSTFLOAT* zone);
    virtual void openEventBox(const char* label = "");
    virtual void openHandleBox(const char* label = "");
    virtual void openExpanderBox(const char* label, FAUSTFLOAT* zone);
    
    virtual void adjustStack(int n);
    
    // -- active widgets - internal
    virtual void addToggleButton(const char* label, FAUSTFLOAT* zone);
    virtual void addKnob(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step);
    
    // -- passive display widgets - internal
    
    virtual void addNumDisplay(const char* label, FAUSTFLOAT* zone, int precision);
    virtual void addTextDisplay(const char* label, FAUSTFLOAT* zone, const char* names[], FAUSTFLOAT min, FAUSTFLOAT max);
   
    virtual void show();
    virtual void run();
    
};

/******************************************************************************
*******************************************************************************

                                GRAPHIC USER INTERFACE (v2)
                                  gtk implementation

*******************************************************************************
*******************************************************************************/

// global static fields

bool                             GTKUI::fInitialized = false;
std::map<FAUSTFLOAT*, FAUSTFLOAT>     GTKUI::fGuiSize;
std::map<FAUSTFLOAT*, std::string>    GTKUI::fTooltip;
std::set<FAUSTFLOAT*>                 GTKUI::fKnobSet;       // set of widget zone to be knobs

/**
* Format tooltip string by replacing some white spaces by 
* return characters so that line width doesn't exceed n.
* Limitation : long words exceeding n are not cut 
*/
static std::string formatTooltip(unsigned int n, const std::string& tt)
{
	std::string  ss = tt;	// ss string we are going to format
	unsigned int lws = 0;	// last white space encountered
	unsigned int lri = 0;	// last return inserted
	for (unsigned int i = 0; i < tt.size(); i++) {
		if (tt[i] == ' ') lws = i;
		if (((i-lri) >= n) && (lws > lri)) {
			// insert return here
			ss[lws] = '\n';
			lri = lws;
		}
	}
	//std::cout << ss;
	return ss;
}

static gint delete_event( GtkWidget *widget, GdkEvent *event, gpointer data )
{
    return FALSE; 
}

static void destroy_event( GtkWidget *widget, gpointer data )
{
    gtk_main_quit ();
}

GTKUI::GTKUI(char * name, int* pargc, char*** pargv) 
{
    if (!fInitialized) {
        gtk_init(pargc, pargv);
        fInitialized = true;
    }
    
    fWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    //gtk_container_set_border_width (GTK_CONTAINER (fWindow), 10);
    gtk_window_set_title (GTK_WINDOW (fWindow), name);
    gtk_signal_connect (GTK_OBJECT (fWindow), "delete_event", GTK_SIGNAL_FUNC (delete_event), NULL);
    gtk_signal_connect (GTK_OBJECT (fWindow), "destroy", GTK_SIGNAL_FUNC (destroy_event), NULL);

    fTop = 0;
    fBox[fTop] = gtk_vbox_new (homogene, 4);
    fMode[fTop] = kBoxMode;
    gtk_container_add (GTK_CONTAINER (fWindow), fBox[fTop]);
    fStopped = false;
}

// empilement des boites

void GTKUI::pushBox(int mode, GtkWidget* w)
{
    ++fTop;
    assert(fTop < stackSize);
    fMode[fTop] = mode;
    fBox[fTop] = w;
}

/**
 * Remove n levels from the stack S before the top level
 * adjustStack(n): S -> S' with S' = S(0),S(n+1),S(n+2),...
 */
void GTKUI::adjustStack(int n)
{
    if (n > 0) {
        assert(fTop >= n);
        fTop -= n; 
        fMode[fTop] = fMode[fTop+n];
        fBox[fTop] = fBox[fTop+n];
    }
}

void GTKUI::closeBox()
{
    --fTop;
    assert(fTop >= 0);
}

/**
 * Analyses the widget zone metadata declarations and takes
 * appropriate actions 
 */
void GTKUI::declare(FAUSTFLOAT* zone, const char* key, const char* value)
{
	if (zone == 0) {
		// special zone 0 means group metadata
		if (strcmp(key,"tooltip") == 0) {
			// only group tooltip are currently implemented
			gGroupTooltip = formatTooltip(30, value);
		}
	} else {
		if (strcmp(key,"size")==0) {
			fGuiSize[zone] = atof(value);
		}
		else if (strcmp(key,"tooltip") == 0) {
			fTooltip[zone] = formatTooltip(30,value) ;
		}
		else if (strcmp(key,"style") == 0) {
			if (strcmp(value,"knob") == 0) {
				fKnobSet.insert(zone);
			}
		}
	}
}
    
/**
 * Analyses a full label and activates the relevant options. returns a simplified
 * label (without options) and an amount of stack adjustement (in case additional
 * containers were pushed on the stack). 
 */

int GTKUI::checkLabelOptions(GtkWidget* widget, const std::string& fullLabel, std::string& simplifiedLabel)
{   
    std::map<std::string, std::string> metadata;
    extractMetadata(fullLabel, simplifiedLabel, metadata);

    if (metadata.count("tooltip")) {
        gtk_tooltips_set_tip (gtk_tooltips_new (), widget, metadata["tooltip"].c_str(), NULL);
    }
    if (metadata["option"] == "detachable") {
        openHandleBox(simplifiedLabel.c_str());
        return 1;
    }

	//---------------------
	if (gGroupTooltip != std::string()) {
		gtk_tooltips_set_tip (gtk_tooltips_new (), widget, gGroupTooltip.c_str(), NULL);
		gGroupTooltip = std::string();
	}
	
	//----------------------
    // no adjustement of the stack needed
    return 0;
}

/**
 * Check if a tooltip is associated to a zone and add it to the corresponding widget
 */
void GTKUI::checkForTooltip(FAUSTFLOAT* zone, GtkWidget* widget)
{
    if (fTooltip.count(zone)) {
        gtk_tooltips_set_tip (gtk_tooltips_new (), widget, fTooltip[zone].c_str(), NULL);
    }
}

// les differentes boites

void GTKUI::openFrameBox(const char* label)
{
    GtkWidget * box = gtk_frame_new (label);
    //gtk_container_set_border_width (GTK_CONTAINER (box), 10);
            
    pushBox(kSingleMode, addWidget(label, box));
}

void GTKUI::openTabBox(const char* fullLabel)
{
    std::string label;
    GtkWidget* widget = gtk_notebook_new();

    int adjust = checkLabelOptions(widget, fullLabel, label);

    pushBox(kTabMode, addWidget(label.c_str(), widget));

    // adjust stack because otherwise Handlebox will remain open
    adjustStack(adjust);
}

void GTKUI::openHorizontalBox(const char* fullLabel)
{   
    std::string label;
    GtkWidget* box = gtk_hbox_new (homogene, 4);
    int adjust = checkLabelOptions(box, fullLabel, label);

    gtk_container_set_border_width (GTK_CONTAINER (box), 10);
            
    if (fMode[fTop] != kTabMode && label[0] != 0) {
        GtkWidget * frame = addWidget(label.c_str(), gtk_frame_new (label.c_str()));
        gtk_container_add (GTK_CONTAINER(frame), box);
        gtk_widget_show(box);
        pushBox(kBoxMode, box);
    } else {
        pushBox(kBoxMode, addWidget(label.c_str(), box));
    }

    // adjust stack because otherwise Handlebox will remain open
    adjustStack(adjust);
}

void GTKUI::openVerticalBox(const char* fullLabel)
{
    std::string  label;
    GtkWidget * box = gtk_vbox_new (homogene, 4);
    int      adjust = checkLabelOptions(box, fullLabel, label);

    gtk_container_set_border_width (GTK_CONTAINER (box), 10);
            
    if (fMode[fTop] != kTabMode && label[0] != 0) {
        GtkWidget * frame = addWidget(label.c_str(), gtk_frame_new (label.c_str()));
        gtk_container_add (GTK_CONTAINER(frame), box);
        gtk_widget_show(box);
        pushBox(kBoxMode, box);
    } else {
        pushBox(kBoxMode, addWidget(label.c_str(), box));
    }

    // adjust stack because otherwise Handlebox will remain open
    adjustStack(adjust);
}

void GTKUI::openHandleBox(const char* label)
{
    GtkWidget * box = gtk_hbox_new (homogene, 4);
    gtk_container_set_border_width (GTK_CONTAINER (box), 2);
    if (fMode[fTop] != kTabMode && label[0] != 0)
    {
        GtkWidget * frame = addWidget(label, gtk_handle_box_new ());
        gtk_container_add (GTK_CONTAINER(frame), box);
        gtk_widget_show(box);
        pushBox(kBoxMode, box);
    }
    else
    {
        pushBox(kBoxMode, addWidget(label, box));
    }
}

void GTKUI::openEventBox(const char* label)
{
    GtkWidget * box = gtk_hbox_new (homogene, 4);
    gtk_container_set_border_width (GTK_CONTAINER (box), 2);
    if (fMode[fTop] != kTabMode && label[0] != 0)
    {
        GtkWidget * frame = addWidget(label, gtk_event_box_new ());
        gtk_container_add (GTK_CONTAINER(frame), box);
        gtk_widget_show(box);
        pushBox(kBoxMode, box);
    }
    else
    {
        pushBox(kBoxMode, addWidget(label, box));
    }
}

struct uiExpanderBox : public uiItem
{
    GtkExpander* fButton;
    uiExpanderBox(GUI* ui, FAUSTFLOAT* zone, GtkExpander* b) : uiItem(ui, zone), fButton(b) {}
    static void expanded (GtkWidget *widget, gpointer data)
    {
        FAUSTFLOAT v = gtk_expander_get_expanded  (GTK_EXPANDER(widget));
        if (v == 1.000000) {
            v = 0;
        } else {
            v = 1;
        }
        ((uiItem*)data)->modifyZone(v);
    }

    virtual void reflectZone()
    {
        FAUSTFLOAT v = *fZone;
        fCache = v;
        gtk_expander_set_expanded(GTK_EXPANDER(fButton), v);
    }
};

void GTKUI::openExpanderBox(const char* label, FAUSTFLOAT* zone)
{
    *zone = 0.0;
    GtkWidget * box = gtk_hbox_new (homogene, 4);
    gtk_container_set_border_width (GTK_CONTAINER (box), 2);
    if (fMode[fTop] != kTabMode && label[0] != 0)
    {
        GtkWidget * frame = addWidget(label, gtk_expander_new (label));
        gtk_container_add (GTK_CONTAINER(frame), box);
        uiExpanderBox* c = new uiExpanderBox(this, zone, GTK_EXPANDER(frame));
        gtk_signal_connect (GTK_OBJECT (frame), "activate", GTK_SIGNAL_FUNC (uiExpanderBox::expanded), (gpointer)c);
        gtk_widget_show(box);
        pushBox(kBoxMode, box);
    }
    else
    {
        pushBox(kBoxMode, addWidget(label, box));
    }
}

GtkWidget* GTKUI::addWidget(const char* label, GtkWidget* w)
{ 
    switch (fMode[fTop]) {
        case kSingleMode    : gtk_container_add (GTK_CONTAINER(fBox[fTop]), w);                             break;
        case kBoxMode       : gtk_box_pack_start (GTK_BOX(fBox[fTop]), w, expand, fill, 0);                 break;
        case kTabMode       : gtk_notebook_append_page (GTK_NOTEBOOK(fBox[fTop]), w, gtk_label_new(label)); break;
    }
    gtk_widget_show (w);
    return w;
}

// --------------------------- Press button ---------------------------

struct uiButton : public uiItem
{
    GtkButton*  fButton;
    
    uiButton(GUI* ui, FAUSTFLOAT* zone, GtkButton* b) : uiItem(ui, zone), fButton(b) {}
    
    static void pressed(GtkWidget *widget, gpointer data)
    {
        uiItem* c = (uiItem*) data;
        c->modifyZone(1.0);
    }

    static void released(GtkWidget *widget, gpointer data)
    {
        uiItem* c = (uiItem*) data;
        c->modifyZone(0.0);
    }

    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v; 
        if (v > 0.0) gtk_button_pressed(fButton); else gtk_button_released(fButton);
    }
};

void GTKUI::addButton(const char* label, FAUSTFLOAT* zone)
{
    *zone = 0.0;
    GtkWidget*  button = gtk_button_new_with_label (label);
    addWidget(label, button);
    
    uiButton* c = new uiButton(this, zone, GTK_BUTTON(button));
    
    gtk_signal_connect (GTK_OBJECT (button), "pressed", GTK_SIGNAL_FUNC (uiButton::pressed), (gpointer) c);
    gtk_signal_connect (GTK_OBJECT (button), "released", GTK_SIGNAL_FUNC (uiButton::released), (gpointer) c);

    checkForTooltip(zone, button);
}

// ---------------------------  Toggle Buttons ---------------------------

struct uiToggleButton : public uiItem
{
    GtkToggleButton* fButton;
    
    uiToggleButton(GUI* ui, FAUSTFLOAT* zone, GtkToggleButton* b) : uiItem(ui, zone), fButton(b) {}
    
    static void toggled (GtkWidget *widget, gpointer data)
    {
        FAUSTFLOAT v = (GTK_TOGGLE_BUTTON (widget)->active) ? 1.0 : 0.0; 
        ((uiItem*)data)->modifyZone(v);
    }

    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v; 
        gtk_toggle_button_set_active(fButton, v > 0.0); 
    }
};

void GTKUI::addToggleButton(const char* label, FAUSTFLOAT* zone)
{
    *zone = 0.0;
    GtkWidget*  button = gtk_toggle_button_new_with_label (label);
    addWidget(label, button);
    
    uiToggleButton* c = new uiToggleButton(this, zone, GTK_TOGGLE_BUTTON(button));
    gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC (uiToggleButton::toggled), (gpointer) c);

    checkForTooltip(zone, button);
}

void show_dialog(GtkWidget *widget, gpointer data)
{
    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget)) == TRUE)
    {
        gtk_widget_show(GTK_WIDGET(data));
        gint root_x, root_y;
        gtk_window_get_position (GTK_WINDOW(data), &root_x, &root_y);
        root_y -= 120;
        gtk_window_move(GTK_WINDOW(data), root_x, root_y);
    }
    else gtk_widget_hide(GTK_WIDGET(data));
}

static gboolean deleteevent( GtkWidget *widget, gpointer   data )
{
    return TRUE;
} 

void GTKUI::openDialogBox(const char* label, FAUSTFLOAT* zone)
{
    // create toplevel window and set properties
    GtkWidget * dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_window_set_decorated(GTK_WINDOW(dialog), TRUE);
    gtk_window_set_deletable(GTK_WINDOW(dialog), FALSE);
    gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
    gtk_window_set_gravity(GTK_WINDOW(dialog), GDK_GRAVITY_SOUTH);
    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(fWindow));
    gtk_window_set_position (GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
    gtk_window_set_keep_below (GTK_WINDOW(dialog), FALSE);
    gtk_window_set_title (GTK_WINDOW (dialog), label);
    g_signal_connect (G_OBJECT (dialog), "delete_event", G_CALLBACK (deleteevent), NULL); 
    gtk_window_set_destroy_with_parent(GTK_WINDOW(dialog), TRUE);

    GtkWidget * box = gtk_hbox_new (homogene, 4);
 
    *zone = 0.0;
    GtkWidget*  button = gtk_toggle_button_new ();
    gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC (show_dialog), (gpointer) dialog);
 
    gtk_container_add (GTK_CONTAINER(fBox[fTop]), button);
    gtk_container_add (GTK_CONTAINER(dialog), box);
    gtk_widget_show (button);
    gtk_widget_show(box);
    pushBox(kBoxMode, box);
}

// ---------------------------  Check Button ---------------------------

struct uiCheckButton : public uiItem
{
    GtkToggleButton* fButton;
    
    uiCheckButton(GUI* ui, FAUSTFLOAT* zone, GtkToggleButton* b) : uiItem(ui, zone), fButton(b) {}
    
    static void toggled (GtkWidget *widget, gpointer data)
    {
        FAUSTFLOAT v = (GTK_TOGGLE_BUTTON (widget)->active) ? 1.0 : 0.0; 
        ((uiItem*)data)->modifyZone(v);
    }

    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v; 
        gtk_toggle_button_set_active(fButton, v > 0.0); 
    }
};

void GTKUI::addCheckButton(const char* label, FAUSTFLOAT* zone)
{
    *zone = 0.0;
    GtkWidget*  button = gtk_check_button_new_with_label (label);
    addWidget(label, button);
    
    uiCheckButton* c = new uiCheckButton(this, zone, GTK_TOGGLE_BUTTON(button));
    gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC(uiCheckButton::toggled), (gpointer) c);

    checkForTooltip(zone, button);
}

// ---------------------------  Adjustmenty based widgets ---------------------------

struct uiAdjustment : public uiItem
{
    GtkAdjustment* fAdj;
    
    uiAdjustment(GUI* ui, FAUSTFLOAT* zone, GtkAdjustment* adj) : uiItem(ui, zone), fAdj(adj) {}
    
    static void changed (GtkWidget *widget, gpointer data)
    {
        FAUSTFLOAT v = GTK_ADJUSTMENT (widget)->value; 
        ((uiItem*)data)->modifyZone(v);
    }

    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v; 
        gtk_adjustment_set_value(fAdj, v);  
    }
};

// --------------------------- format knob value display ---------------------------

struct uiValueDisplay : public uiItem
{
	GtkLabel* fLabel;
	int	fPrecision ;

	uiValueDisplay(GUI* ui, FAUSTFLOAT* zone, GtkLabel* label, int precision)
		: uiItem(ui, zone), fLabel(label), fPrecision(precision) {}

	virtual void reflectZone()
		{
			FAUSTFLOAT v = *fZone;
			fCache = v;
			char s[64];
			if (fPrecision <= 0)
				snprintf(s, 63, "%d", int(v));

			else if (fPrecision > 3)
				snprintf(s, 63, "%f", v);

			else if (fPrecision == 1)
			{
				const char* format[] = {"%.1f", "%.2f", "%.3f"};
				snprintf(s, 63, format[1-1], v);
			}
			else if (fPrecision == 2)
			{
				const char* format[] = {"%.1f", "%.2f", "%.3f"};
				snprintf(s, 63, format[2-1], v);
			}
			else
			{
				const char* format[] = {"%.1f", "%.2f", "%.3f"};
				snprintf(s, 63, format[3-1], v);
			}
			gtk_label_set_text(fLabel, s);
		}
};

// ------------------------------- Knob -----------------------------------------

void GTKUI::addKnob(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step)
{
	*zone = init;
    GtkObject* adj = gtk_adjustment_new(init, min, max, step, 10*step, 0);
    
    uiAdjustment* c = new uiAdjustment(this, zone, GTK_ADJUSTMENT(adj));

    gtk_signal_connect (GTK_OBJECT (adj), "value-changed", GTK_SIGNAL_FUNC (uiAdjustment::changed), (gpointer) c);
    
	GtkWidget* slider = gtk_vbox_new (FALSE, 0);
	GtkWidget* fil = gtk_vbox_new (FALSE, 0);
	GtkWidget* rei = gtk_vbox_new (FALSE, 0);
	GtkWidget* re =myGtkKnob.gtk_knob_new_with_adjustment(GTK_ADJUSTMENT(adj));
	GtkWidget* lw = gtk_label_new("");
	new uiValueDisplay(this, zone, GTK_LABEL(lw),precision(step));
	gtk_container_add (GTK_CONTAINER(rei), re);
	if(fGuiSize[zone]) {
		FAUSTFLOAT size = 30 * fGuiSize[zone];
		gtk_widget_set_size_request(rei, size, size );
		gtk_box_pack_start (GTK_BOX(slider), fil, TRUE, TRUE, 0);
		gtk_box_pack_start (GTK_BOX(slider), rei, FALSE, FALSE, 0);
	} else {
		gtk_container_add (GTK_CONTAINER(slider), fil);
		gtk_container_add (GTK_CONTAINER(slider), rei);
	}
	gtk_container_add (GTK_CONTAINER(slider), lw);
	gtk_widget_show_all(slider);
	
	if (label && label[0]!=0) {
        openFrameBox(label);
        addWidget(label, slider);
        closeBox();
    } else {
        addWidget(label, slider);
    }

    checkForTooltip(zone, slider);
}

// -------------------------- Vertical Slider -----------------------------------

void GTKUI::addVerticalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step)
{
	if (isKnob(zone)) { 
		addKnob(label, zone, init, min, max, step);
		return;
	} 
    *zone = init;
    GtkObject* adj = gtk_adjustment_new(init, min, max, step, 10*step, 0);
    
    uiAdjustment* c = new uiAdjustment(this, zone, GTK_ADJUSTMENT(adj));

    gtk_signal_connect (GTK_OBJECT (adj), "value-changed", GTK_SIGNAL_FUNC (uiAdjustment::changed), (gpointer) c);
    
	GtkWidget* slider = gtk_vscale_new (GTK_ADJUSTMENT(adj));
	gtk_scale_set_digits(GTK_SCALE(slider), precision(step));
	FAUSTFLOAT size = 160;
	if(fGuiSize[zone]) {
		size = 160 * fGuiSize[zone];
	}
	gtk_widget_set_size_request(slider, -1, size);
	
    gtk_range_set_inverted (GTK_RANGE(slider), TRUE);
    
    if (label && label[0]!=0) {
        openFrameBox(label);
        addWidget(label, slider);
        closeBox();
    } else {
        addWidget(label, slider);
    }

    checkForTooltip(zone, slider);
}

// -------------------------- Horizontal Slider -----------------------------------

void GTKUI::addHorizontalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step)
{
	if (isKnob(zone)) { 
		addKnob(label, zone, init, min, max, step);
		return;
	} 
    *zone = init;
    GtkObject* adj = gtk_adjustment_new(init, min, max, step, 10*step, 0);
    
    uiAdjustment* c = new uiAdjustment(this, zone, GTK_ADJUSTMENT(adj));

    gtk_signal_connect (GTK_OBJECT (adj), "value-changed", GTK_SIGNAL_FUNC (uiAdjustment::changed), (gpointer) c);
    
    GtkWidget* slider = gtk_hscale_new (GTK_ADJUSTMENT(adj));
	gtk_scale_set_digits(GTK_SCALE(slider), precision(step));
	FAUSTFLOAT size = 160;
	if(fGuiSize[zone]) {
		size = 160 * fGuiSize[zone];
	}
	gtk_widget_set_size_request(slider, size, -1);
    
    if (label && label[0]!=0) {
        openFrameBox(label);
        addWidget(label, slider);
        closeBox();
    } else {
        addWidget(label, slider);
    }             

    checkForTooltip(zone, slider);
}

// ------------------------------ Num Entry -----------------------------------

void GTKUI::addNumEntry(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step)
{
	if (isKnob(zone)) { 
		addKnob(label, zone, init, min, max, step);
		return;
	} 
    *zone = init;
    GtkObject* adj = gtk_adjustment_new(init, min, max, step, 10*step, step);
    
    uiAdjustment* c = new uiAdjustment(this, zone, GTK_ADJUSTMENT(adj));

    gtk_signal_connect (GTK_OBJECT (adj), "value-changed", GTK_SIGNAL_FUNC (uiAdjustment::changed), (gpointer) c);
    
    GtkWidget* spinner = gtk_spin_button_new (GTK_ADJUSTMENT(adj), 0.005, precision(step));

    openFrameBox(label);
    addWidget(label, spinner);
    closeBox();

    checkForTooltip(zone, spinner);
}

// ==========================   passive widgets ===============================

// ------------------------------ Progress Bar -----------------------------------

struct uiBargraph : public uiItem
{
    GtkProgressBar*     fProgressBar;
    FAUSTFLOAT          fMin;
    FAUSTFLOAT          fMax;
    
    uiBargraph(GUI* ui, FAUSTFLOAT* zone, GtkProgressBar* pbar, FAUSTFLOAT lo, FAUSTFLOAT hi) 
            : uiItem(ui, zone), fProgressBar(pbar), fMin(lo), fMax(hi) {}

    FAUSTFLOAT scale(FAUSTFLOAT v)        { return (v-fMin)/(fMax-fMin); }
    
    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v; 
        gtk_progress_bar_set_fraction(fProgressBar, scale(v));  
    }
};

void GTKUI::addVerticalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT lo, FAUSTFLOAT hi)
{
    GtkWidget* pb = gtk_progress_bar_new();
    gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(pb), GTK_PROGRESS_BOTTOM_TO_TOP);
    gtk_widget_set_size_request(pb, 8, -1);
    new uiBargraph(this, zone, GTK_PROGRESS_BAR(pb), lo, hi);
    openFrameBox(label);
    addWidget(label, pb);
    closeBox();

    checkForTooltip(zone, pb);
}
    
void GTKUI::addHorizontalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT lo, FAUSTFLOAT hi)
{
    GtkWidget* pb = gtk_progress_bar_new();
    gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(pb), GTK_PROGRESS_LEFT_TO_RIGHT);
    gtk_widget_set_size_request(pb, -1, 8);
    new uiBargraph(this, zone, GTK_PROGRESS_BAR(pb), lo, hi);
    openFrameBox(label);
    addWidget(label, pb);
    closeBox();

    checkForTooltip(zone, pb);
}

// ------------------------------ Num Display -----------------------------------

struct uiNumDisplay : public uiItem
{
    GtkLabel* fLabel;
    int fPrecision;
    
    uiNumDisplay(GUI* ui, FAUSTFLOAT* zone, GtkLabel* label, int precision) 
            : uiItem(ui, zone), fLabel(label), fPrecision(precision) {}

    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v;
        char s[64]; 
        if (fPrecision <= 0) { 
            snprintf(s, 63, "%d", int(v)); 
        } else if (fPrecision>3) {
            snprintf(s, 63, "%f", v);
        } else {
            const char* format[] = {"%.1f", "%.2f", "%.3f"};
            snprintf(s, 63, format[fPrecision-1], v);
        }
        gtk_label_set_text(fLabel, s);
    }
};

void GTKUI::addNumDisplay(const char* label, FAUSTFLOAT* zone, int precision)
{
    GtkWidget* lw = gtk_label_new("");
    new uiNumDisplay(this, zone, GTK_LABEL(lw), precision);
    openFrameBox(label);
    addWidget(label, lw);
    closeBox();

    checkForTooltip(zone, lw);
}

// ------------------------------ Text Display -----------------------------------

struct uiTextDisplay : public uiItem
{
    GtkLabel*       fLabel;
    const char**    fNames;
    FAUSTFLOAT      fMin;
    FAUSTFLOAT      fMax;
    int             fNum;
    
    uiTextDisplay (GUI* ui, FAUSTFLOAT* zone, GtkLabel* label, const char* names[], FAUSTFLOAT lo, FAUSTFLOAT hi)
                    : uiItem(ui, zone), fLabel(label), fNames(names), fMin(lo), fMax(hi)
    {
        fNum = 0;
        while (fNames[fNum] != 0) fNum++;
    }

    virtual void reflectZone()  
    { 
        FAUSTFLOAT v = *fZone;
        fCache = v;
        
        int idx = int(fNum*(v-fMin)/(fMax-fMin));
        
        if      (idx < 0)       idx = 0; 
        else if (idx >= fNum)   idx = fNum-1;
                
        gtk_label_set_text(fLabel, fNames[idx]); 
    }
};
    
void GTKUI::addTextDisplay(const char* label, FAUSTFLOAT* zone, const char* names[], FAUSTFLOAT lo, FAUSTFLOAT hi)
{
    GtkWidget* lw = gtk_label_new("");
    new uiTextDisplay (this, zone, GTK_LABEL(lw), names, lo, hi);
    openFrameBox(label);
    addWidget(label, lw);
    closeBox();

    checkForTooltip(zone, lw);
}

void GTKUI::show() 
{
    assert(fTop == 0);
    gtk_widget_show  (fBox[0]);
    gtk_widget_show  (fWindow);
}

/**
 * Update all user items reflecting zone z
 */
    
static gboolean callUpdateAllGuis(gpointer)
{ 
    GUI::updateAllGuis(); 
    return TRUE;
}

void GTKUI::run() 
{
    assert(fTop == 0);
    gtk_widget_show  (fBox[0]);
    gtk_widget_show  (fWindow);
    gtk_timeout_add(40, callUpdateAllGuis, 0);
    gtk_main ();
    stop();
}

#endif


#ifndef __jack_dsp__
#define __jack_dsp__

#include <stdio.h>
#include <cstdlib>
#include <list>
#include <string.h>
#include <jack/jack.h>
#ifdef JACK_IOS
#include <jack/custom.h>
#endif

/******************************************************************************
*******************************************************************************

						An abstraction layer over audio layer

*******************************************************************************
*******************************************************************************/

#ifndef __audio__
#define __audio__
			
class dsp;

typedef void (* shutdown_callback)(const char* message, void* arg);

typedef void (* buffer_size_callback)(int frames, void* arg);

class audio {
    
 public:
			 audio() {}
	virtual ~audio() {}
	
	virtual bool init(const char* name, dsp*)               = 0;
	virtual bool start()                                    = 0;
	virtual void stop()                                     = 0;
    virtual void shutdown(shutdown_callback cb, void* arg)  {}
    
};
					
#endif

/******************************************************************************
*******************************************************************************

								FAUST DSP

*******************************************************************************
*******************************************************************************/

#ifndef __dsp__
#define __dsp__

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif

class UI;

//----------------------------------------------------------------
//  signal processor definition
//----------------------------------------------------------------

class dsp {
 protected:
	int fSamplingFreq;
 public:
	dsp() {}
	virtual ~dsp() {}

	virtual int getNumInputs() 										= 0;
	virtual int getNumOutputs() 									= 0;
	virtual void buildUserInterface(UI* interface) 					= 0;
	virtual void init(int samplingRate) 							= 0;
 	virtual void compute(int len, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) 	= 0;
};

// On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
// flags to avoid costly denormals
#ifdef __SSE__
    #include <xmmintrin.h>
    #ifdef __SSE2__
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8040)
    #else
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8000)
    #endif
#else
    #define AVOIDDENORMALS
#endif

#endif

/******************************************************************************
*******************************************************************************

							JACK AUDIO INTERFACE

*******************************************************************************
*******************************************************************************/

class jackaudio : public audio {
    
    private:

        dsp*			fDsp;               // FAUST DSP
        jack_client_t*	fClient;            // JACK client
    
        int				fNumInChans;		// number of input channels
        int				fNumOutChans;       // number of output channels
    
        jack_port_t**	fInputPorts;       // JACK input ports
        jack_port_t**	fOutputPorts;      // JACK output ports
    
        shutdown_callback fShutdown;        // Shutdown callback to be called by libjack
        void*           fShutdownArg;
        void*           fIconData;
        int             fIconSize;
        bool            fAutoConnect;
        
        std::list<std::pair<std::string, std::string> > fConnections;		// Connections list
    
        static int  _jack_srate(jack_nframes_t nframes, void* arg);
        static void _jack_shutdown(void* arg);
        static void _jack_info_shutdown(jack_status_t code, const char* reason, void* arg);
        static int  _jack_process(jack_nframes_t nframes, void* arg);
        static int  _jack_buffersize(jack_nframes_t nframes, void* arg);
    #ifdef _OPENMP
        static void* _jack_thread(void* arg);
    #endif
        void shutdown(const char* message)
        {
            if (fShutdown) {
                fShutdown(message, fShutdownArg);
            } else {
                exit(1); // By default
            }
        }
        
        // Save client connections
        void save_connections()
        {
            fConnections.clear();
            
             for (int i = 0; i < fNumInChans; i++) {
                const char** connected_port = jack_port_get_all_connections(fClient, fInputPorts[i]);
                if (connected_port != NULL) {
                    for (int port = 0; connected_port[port]; port++) {
                        fConnections.push_back(std::make_pair(connected_port[port], jack_port_name(fInputPorts[i])));
                        printf("INPUT %s ==> %s\n", connected_port[port], jack_port_name(fInputPorts[i]));
                    }
                    jack_free(connected_port);
                }
            }
       
            for (int i = 0; i < fNumOutChans; i++) {
                const char** connected_port = jack_port_get_all_connections(fClient, fOutputPorts[i]);
                if (connected_port != NULL) {
                    for (int port = 0; connected_port[port]; port++) {
                        fConnections.push_back(std::make_pair(jack_port_name(fOutputPorts[i]), connected_port[port]));
                        printf("OUTPUT %s ==> %s\n", jack_port_name(fOutputPorts[i]), connected_port[port]);
                    }
                    jack_free(connected_port);
                }
            }
        }

        // Load previous client connections
        void load_connections()
        {
            std::list<std::pair<std::string, std::string> >::const_iterator it;
            for (it = fConnections.begin(); it != fConnections.end(); it++) {
                std::pair<std::string, std::string> connection = *it;
                jack_connect(fClient, connection.first.c_str(), connection.second.c_str());
            }
        }
        
        // Connect to physical inputs/outputs
        void default_connections()
        {
            char** physicalOutPorts = (char**)jack_get_ports(fClient, NULL, JACK_DEFAULT_AUDIO_TYPE, JackPortIsPhysical|JackPortIsOutput);
            if (physicalOutPorts != NULL) {
                for (int i = 0; i < fNumInChans && physicalOutPorts[i]; i++) {
                    jack_connect(fClient, physicalOutPorts[i], jack_port_name(fInputPorts[i]));
                }
                jack_free(physicalOutPorts);
            }
            
            char** physicalInPorts = (char**)jack_get_ports(fClient, NULL, JACK_DEFAULT_AUDIO_TYPE, JackPortIsPhysical|JackPortIsInput);
            if (physicalInPorts != NULL) {
                for (int i = 0; i < fNumOutChans && physicalInPorts[i]; i++) {
                    jack_connect(fClient, jack_port_name(fOutputPorts[i]), physicalInPorts[i]);
                }
                jack_free(physicalInPorts);
            }
        }

    public:
        jackaudio(const void* icon_data = 0, size_t icon_size = 0, bool auto_connect = true) 
            : fClient(0), fNumInChans(0), fNumOutChans(0), fAutoConnect(auto_connect)
        {
            if (icon_data) {
                fIconData = malloc(icon_size);
                fIconSize = icon_size;
                memcpy(fIconData, icon_data, icon_size);
            } else {
                fIconData = NULL;
                fIconSize = 0;
            }
        }
        virtual ~jackaudio() 
        { 
            stop(); 
            if (fIconData) {
                free(fIconData);
            }
        }
        
        jack_client_t* getClient() { return fClient; }

        virtual bool init(const char* name, dsp* DSP) 
        {
            fDsp = DSP;
            if ((fClient = jack_client_open(name, JackNullOption, NULL)) == 0) {
                fprintf(stderr, "JACK server not running ?\n");
                return false;
            }
        #ifdef JACK_IOS
            jack_custom_publish_data(fClient, "icon.png", fIconData, fIconSize);
        #endif
            
        #ifdef _OPENMP
            jack_set_process_thread(fClient, _jack_thread, this);
        #else
            jack_set_process_callback(fClient, _jack_process, this);
        #endif

            jack_set_sample_rate_callback(fClient, _jack_srate, this);
            jack_set_buffer_size_callback(fClient, _jack_buffersize, this);
            jack_on_info_shutdown(fClient, _jack_info_shutdown, this);

            fNumInChans  = fDsp->getNumInputs();
            fNumOutChans = fDsp->getNumOutputs();
            
            fInputPorts = new jack_port_t*[fNumInChans];
            fOutputPorts = new jack_port_t*[fNumOutChans];
        
            for (int i = 0; i < fNumInChans; i++) {
                char buf[256];
                snprintf(buf, 256, "in_%d", i);
                fInputPorts[i] = jack_port_register(fClient, buf, JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
            }
            for (int i = 0; i < fNumOutChans; i++) {
                char buf[256];
                snprintf(buf, 256, "out_%d", i);
                fOutputPorts[i] = jack_port_register(fClient, buf, JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
            }
            fDsp->init(jack_get_sample_rate(fClient));
            return true;
        }

        virtual bool start() 
        {
            if (jack_activate(fClient)) {
                fprintf(stderr, "Cannot activate client");
                return false;
            }
            
            if (fConnections.size() > 0) {
                load_connections();
            } else if (fAutoConnect) {
                default_connections();
            }
            return true;
        }

        virtual void stop() 
        {
            if (fClient) {
                save_connections();
                jack_deactivate(fClient);
                for (int i = 0; i < fNumInChans; i++) {
                    jack_port_unregister(fClient, fInputPorts[i]);
                }
                for (int i = 0; i < fNumOutChans; i++) {
                    jack_port_unregister(fClient, fOutputPorts[i]);
                }
                jack_client_close(fClient);
                fClient = 0;
                
                delete[] fInputPorts;
                delete[] fOutputPorts;
            }
        }
    
        virtual void shutdown(shutdown_callback cb, void* arg)
        {
            fShutdown = cb;
            fShutdownArg = arg;
        }

        // jack callbacks
        int	process(jack_nframes_t nframes) 
        {
            AVOIDDENORMALS;
            // Retrieve JACK inputs/output audio buffers
            float* fInChannel[fNumInChans];
            for (int i = 0; i < fNumInChans; i++) {
                fInChannel[i] = (float*)jack_port_get_buffer(fInputPorts[i], nframes);
            }
            float* fOutChannel[fNumOutChans];
            for (int i = 0; i < fNumOutChans; i++) {
                fOutChannel[i] = (float*)jack_port_get_buffer(fOutputPorts[i], nframes);
            }
            fDsp->compute(nframes, fInChannel, fOutChannel);
            return 0;
        }

    #ifdef _OPENMP
        void process_thread() 
        {
            jack_nframes_t nframes;
            while (1) {
                nframes = jack_cycle_wait(fClient);
                process(nframes);
                jack_cycle_signal(fClient, 0);
            }
        }
    #endif
};

//----------------------------------------------------------------------------
// Jack Callbacks
//----------------------------------------------------------------------------

int jackaudio::_jack_srate(jack_nframes_t nframes, void* arg)
{
  	fprintf(stdout, "The sample rate is now %u/sec\n", nframes);
	return 0;
}

int jackaudio::_jack_buffersize(jack_nframes_t nframes, void* arg)
{
  	fprintf(stdout, "The buffer size is now %u/sec\n", nframes);
	return 0;
}

void jackaudio::_jack_info_shutdown(jack_status_t code, const char* reason, void* arg)
{
    fprintf(stderr, "%s\n", reason);
	jackaudio* audio = (jackaudio*)arg;
    audio->shutdown(reason);
}

int jackaudio::_jack_process(jack_nframes_t nframes, void* arg)
{
	jackaudio* audio = (jackaudio*)arg;
	return audio->process(nframes);
}

#ifdef _OPENMP
void* jackaudio::_jack_thread(void* arg)
{
	jackaudio* audio = (jackaudio*)arg;
	audio->process_thread();
	return 0;
}
#endif

#endif

#ifdef OSCCTRL
/*
   Copyright (C) 2011 Grame - Lyon
   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted.
*/

#ifndef __OSCUI__
#define __OSCUI__

/*

  Faust Project

  Copyright (C) 2011 Grame

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

  Grame Research Laboratory, 9 rue du Garet, 69001 Lyon - France
  research@grame.fr

*/

#ifndef __OSCControler__
#define __OSCControler__

#include <string>

namespace oscfaust
{

class OSCIO;
class OSCSetup;
class FaustFactory;

//--------------------------------------------------------------------------
/*!
	\brief the main Faust OSC Lib API
	
	The OSCControler is essentially a glue between the memory representation (in charge of the FaustFactory), 
	and the network services (in charge of OSCSetup).
*/
class OSCControler
{
	int fUDPPort, fUDPOut, fUPDErr;		// the udp ports numbers
	std::string		fDestAddress;		// the osc messages destination address
	FaustFactory *	fFactory;			// a factory to build the memory represetnatin
	OSCSetup*		fOsc;				// the network manager (handles the udp sockets)
	OSCIO*			fIO;				// hack for OSC IO support (actually only relayed to the factory)

	public:
		/*
			base udp port is chosen in an unassigned range from IANA PORT NUMBERS (last updated 2011-01-24)
			see at http://www.iana.org/assignments/port-numbers
			5507-5552  Unassigned
		*/
		enum { kUDPBasePort = 5510};

				 OSCControler (int argc, char *argv[], OSCIO* io=0);
		virtual ~OSCControler ();
	
		//--------------------------------------------------------------------------
		// addnode, opengroup and closegroup are simply relayed to the factory
		//--------------------------------------------------------------------------
		// Add a node in the current group (top of the group stack)
		template <typename C> void addnode (const char* label, C* zone, C init, C min, C max);
		
		//--------------------------------------------------------------------------
		// Add a node using its fullpath from the root instead of the current group
		// This method is used for alias messages. The arguments imin and imax allow
		// to map incomming values from the alias input range to the actual range 
		template <typename C> void addfullpathnode (const std::string& fullpath, C* zone, C imin, C imax, C init, C min, C max);
        	
		void opengroup (const char* label);
		void closegroup ();

		//--------------------------------------------------------------------------
		void run ();				// starts the network services
		void quit ();				// stop the network services
		
		int	getUDPPort()			{ return fUDPPort; }
		int	getUDPOut()				{ return fUDPOut; }
		int	getUDPErr()				{ return fUPDErr; }
		const char*	getDesAddress() { return fDestAddress.c_str(); }
		const char*	getRootName();	// probably useless, introduced for UI extension experiments

		static float version();				// the Faust OSC library version number
		static const char* versionstr();	// the Faust OSC library version number as a string
};

}

#endif
#include <vector>

/******************************************************************************
*******************************************************************************

					OSC (Open Sound Control) USER INTERFACE

*******************************************************************************
*******************************************************************************/
/*

Note about the OSC addresses and the Faust UI names:
----------------------------------------------------
There are potential conflicts between the Faust UI objects naming scheme and 
the OSC address space. An OSC symbolic names is an ASCII string consisting of
printable characters other than the following:
	space 
#	number sign
*	asterisk
,	comma
/	forward
?	question mark
[	open bracket
]	close bracket
{	open curly brace
}	close curly brace

a simple solution to address the problem consists in replacing 
space or tabulation with '_' (underscore)
all the other osc excluded characters with '-' (hyphen)

This solution is implemented in the proposed OSC UI;
*/

///using namespace std;

//class oscfaust::OSCIO;
class OSCUI : public GUI 
{
     
	oscfaust::OSCControler*	fCtrl;
	std::vector<const char*>		fAlias;
	
	const char* tr(const char* label) const;
	
	// add all accumulated alias
	void addalias(FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max) 
	{
		for (unsigned int i=0; i<fAlias.size(); i++) {
			fCtrl->addfullpathnode(fAlias[i], zone, (FAUSTFLOAT)0, (FAUSTFLOAT)1, init, min, max);
		}
		fAlias.clear();
	}
	
 public:
		
	OSCUI(char* /*applicationname*/, int argc, char *argv[], oscfaust::OSCIO* io=0) : GUI() 
    { 
		fCtrl = new oscfaust::OSCControler(argc, argv, io); 
//		fCtrl->opengroup(applicationname);
	}
	
	virtual ~OSCUI() { delete fCtrl; }
    
    // -- widget's layouts
    
  	virtual void openTabBox(const char* label) 			{ fCtrl->opengroup( tr(label)); }
	virtual void openHorizontalBox(const char* label) 	{ fCtrl->opengroup( tr(label)); }
	virtual void openVerticalBox(const char* label) 	{ fCtrl->opengroup( tr(label)); }
	virtual void closeBox() 							{ fCtrl->closegroup(); }

	
	// -- active widgets
	virtual void addButton(const char* label, FAUSTFLOAT* zone) 		{ addalias(zone, 0, 0, 1); fCtrl->addnode( tr(label), zone, (FAUSTFLOAT)0, (FAUSTFLOAT)0, (FAUSTFLOAT)1); }
	virtual void addCheckButton(const char* label, FAUSTFLOAT* zone) 	{ addalias(zone, 0, 0, 1); fCtrl->addnode( tr(label), zone, (FAUSTFLOAT)0, (FAUSTFLOAT)0, (FAUSTFLOAT)1); }
	virtual void addVerticalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT /*step*/) 	{ addalias(zone, init, min, max); fCtrl->addnode( tr(label), zone, init, min, max); }
	virtual void addHorizontalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT /*step*/) { addalias(zone, init, min, max); fCtrl->addnode( tr(label), zone, init, min, max); }
	virtual void addNumEntry(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT /*step*/) 		{ addalias(zone, init, min, max); fCtrl->addnode( tr(label), zone, init, min, max); }
	
	// -- passive widgets
	
	virtual void addHorizontalBargraph(const char* /*label*/, FAUSTFLOAT* /*zone*/, FAUSTFLOAT /*min*/, FAUSTFLOAT /*max*/) {}
	virtual void addVerticalBargraph(const char* /*label*/, FAUSTFLOAT* /*zone*/, FAUSTFLOAT /*min*/, FAUSTFLOAT /*max*/) {}
		
	// -- metadata declarations
    
	virtual void declare(FAUSTFLOAT* , const char* key , const char* alias) 
	{ 
		if (strcasecmp(key,"OSC")==0) fAlias.push_back(alias);
	}

	virtual void show() {}

	void run()											{ fCtrl->run(); }
	const char* getRootName()							{ return fCtrl->getRootName(); }
};

const char* OSCUI::tr(const char* label) const
{
	static char buffer[1024];
	char * ptr = buffer; int n=1;
	while (*label && (n++ < 1024)) {
		switch (*label) {
			case ' ': case '	':
				*ptr++ = '_';
				break;
			case '#': case '*': case ',': case '/': case '?':
			case '[': case ']': case '{': case '}':
				*ptr++ = '_';
				break;
			default: 
				*ptr++ = *label;
		}
		label++;
	}
	*ptr = 0;
	return buffer;
}

#endif
#endif

#ifdef HTTPCTRL
/*
   Copyright (C) 2012 Grame - Lyon
   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted.
*/

#ifndef __httpdUI__
#define __httpdUI__

/*

  Faust Project

  Copyright (C) 2012 Grame

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

  Grame Research Laboratory, 9 rue du Garet, 69001 Lyon - France
  research@grame.fr

*/

#ifndef __HTTPDControler__
#define __HTTPDControler__

#include <string>
#include <map>

namespace httpdfaust
{

class HTTPDSetup;
class JSONDesc;
class FaustFactory;
class jsonfactory;
class htmlfactory;

//--------------------------------------------------------------------------
/*!
	\brief the main Faust HTTPD Lib API
	
	The HTTPDControler is essentially a glue between the memory representation (in charge of the FaustFactory), 
	and the network services (in charge of HTTPDSetup).
*/
class HTTPDControler
{
	int fTCPPort;				// the tcp port number
	FaustFactory *	fFactory;	// a factory to build the memory representation
	jsonfactory*	fJson;
	htmlfactory*	fHtml;
	HTTPDSetup*		fHttpd;		// the network manager
	std::string		fHTML;		// the corresponding HTML page
	std::map<std::string, std::string>	fCurrentMeta;	// the current meta declarations 

	public:
		/*
			base udp port is chosen in an unassigned range from IANA PORT NUMBERS (last updated 2011-01-24)
			see at http://www.iana.org/assignments/port-numbers
			5507-5552  Unassigned
		*/
		enum { kTCPBasePort = 5510};

				 HTTPDControler (int argc, char *argv[], const char* applicationname);
		virtual ~HTTPDControler ();
	
		//--------------------------------------------------------------------------
		// addnode, opengroup and closegroup are simply relayed to the factory
		//--------------------------------------------------------------------------
		template <typename C> void addnode (const char* type, const char* label, C* zone);
		template <typename C> void addnode (const char* type, const char* label, C* zone, C min, C max);
		template <typename C> void addnode (const char* type, const char* label, C* zone, C init, C min, C max, C step);
							  void declare (const char* key, const char* val ) { fCurrentMeta[key] = val; }

		void opengroup (const char* type, const char* label);
		void closegroup ();

		//--------------------------------------------------------------------------
		void run ();				// start the httpd server
		void quit ();				// stop the httpd server
		
		int	getTCPPort()			{ return fTCPPort; }

		static float version();				// the Faust httpd library version number
		static const char* versionstr();	// the Faust httpd library version number as a string
};

}

#endif

/******************************************************************************
*******************************************************************************

					HTTPD USER INTERFACE

*******************************************************************************
*******************************************************************************/
/*

Note about URLs and the Faust UI names:
----------------------------------------------------
Characters in a url could be:
1. Reserved: ; / ? : @ & = + $ ,
   These characters delimit URL parts.
2. Unreserved: alphanum - _ . ! ~ * ' ( )
   These characters have no special meaning and can be used as is.
3. Excluded: control characters, space, < > # % ", { } | \ ^ [ ] `

To solve potential conflicts between the Faust UI objects naming scheme and
the URL allowed characters, the reserved and excluded characters are replaced
with '-' (hyphen).
Space or tabulation are replaced with '_' (underscore)
*/

//using namespace std;

class httpdUI : public UI 
{
	httpdfaust::HTTPDControler*	fCtrl;	
	const char* tr(const char* label) const;

 public:
		
	httpdUI(const char* applicationname, int argc, char *argv[]) 
    { 
		fCtrl = new httpdfaust::HTTPDControler(argc, argv, applicationname); 
	}
	
	virtual ~httpdUI() { delete fCtrl; }
		
    // -- widget's layouts
	virtual void openTabBox(const char* label) 			{ fCtrl->opengroup( "tgroup", tr(label)); }
	virtual void openHorizontalBox(const char* label) 	{ fCtrl->opengroup( "hgroup", tr(label)); }
	virtual void openVerticalBox(const char* label) 	{ fCtrl->opengroup( "vgroup", tr(label)); }
	virtual void closeBox() 							{ fCtrl->closegroup(); }
	
	// -- active widgets
	virtual void addButton(const char* label, FAUSTFLOAT* zone)			{ fCtrl->addnode( "button", tr(label), zone); }
	virtual void addCheckButton(const char* label, FAUSTFLOAT* zone)	{ fCtrl->addnode( "checkbox", tr(label), zone); }
	virtual void addVerticalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step)
									{ fCtrl->addnode( "vslider", tr(label), zone, init, min, max, step); }
	virtual void addHorizontalSlider(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step) 	
									{ fCtrl->addnode( "hslider", tr(label), zone, init, min, max, step); }
	virtual void addNumEntry(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT init, FAUSTFLOAT min, FAUSTFLOAT max, FAUSTFLOAT step) 			
									{ fCtrl->addnode( "nentry", tr(label), zone, init, min, max, step); }
	
	// -- passive widgets	
	virtual void addHorizontalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT min, FAUSTFLOAT max) 
									{ fCtrl->addnode( "hbargraph", tr(label), zone, min, max); }
	virtual void addVerticalBargraph(const char* label, FAUSTFLOAT* zone, FAUSTFLOAT min, FAUSTFLOAT max)
									{ fCtrl->addnode( "vbargraph", tr(label), zone, min, max); }
	
    virtual void declare (FAUSTFLOAT* , const char* key, const char* val ) { fCtrl->declare(key, val); }

	void run()						{ fCtrl->run(); }
	int getTCPPort()                { return fCtrl->getTCPPort(); }

};

					
const char* httpdUI::tr(const char* label) const
{
	static char buffer[1024];
	char * ptr = buffer; int n=1;
	while (*label && (n++ < 1024)) {
		switch (*label) {
			case ' ': case '	':
				*ptr++ = '_';
				break;
			case ';': case '/': case '?': case ':': case '@': 
			case '&': case '=': case '+': case '$': case ',':
			case '<': case '>': case '#': case '%': case '"': 
			case '{': case '}': case '|': case '\\': case '^': 
			case '[': case ']': case '`':
				*ptr++ = '_';
				break;
			default: 
				*ptr++ = *label;
		}
		label++;
	}
	*ptr = 0;
	return buffer;
}

#endif
#endif

/**************************BEGIN USER SECTION **************************/

/******************************************************************************
*******************************************************************************

							       VECTOR INTRINSICS

*******************************************************************************
*******************************************************************************/



#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif  

typedef long double quad;

#ifndef FAUSTCLASS 
#define FAUSTCLASS mydsp
#endif

class mydsp : public dsp {
  private:
	float 	fYec0[512];
	int 	fYec0_idx;
	int 	fYec0_idx_save;
	FAUSTFLOAT 	fentry0;
	int 	iConst0;
	float 	fConst1;
	float 	fConst2;
	FAUSTFLOAT 	fentry1;
	float 	fConst3;
	float 	fConst4;
	float 	fConst5;
	float 	fConst6;
	float 	fConst7;
	float 	fConst8;
	float 	fConst9;
	float 	fConst10;
	float 	fConst11;
	float 	fConst12;
	float 	fConst13;
	float 	fConst14;
	float 	fConst15;
	float 	fConst16;
	float 	fConst17;
	float 	fConst18;
	float 	fConst19;
	float 	fConst20;
	float 	fConst21;
	float 	fConst22;
	float 	fConst23;
	float 	fConst24;
	float 	fConst25;
	float 	fConst26;
	float 	fConst27;
	float 	fConst28;
	float 	fConst29;
	float 	fConst30;
	float 	fConst31;
	float 	fConst32;
	float 	fConst33;
	float 	fConst34;
	float 	fConst35;
	float 	fConst36;
	float 	fConst37;
	float 	fConst38;
	float 	fConst39;
	float 	fConst40;
	float 	fConst41;
	float 	fConst42;
	float 	fConst43;
	float 	fConst44;
	float 	fConst45;
	float 	fConst46;
	float 	fConst47;
	float 	fConst48;
	float 	fConst49;
	float 	fConst50;
	float 	fConst51;
	float 	fConst52;
	float 	fConst53;
	float 	fConst54;
	float 	fConst55;
	float 	fConst56;
	float 	fConst57;
	float 	fConst58;
	float 	fConst59;
	float 	fConst60;
	float 	fConst61;
	float 	fConst62;
	float 	fConst63;
	float 	fConst64;
	float 	fConst65;
	float 	fConst66;
	float 	fConst67;
	float 	fConst68;
	float 	fConst69;
	float 	fConst70;
	float 	fConst71;
	float 	fConst72;
	float 	fConst73;
	float 	fConst74;
	float 	fConst75;
	float 	fConst76;
	float 	fConst77;
	float 	fConst78;
	float 	fConst79;
	float 	fConst80;
	float 	fConst81;
	float 	fConst82;
	float 	fConst83;
	float 	fConst84;
	float 	fConst85;
	float 	fConst86;
	float 	fConst87;
	float 	fConst88;
	float 	fConst89;
	float 	fConst90;
	float 	fConst91;
	FAUSTFLOAT 	fentry2;
	FAUSTFLOAT 	fentry3;
	float 	fYec1[1024];
	int 	fYec1_idx;
	int 	fYec1_idx_save;
	FAUSTFLOAT 	fentry4;
	float 	fConst92;
	FAUSTFLOAT 	fentry5;
	float 	fYec2[512];
	int 	fYec2_idx;
	int 	fYec2_idx_save;
	FAUSTFLOAT 	fentry6;
	float 	fYec3[512];
	int 	fYec3_idx;
	int 	fYec3_idx_save;
	float 	fYec4[1024];
	int 	fYec4_idx;
	int 	fYec4_idx_save;
	float 	fYec5[512];
	int 	fYec5_idx;
	int 	fYec5_idx_save;
  public:
	static void metadata(Meta* m) 	{ 
		m->declare("name", "Advanced Crossfeed");
		m->declare("id", "adv_xfeed");
		m->declare("author", "Radoslaw Szkodzinski");
		m->declare("email", "astralstorm@gmail.com");
		m->declare("version", "1.1");
		m->declare("filter.lib/name", "Faust Filter Library");
		m->declare("filter.lib/author", "Julius O. Smith (jos at ccrma.stanford.edu)");
		m->declare("filter.lib/copyright", "Julius O. Smith III");
		m->declare("filter.lib/version", "1.29");
		m->declare("filter.lib/license", "STK-4.3");
		m->declare("filter.lib/reference", "https://ccrma.stanford.edu/~jos/filters/");
		m->declare("music.lib/name", "Music Library");
		m->declare("music.lib/author", "GRAME");
		m->declare("music.lib/copyright", "GRAME");
		m->declare("music.lib/version", "1.0");
		m->declare("music.lib/license", "LGPL with exception");
		m->declare("math.lib/name", "Math Library");
		m->declare("math.lib/author", "GRAME");
		m->declare("math.lib/copyright", "GRAME");
		m->declare("math.lib/version", "1.0");
		m->declare("math.lib/license", "LGPL with exception");
	}

	virtual int getNumInputs() 	{ return 2; }
	virtual int getNumOutputs() 	{ return 2; }
	static void classInit(int samplingFreq) {
	}
	virtual void instanceInit(int samplingFreq) {
		fSamplingFreq = samplingFreq;
		for (int i=0; i<512; i++) fYec0[i]=0;
		fYec0_idx = 0;
		fYec0_idx_save = 0;
		fentry0 = 1.5e+03f;
		iConst0 = min(192000, max(1, fSamplingFreq));
		fConst1 = (2.0f / float(iConst0));
		fConst2 = (565.4866776461628f / float(iConst0));
		fentry1 = 0.75f;
		fConst3 = (559.2034923389832f / float(iConst0));
		fConst4 = (552.9203070318035f / float(iConst0));
		fConst5 = (546.637121724624f / float(iConst0));
		fConst6 = (540.3539364174444f / float(iConst0));
		fConst7 = (534.0707511102648f / float(iConst0));
		fConst8 = (527.7875658030853f / float(iConst0));
		fConst9 = (521.5043804959057f / float(iConst0));
		fConst10 = (515.221195188726f / float(iConst0));
		fConst11 = (508.93800988154646f / float(iConst0));
		fConst12 = (502.6548245743669f / float(iConst0));
		fConst13 = (496.37163926718733f / float(iConst0));
		fConst14 = (490.0884539600077f / float(iConst0));
		fConst15 = (483.80526865282815f / float(iConst0));
		fConst16 = (477.5220833456485f / float(iConst0));
		fConst17 = (471.23889803846896f / float(iConst0));
		fConst18 = (464.9557127312894f / float(iConst0));
		fConst19 = (458.6725274241098f / float(iConst0));
		fConst20 = (452.3893421169302f / float(iConst0));
		fConst21 = (446.10615680975064f / float(iConst0));
		fConst22 = (439.822971502571f / float(iConst0));
		fConst23 = (433.53978619539146f / float(iConst0));
		fConst24 = (427.2566008882119f / float(iConst0));
		fConst25 = (420.97341558103227f / float(iConst0));
		fConst26 = (414.6902302738527f / float(iConst0));
		fConst27 = (408.4070449666731f / float(iConst0));
		fConst28 = (402.1238596594935f / float(iConst0));
		fConst29 = (395.84067435231395f / float(iConst0));
		fConst30 = (389.55748904513433f / float(iConst0));
		fConst31 = (383.27430373795477f / float(iConst0));
		fConst32 = (376.99111843077515f / float(iConst0));
		fConst33 = (370.7079331235956f / float(iConst0));
		fConst34 = (364.424747816416f / float(iConst0));
		fConst35 = (358.1415625092364f / float(iConst0));
		fConst36 = (351.85837720205683f / float(iConst0));
		fConst37 = (345.57519189487726f / float(iConst0));
		fConst38 = (339.29200658769764f / float(iConst0));
		fConst39 = (333.0088212805181f / float(iConst0));
		fConst40 = (326.7256359733385f / float(iConst0));
		fConst41 = (320.4424506661589f / float(iConst0));
		fConst42 = (314.1592653589793f / float(iConst0));
		fConst43 = (307.8760800517997f / float(iConst0));
		fConst44 = (301.59289474462014f / float(iConst0));
		fConst45 = (295.3097094374406f / float(iConst0));
		fConst46 = (289.02652413026095f / float(iConst0));
		fConst47 = (282.7433388230814f / float(iConst0));
		fConst48 = (276.46015351590177f / float(iConst0));
		fConst49 = (270.1769682087222f / float(iConst0));
		fConst50 = (263.89378290154264f / float(iConst0));
		fConst51 = (257.610597594363f / float(iConst0));
		fConst52 = (251.32741228718345f / float(iConst0));
		fConst53 = (245.04422698000386f / float(iConst0));
		fConst54 = (238.76104167282426f / float(iConst0));
		fConst55 = (232.4778563656447f / float(iConst0));
		fConst56 = (226.1946710584651f / float(iConst0));
		fConst57 = (219.9114857512855f / float(iConst0));
		fConst58 = (213.62830044410595f / float(iConst0));
		fConst59 = (207.34511513692635f / float(iConst0));
		fConst60 = (201.06192982974676f / float(iConst0));
		fConst61 = (194.77874452256717f / float(iConst0));
		fConst62 = (188.49555921538757f / float(iConst0));
		fConst63 = (182.212373908208f / float(iConst0));
		fConst64 = (175.92918860102841f / float(iConst0));
		fConst65 = (169.64600329384882f / float(iConst0));
		fConst66 = (163.36281798666926f / float(iConst0));
		fConst67 = (157.07963267948966f / float(iConst0));
		fConst68 = (150.79644737231007f / float(iConst0));
		fConst69 = (144.51326206513048f / float(iConst0));
		fConst70 = (138.23007675795088f / float(iConst0));
		fConst71 = (131.94689145077132f / float(iConst0));
		fConst72 = (125.66370614359172f / float(iConst0));
		fConst73 = (119.38052083641213f / float(iConst0));
		fConst74 = (113.09733552923255f / float(iConst0));
		fConst75 = (106.81415022205297f / float(iConst0));
		fConst76 = (100.53096491487338f / float(iConst0));
		fConst77 = (94.24777960769379f / float(iConst0));
		fConst78 = (87.96459430051421f / float(iConst0));
		fConst79 = (81.68140899333463f / float(iConst0));
		fConst80 = (75.39822368615503f / float(iConst0));
		fConst81 = (69.11503837897544f / float(iConst0));
		fConst82 = (62.83185307179586f / float(iConst0));
		fConst83 = (56.548667764616276f / float(iConst0));
		fConst84 = (50.26548245743669f / float(iConst0));
		fConst85 = (43.982297150257104f / float(iConst0));
		fConst86 = (37.69911184307752f / float(iConst0));
		fConst87 = (31.41592653589793f / float(iConst0));
		fConst88 = (25.132741228718345f / float(iConst0));
		fConst89 = (18.84955592153876f / float(iConst0));
		fConst90 = (12.566370614359172f / float(iConst0));
		fConst91 = (6.283185307179586f / float(iConst0));
		fentry2 = -3.0f;
		fentry3 = -9.0f;
		for (int i=0; i<1024; i++) fYec1[i]=0;
		fYec1_idx = 0;
		fYec1_idx_save = 0;
		fentry4 = 37.0f;
		fConst92 = (1e-06f * iConst0);
		fentry5 = 4e+01f;
		for (int i=0; i<512; i++) fYec2[i]=0;
		fYec2_idx = 0;
		fYec2_idx_save = 0;
		fentry6 = -3.0f;
		for (int i=0; i<512; i++) fYec3[i]=0;
		fYec3_idx = 0;
		fYec3_idx_save = 0;
		for (int i=0; i<1024; i++) fYec4[i]=0;
		fYec4_idx = 0;
		fYec4_idx_save = 0;
		for (int i=0; i<512; i++) fYec5[i]=0;
		fYec5_idx = 0;
		fYec5_idx_save = 0;
	}
	virtual void init(int samplingFreq) {
		classInit(samplingFreq);
		instanceInit(samplingFreq);
	}
	virtual void buildUserInterface(UI* interface) {
		interface->openVerticalBox("adv_xfeed_v2");
		interface->declare(&fentry5, "unit", "%%");
		interface->addNumEntry("Center control (percent)", &fentry5, 4e+01f, 0.0f, 1e+02f, 0.1f);
		interface->declare(&fentry0, "unit", "Hz");
		interface->addNumEntry("Corner frequency (Hz)", &fentry0, 1.5e+03f, 1.5e+02f, 6e+03f, 1e+01f);
		interface->addNumEntry("Filter steepness", &fentry1, 0.75f, 0.01f, 6.0f, 0.01f);
		interface->declare(&fentry6, "unit", "dB");
		interface->addNumEntry("Gain (dB)", &fentry6, -3.0f, -24.0f, 0.0f, 0.1f);
		interface->declare(&fentry3, "unit", "dB");
		interface->addNumEntry("HF feed level (dB)", &fentry3, -9.0f, -48.0f, 0.0f, 0.1f);
		interface->declare(&fentry4, "unit", "us");
		interface->addNumEntry("Inter-aural time delay (us)", &fentry4, 37.0f, 0.0f, 7.5e+02f, 1.0f);
		interface->declare(&fentry2, "unit", "dB");
		interface->addNumEntry("LF feed level (dB)", &fentry2, -3.0f, -48.0f, 0.0f, 0.1f);
		interface->closeBox();
	}
	virtual void compute (int fullcount, FAUSTFLOAT** input, FAUSTFLOAT** output) {
		float 	fZec0[256];
		float 	fSlow0 = float(fentry0);
		float 	fSlow1 = (fConst1 * fSlow0);
		float 	fSlow2 = (0.0035367765131532297f * sinf((0 - (fConst2 * fSlow0))));
		float 	fSlow3 = float(fentry1);
		float 	fSlow4 = (3.141592653589793f * fSlow3);
		float 	fSlow5 = faustpower<2>(fSlow4);
		float 	fSlow6 = (1 + (fSlow5 * ((((((((((((((0.25f + (0.0625f * fSlow5)) + (0.006944444444444444f * faustpower<4>(fSlow4))) + (0.00043402777777777775f * faustpower<6>(fSlow4))) + (1.736111111111111e-05f * faustpower<8>(fSlow4))) + (4.822530864197531e-07f * faustpower<10>(fSlow4))) + (9.841899722852104e-09f * faustpower<12>(fSlow4))) + (1.5377968316956413e-10f * faustpower<14>(fSlow4))) + (1.898514607031656e-12f * faustpower<16>(fSlow4))) + (1.898514607031656e-14f * faustpower<18>(fSlow4))) + (1.5690203363897983e-16f * faustpower<20>(fSlow4))) + (1.0895974558262487e-18f * faustpower<22>(fSlow4))) + (6.697330183385451e-20f * faustpower<24>(fSlow4))) + (1.5283966662112614e-19f * faustpower<26>(fSlow4))) + (6.223149226587858e-20f * faustpower<28>(fSlow4)))));
		float 	fSlow7 = min(1.0f, (1.0f / fSlow6));
		float 	fSlow8 = (fSlow7 * min(fSlow1, (0 - fSlow2)));
		float 	fSlow9 = (fConst3 * fSlow0);
		float 	fSlow10 = (0.0035765155750987717f * sinf((0 - fSlow9)));
		float 	fSlow11 = (0.4670182786222422f * fSlow3);
		float 	fSlow12 = faustpower<2>(fSlow11);
		float 	fSlow13 = min(1.0f, ((1 + (fSlow12 * ((((((((((((((0.25f + (0.0625f * fSlow12)) + (0.006944444444444444f * faustpower<4>(fSlow11))) + (0.00043402777777777775f * faustpower<6>(fSlow11))) + (1.736111111111111e-05f * faustpower<8>(fSlow11))) + (4.822530864197531e-07f * faustpower<10>(fSlow11))) + (9.841899722852104e-09f * faustpower<12>(fSlow11))) + (1.5377968316956413e-10f * faustpower<14>(fSlow11))) + (1.898514607031656e-12f * faustpower<16>(fSlow11))) + (1.898514607031656e-14f * faustpower<18>(fSlow11))) + (1.5690203363897983e-16f * faustpower<20>(fSlow11))) + (1.0895974558262487e-18f * faustpower<22>(fSlow11))) + (6.697330183385451e-20f * faustpower<24>(fSlow11))) + (1.5283966662112614e-19f * faustpower<26>(fSlow11))) + (6.223149226587858e-20f * faustpower<28>(fSlow11))))) / fSlow6));
		float 	fSlow14 = (fSlow13 * min(fSlow1, (0 - fSlow10)));
		float 	fSlow15 = (fConst4 * fSlow0);
		float 	fSlow16 = (0.0036171577975430765f * sinf((0 - fSlow15)));
		float 	fSlow17 = (0.6586161293016393f * fSlow3);
		float 	fSlow18 = faustpower<2>(fSlow17);
		float 	fSlow19 = min(1.0f, ((1 + (fSlow18 * ((((((((((((((0.25f + (0.0625f * fSlow18)) + (0.006944444444444444f * faustpower<4>(fSlow17))) + (0.00043402777777777775f * faustpower<6>(fSlow17))) + (1.736111111111111e-05f * faustpower<8>(fSlow17))) + (4.822530864197531e-07f * faustpower<10>(fSlow17))) + (9.841899722852104e-09f * faustpower<12>(fSlow17))) + (1.5377968316956413e-10f * faustpower<14>(fSlow17))) + (1.898514607031656e-12f * faustpower<16>(fSlow17))) + (1.898514607031656e-14f * faustpower<18>(fSlow17))) + (1.5690203363897983e-16f * faustpower<20>(fSlow17))) + (1.0895974558262487e-18f * faustpower<22>(fSlow17))) + (6.697330183385451e-20f * faustpower<24>(fSlow17))) + (1.5283966662112614e-19f * faustpower<26>(fSlow17))) + (6.223149226587858e-20f * faustpower<28>(fSlow17))))) / fSlow6));
		float 	fSlow20 = (fSlow19 * min(fSlow1, (0 - fSlow16)));
		float 	fSlow21 = (fConst5 * fSlow0);
		float 	fSlow22 = (0.003658734323951617f * sinf((0 - fSlow21)));
		float 	fSlow23 = (0.8043677017552168f * fSlow3);
		float 	fSlow24 = faustpower<2>(fSlow23);
		float 	fSlow25 = min(1.0f, ((1 + (fSlow24 * ((((((((((((((0.25f + (0.0625f * fSlow24)) + (0.006944444444444444f * faustpower<4>(fSlow23))) + (0.00043402777777777775f * faustpower<6>(fSlow23))) + (1.736111111111111e-05f * faustpower<8>(fSlow23))) + (4.822530864197531e-07f * faustpower<10>(fSlow23))) + (9.841899722852104e-09f * faustpower<12>(fSlow23))) + (1.5377968316956413e-10f * faustpower<14>(fSlow23))) + (1.898514607031656e-12f * faustpower<16>(fSlow23))) + (1.898514607031656e-14f * faustpower<18>(fSlow23))) + (1.5690203363897983e-16f * faustpower<20>(fSlow23))) + (1.0895974558262487e-18f * faustpower<22>(fSlow23))) + (6.697330183385451e-20f * faustpower<24>(fSlow23))) + (1.5283966662112614e-19f * faustpower<26>(fSlow23))) + (6.223149226587858e-20f * faustpower<28>(fSlow23))))) / fSlow6));
		float 	fSlow26 = (fSlow25 * min(fSlow1, (0 - fSlow22)));
		float 	fSlow27 = (fConst6 * fSlow0);
		float 	fSlow28 = (0.0037012777463231476f * sinf((0 - fSlow27)));
		float 	fSlow29 = (0.9261763623194942f * fSlow3);
		float 	fSlow30 = faustpower<2>(fSlow29);
		float 	fSlow31 = min(1.0f, ((1 + (fSlow30 * ((((((((((((((0.25f + (0.0625f * fSlow30)) + (0.006944444444444444f * faustpower<4>(fSlow29))) + (0.00043402777777777775f * faustpower<6>(fSlow29))) + (1.736111111111111e-05f * faustpower<8>(fSlow29))) + (4.822530864197531e-07f * faustpower<10>(fSlow29))) + (9.841899722852104e-09f * faustpower<12>(fSlow29))) + (1.5377968316956413e-10f * faustpower<14>(fSlow29))) + (1.898514607031656e-12f * faustpower<16>(fSlow29))) + (1.898514607031656e-14f * faustpower<18>(fSlow29))) + (1.5690203363897983e-16f * faustpower<20>(fSlow29))) + (1.0895974558262487e-18f * faustpower<22>(fSlow29))) + (6.697330183385451e-20f * faustpower<24>(fSlow29))) + (1.5283966662112614e-19f * faustpower<26>(fSlow29))) + (6.223149226587858e-20f * faustpower<28>(fSlow29))))) / fSlow6));
		float 	fSlow32 = (fSlow31 * min(fSlow1, (0 - fSlow28)));
		float 	fSlow33 = (fConst7 * fSlow0);
		float 	fSlow34 = (0.0037448221903975372f * sinf((0 - fSlow33)));
		float 	fSlow35 = (1.032550710257603f * fSlow3);
		float 	fSlow36 = faustpower<2>(fSlow35);
		float 	fSlow37 = min(1.0f, ((1 + (fSlow36 * ((((((((((((((0.25f + (0.0625f * fSlow36)) + (0.006944444444444444f * faustpower<4>(fSlow35))) + (0.00043402777777777775f * faustpower<6>(fSlow35))) + (1.736111111111111e-05f * faustpower<8>(fSlow35))) + (4.822530864197531e-07f * faustpower<10>(fSlow35))) + (9.841899722852104e-09f * faustpower<12>(fSlow35))) + (1.5377968316956413e-10f * faustpower<14>(fSlow35))) + (1.898514607031656e-12f * faustpower<16>(fSlow35))) + (1.898514607031656e-14f * faustpower<18>(fSlow35))) + (1.5690203363897983e-16f * faustpower<20>(fSlow35))) + (1.0895974558262487e-18f * faustpower<22>(fSlow35))) + (6.697330183385451e-20f * faustpower<24>(fSlow35))) + (1.5283966662112614e-19f * faustpower<26>(fSlow35))) + (6.223149226587858e-20f * faustpower<28>(fSlow35))))) / fSlow6));
		float 	fSlow38 = (fSlow37 * min(fSlow1, (0 - fSlow34)));
		float 	fSlow39 = (fConst8 * fSlow0);
		float 	fSlow40 = (0.003789403406949889f * sinf((0 - fSlow39)));
		float 	fSlow41 = (1.12786627976427f * fSlow3);
		float 	fSlow42 = faustpower<2>(fSlow41);
		float 	fSlow43 = min(1.0f, ((1 + (fSlow42 * ((((((((((((((0.25f + (0.0625f * fSlow42)) + (0.006944444444444444f * faustpower<4>(fSlow41))) + (0.00043402777777777775f * faustpower<6>(fSlow41))) + (1.736111111111111e-05f * faustpower<8>(fSlow41))) + (4.822530864197531e-07f * faustpower<10>(fSlow41))) + (9.841899722852104e-09f * faustpower<12>(fSlow41))) + (1.5377968316956413e-10f * faustpower<14>(fSlow41))) + (1.898514607031656e-12f * faustpower<16>(fSlow41))) + (1.898514607031656e-14f * faustpower<18>(fSlow41))) + (1.5690203363897983e-16f * faustpower<20>(fSlow41))) + (1.0895974558262487e-18f * faustpower<22>(fSlow41))) + (6.697330183385451e-20f * faustpower<24>(fSlow41))) + (1.5283966662112614e-19f * faustpower<26>(fSlow41))) + (6.223149226587858e-20f * faustpower<28>(fSlow41))))) / fSlow6));
		float 	fSlow44 = (fSlow43 * min(fSlow1, (0 - fSlow40)));
		float 	fSlow45 = (fConst9 * fSlow0);
		float 	fSlow46 = (0.003835058869684225f * sinf((0 - fSlow45)));
		float 	fSlow47 = (1.214729097966627f * fSlow3);
		float 	fSlow48 = faustpower<2>(fSlow47);
		float 	fSlow49 = min(1.0f, ((1 + (fSlow48 * ((((((((((((((0.25f + (0.0625f * fSlow48)) + (0.006944444444444444f * faustpower<4>(fSlow47))) + (0.00043402777777777775f * faustpower<6>(fSlow47))) + (1.736111111111111e-05f * faustpower<8>(fSlow47))) + (4.822530864197531e-07f * faustpower<10>(fSlow47))) + (9.841899722852104e-09f * faustpower<12>(fSlow47))) + (1.5377968316956413e-10f * faustpower<14>(fSlow47))) + (1.898514607031656e-12f * faustpower<16>(fSlow47))) + (1.898514607031656e-14f * faustpower<18>(fSlow47))) + (1.5690203363897983e-16f * faustpower<20>(fSlow47))) + (1.0895974558262487e-18f * faustpower<22>(fSlow47))) + (6.697330183385451e-20f * faustpower<24>(fSlow47))) + (1.5283966662112614e-19f * faustpower<26>(fSlow47))) + (6.223149226587858e-20f * faustpower<28>(fSlow47))))) / fSlow6));
		float 	fSlow50 = (fSlow49 * min(fSlow1, (0 - fSlow46)));
		float 	fSlow51 = (fConst10 * fSlow0);
		float 	fSlow52 = (0.0038818278802901307f * sinf((0 - fSlow51)));
		float 	fSlow53 = (1.2948414105619437f * fSlow3);
		float 	fSlow54 = faustpower<2>(fSlow53);
		float 	fSlow55 = min(1.0f, ((1 + (fSlow54 * ((((((((((((((0.25f + (0.0625f * fSlow54)) + (0.006944444444444444f * faustpower<4>(fSlow53))) + (0.00043402777777777775f * faustpower<6>(fSlow53))) + (1.736111111111111e-05f * faustpower<8>(fSlow53))) + (4.822530864197531e-07f * faustpower<10>(fSlow53))) + (9.841899722852104e-09f * faustpower<12>(fSlow53))) + (1.5377968316956413e-10f * faustpower<14>(fSlow53))) + (1.898514607031656e-12f * faustpower<16>(fSlow53))) + (1.898514607031656e-14f * faustpower<18>(fSlow53))) + (1.5690203363897983e-16f * faustpower<20>(fSlow53))) + (1.0895974558262487e-18f * faustpower<22>(fSlow53))) + (6.697330183385451e-20f * faustpower<24>(fSlow53))) + (1.5283966662112614e-19f * faustpower<26>(fSlow53))) + (6.223149226587858e-20f * faustpower<28>(fSlow53))))) / fSlow6));
		float 	fSlow56 = (fSlow55 * min(fSlow1, (0 - fSlow52)));
		float 	fSlow57 = (fConst11 * fSlow0);
		float 	fSlow58 = (0.003929751681281367f * sinf((0 - fSlow57)));
		float 	fSlow59 = (1.3693884898767688f * fSlow3);
		float 	fSlow60 = faustpower<2>(fSlow59);
		float 	fSlow61 = min(1.0f, ((1 + (fSlow60 * ((((((((((((((0.25f + (0.0625f * fSlow60)) + (0.006944444444444444f * faustpower<4>(fSlow59))) + (0.00043402777777777775f * faustpower<6>(fSlow59))) + (1.736111111111111e-05f * faustpower<8>(fSlow59))) + (4.822530864197531e-07f * faustpower<10>(fSlow59))) + (9.841899722852104e-09f * faustpower<12>(fSlow59))) + (1.5377968316956413e-10f * faustpower<14>(fSlow59))) + (1.898514607031656e-12f * faustpower<16>(fSlow59))) + (1.898514607031656e-14f * faustpower<18>(fSlow59))) + (1.5690203363897983e-16f * faustpower<20>(fSlow59))) + (1.0895974558262487e-18f * faustpower<22>(fSlow59))) + (6.697330183385451e-20f * faustpower<24>(fSlow59))) + (1.5283966662112614e-19f * faustpower<26>(fSlow59))) + (6.223149226587858e-20f * faustpower<28>(fSlow59))))) / fSlow6));
		float 	fSlow62 = (fSlow61 * min(fSlow1, (0 - fSlow58)));
		float 	fSlow63 = (fConst12 * fSlow0);
		float 	fSlow64 = (0.0039788735772973835f * sinf((0 - fSlow63)));
		float 	fSlow65 = (1.4392353714905768f * fSlow3);
		float 	fSlow66 = faustpower<2>(fSlow65);
		float 	fSlow67 = min(1.0f, ((1 + (fSlow66 * ((((((((((((((0.25f + (0.0625f * fSlow66)) + (0.006944444444444444f * faustpower<4>(fSlow65))) + (0.00043402777777777775f * faustpower<6>(fSlow65))) + (1.736111111111111e-05f * faustpower<8>(fSlow65))) + (4.822530864197531e-07f * faustpower<10>(fSlow65))) + (9.841899722852104e-09f * faustpower<12>(fSlow65))) + (1.5377968316956413e-10f * faustpower<14>(fSlow65))) + (1.898514607031656e-12f * faustpower<16>(fSlow65))) + (1.898514607031656e-14f * faustpower<18>(fSlow65))) + (1.5690203363897983e-16f * faustpower<20>(fSlow65))) + (1.0895974558262487e-18f * faustpower<22>(fSlow65))) + (6.697330183385451e-20f * faustpower<24>(fSlow65))) + (1.5283966662112614e-19f * faustpower<26>(fSlow65))) + (6.223149226587858e-20f * faustpower<28>(fSlow65))))) / fSlow6));
		float 	fSlow68 = (fSlow67 * min(fSlow1, (0 - fSlow64)));
		float 	fSlow69 = (fConst13 * fSlow0);
		float 	fSlow70 = (0.004029239065617604f * sinf((0 - fSlow69)));
		float 	fSlow71 = (1.5050365887691783f * fSlow3);
		float 	fSlow72 = faustpower<2>(fSlow71);
		float 	fSlow73 = min(1.0f, ((1 + (fSlow72 * ((((((((((((((0.25f + (0.0625f * fSlow72)) + (0.006944444444444444f * faustpower<4>(fSlow71))) + (0.00043402777777777775f * faustpower<6>(fSlow71))) + (1.736111111111111e-05f * faustpower<8>(fSlow71))) + (4.822530864197531e-07f * faustpower<10>(fSlow71))) + (9.841899722852104e-09f * faustpower<12>(fSlow71))) + (1.5377968316956413e-10f * faustpower<14>(fSlow71))) + (1.898514607031656e-12f * faustpower<16>(fSlow71))) + (1.898514607031656e-14f * faustpower<18>(fSlow71))) + (1.5690203363897983e-16f * faustpower<20>(fSlow71))) + (1.0895974558262487e-18f * faustpower<22>(fSlow71))) + (6.697330183385451e-20f * faustpower<24>(fSlow71))) + (1.5283966662112614e-19f * faustpower<26>(fSlow71))) + (6.223149226587858e-20f * faustpower<28>(fSlow71))))) / fSlow6));
		float 	fSlow74 = (fSlow73 * min(fSlow1, (0 - fSlow70)));
		float 	fSlow75 = (fConst14 * fSlow0);
		float 	fSlow76 = (0.004080895976715265f * sinf((0 - fSlow75)));
		float 	fSlow77 = (1.5673017811385328f * fSlow3);
		float 	fSlow78 = faustpower<2>(fSlow77);
		float 	fSlow79 = min(1.0f, ((1 + (fSlow78 * ((((((((((((((0.25f + (0.0625f * fSlow78)) + (0.006944444444444444f * faustpower<4>(fSlow77))) + (0.00043402777777777775f * faustpower<6>(fSlow77))) + (1.736111111111111e-05f * faustpower<8>(fSlow77))) + (4.822530864197531e-07f * faustpower<10>(fSlow77))) + (9.841899722852104e-09f * faustpower<12>(fSlow77))) + (1.5377968316956413e-10f * faustpower<14>(fSlow77))) + (1.898514607031656e-12f * faustpower<16>(fSlow77))) + (1.898514607031656e-14f * faustpower<18>(fSlow77))) + (1.5690203363897983e-16f * faustpower<20>(fSlow77))) + (1.0895974558262487e-18f * faustpower<22>(fSlow77))) + (6.697330183385451e-20f * faustpower<24>(fSlow77))) + (1.5283966662112614e-19f * faustpower<26>(fSlow77))) + (6.223149226587858e-20f * faustpower<28>(fSlow77))))) / fSlow6));
		float 	fSlow80 = (fSlow79 * min(fSlow1, (0 - fSlow76)));
		float 	fSlow81 = (fConst15 * fSlow0);
		float 	fSlow82 = (0.004133894625763516f * sinf((0 - fSlow81)));
		float 	fSlow83 = (1.626437110197556f * fSlow3);
		float 	fSlow84 = faustpower<2>(fSlow83);
		float 	fSlow85 = min(1.0f, ((1 + (fSlow84 * ((((((((((((((0.25f + (0.0625f * fSlow84)) + (0.006944444444444444f * faustpower<4>(fSlow83))) + (0.00043402777777777775f * faustpower<6>(fSlow83))) + (1.736111111111111e-05f * faustpower<8>(fSlow83))) + (4.822530864197531e-07f * faustpower<10>(fSlow83))) + (9.841899722852104e-09f * faustpower<12>(fSlow83))) + (1.5377968316956413e-10f * faustpower<14>(fSlow83))) + (1.898514607031656e-12f * faustpower<16>(fSlow83))) + (1.898514607031656e-14f * faustpower<18>(fSlow83))) + (1.5690203363897983e-16f * faustpower<20>(fSlow83))) + (1.0895974558262487e-18f * faustpower<22>(fSlow83))) + (6.697330183385451e-20f * faustpower<24>(fSlow83))) + (1.5283966662112614e-19f * faustpower<26>(fSlow83))) + (6.223149226587858e-20f * faustpower<28>(fSlow83))))) / fSlow6));
		float 	fSlow86 = (fSlow85 * min(fSlow1, (0 - fSlow82)));
		float 	fSlow87 = (fConst16 * fSlow0);
		float 	fSlow88 = (0.004188287976102509f * sinf((0 - fSlow87)));
		float 	fSlow89 = (1.6827725735634163f * fSlow3);
		float 	fSlow90 = faustpower<2>(fSlow89);
		float 	fSlow91 = min(1.0f, ((1 + (fSlow90 * ((((((((((((((0.25f + (0.0625f * fSlow90)) + (0.006944444444444444f * faustpower<4>(fSlow89))) + (0.00043402777777777775f * faustpower<6>(fSlow89))) + (1.736111111111111e-05f * faustpower<8>(fSlow89))) + (4.822530864197531e-07f * faustpower<10>(fSlow89))) + (9.841899722852104e-09f * faustpower<12>(fSlow89))) + (1.5377968316956413e-10f * faustpower<14>(fSlow89))) + (1.898514607031656e-12f * faustpower<16>(fSlow89))) + (1.898514607031656e-14f * faustpower<18>(fSlow89))) + (1.5690203363897983e-16f * faustpower<20>(fSlow89))) + (1.0895974558262487e-18f * faustpower<22>(fSlow89))) + (6.697330183385451e-20f * faustpower<24>(fSlow89))) + (1.5283966662112614e-19f * faustpower<26>(fSlow89))) + (6.223149226587858e-20f * faustpower<28>(fSlow89))))) / fSlow6));
		float 	fSlow92 = (fSlow91 * min(fSlow1, (0 - fSlow88)));
		float 	fSlow93 = (fConst17 * fSlow0);
		float 	fSlow94 = (0.004244131815783876f * sinf((0 - fSlow93)));
		float 	fSlow95 = (1.736580679349052f * fSlow3);
		float 	fSlow96 = faustpower<2>(fSlow95);
		float 	fSlow97 = min(1.0f, ((1 + (fSlow96 * ((((((((((((((0.25f + (0.0625f * fSlow96)) + (0.006944444444444444f * faustpower<4>(fSlow95))) + (0.00043402777777777775f * faustpower<6>(fSlow95))) + (1.736111111111111e-05f * faustpower<8>(fSlow95))) + (4.822530864197531e-07f * faustpower<10>(fSlow95))) + (9.841899722852104e-09f * faustpower<12>(fSlow95))) + (1.5377968316956413e-10f * faustpower<14>(fSlow95))) + (1.898514607031656e-12f * faustpower<16>(fSlow95))) + (1.898514607031656e-14f * faustpower<18>(fSlow95))) + (1.5690203363897983e-16f * faustpower<20>(fSlow95))) + (1.0895974558262487e-18f * faustpower<22>(fSlow95))) + (6.697330183385451e-20f * faustpower<24>(fSlow95))) + (1.5283966662112614e-19f * faustpower<26>(fSlow95))) + (6.223149226587858e-20f * faustpower<28>(fSlow95))))) / fSlow6));
		float 	fSlow98 = (fSlow97 * min(fSlow1, (0 - fSlow94)));
		float 	fSlow99 = (fConst18 * fSlow0);
		float 	fSlow100 = (0.0043014849484296035f * sinf((0 - fSlow99)));
		float 	fSlow101 = (1.78808960571927f * fSlow3);
		float 	fSlow102 = faustpower<2>(fSlow101);
		float 	fSlow103 = min(1.0f, ((1 + (fSlow102 * ((((((((((((((0.25f + (0.0625f * fSlow102)) + (0.006944444444444444f * faustpower<4>(fSlow101))) + (0.00043402777777777775f * faustpower<6>(fSlow101))) + (1.736111111111111e-05f * faustpower<8>(fSlow101))) + (4.822530864197531e-07f * faustpower<10>(fSlow101))) + (9.841899722852104e-09f * faustpower<12>(fSlow101))) + (1.5377968316956413e-10f * faustpower<14>(fSlow101))) + (1.898514607031656e-12f * faustpower<16>(fSlow101))) + (1.898514607031656e-14f * faustpower<18>(fSlow101))) + (1.5690203363897983e-16f * faustpower<20>(fSlow101))) + (1.0895974558262487e-18f * faustpower<22>(fSlow101))) + (6.697330183385451e-20f * faustpower<24>(fSlow101))) + (1.5283966662112614e-19f * faustpower<26>(fSlow101))) + (6.223149226587858e-20f * faustpower<28>(fSlow101))))) / fSlow6));
		float 	fSlow104 = (fSlow103 * min(fSlow1, (0 - fSlow100)));
		float 	fSlow105 = (fConst19 * fSlow0);
		float 	fSlow106 = (0.004360409399777955f * sinf((0 - fSlow105)));
		float 	fSlow107 = (1.8374927158810392f * fSlow3);
		float 	fSlow108 = faustpower<2>(fSlow107);
		float 	fSlow109 = min(1.0f, ((1 + (fSlow108 * ((((((((((((((0.25f + (0.0625f * fSlow108)) + (0.006944444444444444f * faustpower<4>(fSlow107))) + (0.00043402777777777775f * faustpower<6>(fSlow107))) + (1.736111111111111e-05f * faustpower<8>(fSlow107))) + (4.822530864197531e-07f * faustpower<10>(fSlow107))) + (9.841899722852104e-09f * faustpower<12>(fSlow107))) + (1.5377968316956413e-10f * faustpower<14>(fSlow107))) + (1.898514607031656e-12f * faustpower<16>(fSlow107))) + (1.898514607031656e-14f * faustpower<18>(fSlow107))) + (1.5690203363897983e-16f * faustpower<20>(fSlow107))) + (1.0895974558262487e-18f * faustpower<22>(fSlow107))) + (6.697330183385451e-20f * faustpower<24>(fSlow107))) + (1.5283966662112614e-19f * faustpower<26>(fSlow107))) + (6.223149226587858e-20f * faustpower<28>(fSlow107))))) / fSlow6));
		float 	fSlow110 = (fSlow109 * min(fSlow1, (0 - fSlow106)));
		float 	fSlow111 = (fConst20 * fSlow0);
		float 	fSlow112 = (0.004420970641441538f * sinf((0 - fSlow111)));
		float 	fSlow113 = (1.8849555921538754f * fSlow3);
		float 	fSlow114 = faustpower<2>(fSlow113);
		float 	fSlow115 = min(1.0f, ((1 + (fSlow114 * ((((((((((((((0.25f + (0.0625f * fSlow114)) + (0.006944444444444444f * faustpower<4>(fSlow113))) + (0.00043402777777777775f * faustpower<6>(fSlow113))) + (1.736111111111111e-05f * faustpower<8>(fSlow113))) + (4.822530864197531e-07f * faustpower<10>(fSlow113))) + (9.841899722852104e-09f * faustpower<12>(fSlow113))) + (1.5377968316956413e-10f * faustpower<14>(fSlow113))) + (1.898514607031656e-12f * faustpower<16>(fSlow113))) + (1.898514607031656e-14f * faustpower<18>(fSlow113))) + (1.5690203363897983e-16f * faustpower<20>(fSlow113))) + (1.0895974558262487e-18f * faustpower<22>(fSlow113))) + (6.697330183385451e-20f * faustpower<24>(fSlow113))) + (1.5283966662112614e-19f * faustpower<26>(fSlow113))) + (6.223149226587858e-20f * faustpower<28>(fSlow113))))) / fSlow6));
		float 	fSlow116 = (fSlow115 * min(fSlow1, (0 - fSlow112)));
		float 	fSlow117 = (fConst21 * fSlow0);
		float 	fSlow118 = (0.004483237833574517f * sinf((0 - fSlow117)));
		float 	fSlow119 = (1.9306213374222734f * fSlow3);
		float 	fSlow120 = faustpower<2>(fSlow119);
		float 	fSlow121 = min(1.0f, ((1 + (fSlow120 * ((((((((((((((0.25f + (0.0625f * fSlow120)) + (0.006944444444444444f * faustpower<4>(fSlow119))) + (0.00043402777777777775f * faustpower<6>(fSlow119))) + (1.736111111111111e-05f * faustpower<8>(fSlow119))) + (4.822530864197531e-07f * faustpower<10>(fSlow119))) + (9.841899722852104e-09f * faustpower<12>(fSlow119))) + (1.5377968316956413e-10f * faustpower<14>(fSlow119))) + (1.898514607031656e-12f * faustpower<16>(fSlow119))) + (1.898514607031656e-14f * faustpower<18>(fSlow119))) + (1.5690203363897983e-16f * faustpower<20>(fSlow119))) + (1.0895974558262487e-18f * faustpower<22>(fSlow119))) + (6.697330183385451e-20f * faustpower<24>(fSlow119))) + (1.5283966662112614e-19f * faustpower<26>(fSlow119))) + (6.223149226587858e-20f * faustpower<28>(fSlow119))))) / fSlow6));
		float 	fSlow122 = (fSlow121 * min(fSlow1, (0 - fSlow118)));
		float 	fSlow123 = (fConst22 * fSlow0);
		float 	fSlow124 = (0.004547284088339867f * sinf((0 - fSlow123)));
		float 	fSlow125 = (1.9746146391814958f * fSlow3);
		float 	fSlow126 = faustpower<2>(fSlow125);
		float 	fSlow127 = min(1.0f, ((1 + (fSlow126 * ((((((((((((((0.25f + (0.0625f * fSlow126)) + (0.006944444444444444f * faustpower<4>(fSlow125))) + (0.00043402777777777775f * faustpower<6>(fSlow125))) + (1.736111111111111e-05f * faustpower<8>(fSlow125))) + (4.822530864197531e-07f * faustpower<10>(fSlow125))) + (9.841899722852104e-09f * faustpower<12>(fSlow125))) + (1.5377968316956413e-10f * faustpower<14>(fSlow125))) + (1.898514607031656e-12f * faustpower<16>(fSlow125))) + (1.898514607031656e-14f * faustpower<18>(fSlow125))) + (1.5690203363897983e-16f * faustpower<20>(fSlow125))) + (1.0895974558262487e-18f * faustpower<22>(fSlow125))) + (6.697330183385451e-20f * faustpower<24>(fSlow125))) + (1.5283966662112614e-19f * faustpower<26>(fSlow125))) + (6.223149226587858e-20f * faustpower<28>(fSlow125))))) / fSlow6));
		float 	fSlow128 = (fSlow127 * min(fSlow1, (0 - fSlow124)));
		float 	fSlow129 = (fConst23 * fSlow0);
		float 	fSlow130 = (0.004613186756286821f * sinf((0 - fSlow129)));
		float 	fSlow131 = (2.0170449322390613f * fSlow3);
		float 	fSlow132 = faustpower<2>(fSlow131);
		float 	fSlow133 = min(1.0f, ((1 + (fSlow132 * ((((((((((((((0.25f + (0.0625f * fSlow132)) + (0.006944444444444444f * faustpower<4>(fSlow131))) + (0.00043402777777777775f * faustpower<6>(fSlow131))) + (1.736111111111111e-05f * faustpower<8>(fSlow131))) + (4.822530864197531e-07f * faustpower<10>(fSlow131))) + (9.841899722852104e-09f * faustpower<12>(fSlow131))) + (1.5377968316956413e-10f * faustpower<14>(fSlow131))) + (1.898514607031656e-12f * faustpower<16>(fSlow131))) + (1.898514607031656e-14f * faustpower<18>(fSlow131))) + (1.5690203363897983e-16f * faustpower<20>(fSlow131))) + (1.0895974558262487e-18f * faustpower<22>(fSlow131))) + (6.697330183385451e-20f * faustpower<24>(fSlow131))) + (1.5283966662112614e-19f * faustpower<26>(fSlow131))) + (6.223149226587858e-20f * faustpower<28>(fSlow131))))) / fSlow6));
		float 	fSlow134 = (fSlow133 * min(fSlow1, (0 - fSlow130)));
		float 	fSlow135 = (fConst24 * fSlow0);
		float 	fSlow136 = (0.004681027737996921f * sinf((0 - fSlow135)));
		float 	fSlow137 = (2.0580088932544474f * fSlow3);
		float 	fSlow138 = faustpower<2>(fSlow137);
		float 	fSlow139 = min(1.0f, ((1 + (fSlow138 * ((((((((((((((0.25f + (0.0625f * fSlow138)) + (0.006944444444444444f * faustpower<4>(fSlow137))) + (0.00043402777777777775f * faustpower<6>(fSlow137))) + (1.736111111111111e-05f * faustpower<8>(fSlow137))) + (4.822530864197531e-07f * faustpower<10>(fSlow137))) + (9.841899722852104e-09f * faustpower<12>(fSlow137))) + (1.5377968316956413e-10f * faustpower<14>(fSlow137))) + (1.898514607031656e-12f * faustpower<16>(fSlow137))) + (1.898514607031656e-14f * faustpower<18>(fSlow137))) + (1.5690203363897983e-16f * faustpower<20>(fSlow137))) + (1.0895974558262487e-18f * faustpower<22>(fSlow137))) + (6.697330183385451e-20f * faustpower<24>(fSlow137))) + (1.5283966662112614e-19f * faustpower<26>(fSlow137))) + (6.223149226587858e-20f * faustpower<28>(fSlow137))))) / fSlow6));
		float 	fSlow140 = (fSlow139 * min(fSlow1, (0 - fSlow136)));
		float 	fSlow141 = (fConst25 * fSlow0);
		float 	fSlow142 = (0.004750893823638667f * sinf((0 - fSlow141)));
		float 	fSlow143 = (2.0975924321467265f * fSlow3);
		float 	fSlow144 = faustpower<2>(fSlow143);
		float 	fSlow145 = min(1.0f, ((1 + (fSlow144 * ((((((((((((((0.25f + (0.0625f * fSlow144)) + (0.006944444444444444f * faustpower<4>(fSlow143))) + (0.00043402777777777775f * faustpower<6>(fSlow143))) + (1.736111111111111e-05f * faustpower<8>(fSlow143))) + (4.822530864197531e-07f * faustpower<10>(fSlow143))) + (9.841899722852104e-09f * faustpower<12>(fSlow143))) + (1.5377968316956413e-10f * faustpower<14>(fSlow143))) + (1.898514607031656e-12f * faustpower<16>(fSlow143))) + (1.898514607031656e-14f * faustpower<18>(fSlow143))) + (1.5690203363897983e-16f * faustpower<20>(fSlow143))) + (1.0895974558262487e-18f * faustpower<22>(fSlow143))) + (6.697330183385451e-20f * faustpower<24>(fSlow143))) + (1.5283966662112614e-19f * faustpower<26>(fSlow143))) + (6.223149226587858e-20f * faustpower<28>(fSlow143))))) / fSlow6));
		float 	fSlow146 = (fSlow145 * min(fSlow1, (0 - fSlow142)));
		float 	fSlow147 = (fConst26 * fSlow0);
		float 	fSlow148 = (0.004822877063390768f * sinf((0 - fSlow147)));
		float 	fSlow149 = (2.1358722992552126f * fSlow3);
		float 	fSlow150 = faustpower<2>(fSlow149);
		float 	fSlow151 = min(1.0f, ((1 + (fSlow150 * ((((((((((((((0.25f + (0.0625f * fSlow150)) + (0.006944444444444444f * faustpower<4>(fSlow149))) + (0.00043402777777777775f * faustpower<6>(fSlow149))) + (1.736111111111111e-05f * faustpower<8>(fSlow149))) + (4.822530864197531e-07f * faustpower<10>(fSlow149))) + (9.841899722852104e-09f * faustpower<12>(fSlow149))) + (1.5377968316956413e-10f * faustpower<14>(fSlow149))) + (1.898514607031656e-12f * faustpower<16>(fSlow149))) + (1.898514607031656e-14f * faustpower<18>(fSlow149))) + (1.5690203363897983e-16f * faustpower<20>(fSlow149))) + (1.0895974558262487e-18f * faustpower<22>(fSlow149))) + (6.697330183385451e-20f * faustpower<24>(fSlow149))) + (1.5283966662112614e-19f * faustpower<26>(fSlow149))) + (6.223149226587858e-20f * faustpower<28>(fSlow149))))) / fSlow6));
		float 	fSlow152 = (fSlow151 * min(fSlow1, (0 - fSlow148)));
		float 	fSlow153 = (fConst27 * fSlow0);
		float 	fSlow154 = (0.004897075172058319f * sinf((0 - fSlow153)));
		float 	fSlow155 = (2.172917395276218f * fSlow3);
		float 	fSlow156 = faustpower<2>(fSlow155);
		float 	fSlow157 = min(1.0f, ((1 + (fSlow156 * ((((((((((((((0.25f + (0.0625f * fSlow156)) + (0.006944444444444444f * faustpower<4>(fSlow155))) + (0.00043402777777777775f * faustpower<6>(fSlow155))) + (1.736111111111111e-05f * faustpower<8>(fSlow155))) + (4.822530864197531e-07f * faustpower<10>(fSlow155))) + (9.841899722852104e-09f * faustpower<12>(fSlow155))) + (1.5377968316956413e-10f * faustpower<14>(fSlow155))) + (1.898514607031656e-12f * faustpower<16>(fSlow155))) + (1.898514607031656e-14f * faustpower<18>(fSlow155))) + (1.5690203363897983e-16f * faustpower<20>(fSlow155))) + (1.0895974558262487e-18f * faustpower<22>(fSlow155))) + (6.697330183385451e-20f * faustpower<24>(fSlow155))) + (1.5283966662112614e-19f * faustpower<26>(fSlow155))) + (6.223149226587858e-20f * faustpower<28>(fSlow155))))) / fSlow6));
		float 	fSlow158 = (fSlow157 * min(fSlow1, (0 - fSlow154)));
		float 	fSlow159 = (fConst28 * fSlow0);
		float 	fSlow160 = (0.0049735919716217296f * sinf((0 - fSlow159)));
		float 	fSlow161 = (2.2087898486057753f * fSlow3);
		float 	fSlow162 = faustpower<2>(fSlow161);
		float 	fSlow163 = min(1.0f, ((1 + (fSlow162 * ((((((((((((((0.25f + (0.0625f * fSlow162)) + (0.006944444444444444f * faustpower<4>(fSlow161))) + (0.00043402777777777775f * faustpower<6>(fSlow161))) + (1.736111111111111e-05f * faustpower<8>(fSlow161))) + (4.822530864197531e-07f * faustpower<10>(fSlow161))) + (9.841899722852104e-09f * faustpower<12>(fSlow161))) + (1.5377968316956413e-10f * faustpower<14>(fSlow161))) + (1.898514607031656e-12f * faustpower<16>(fSlow161))) + (1.898514607031656e-14f * faustpower<18>(fSlow161))) + (1.5690203363897983e-16f * faustpower<20>(fSlow161))) + (1.0895974558262487e-18f * faustpower<22>(fSlow161))) + (6.697330183385451e-20f * faustpower<24>(fSlow161))) + (1.5283966662112614e-19f * faustpower<26>(fSlow161))) + (6.223149226587858e-20f * faustpower<28>(fSlow161))))) / fSlow6));
		float 	fSlow164 = (fSlow163 * min(fSlow1, (0 - fSlow160)));
		float 	fSlow165 = (fConst29 * fSlow0);
		float 	fSlow166 = (0.0050525378759331855f * sinf((0 - fSlow165)));
		float 	fSlow167 = (2.2435459087247516f * fSlow3);
		float 	fSlow168 = faustpower<2>(fSlow167);
		float 	fSlow169 = min(1.0f, ((1 + (fSlow168 * ((((((((((((((0.25f + (0.0625f * fSlow168)) + (0.006944444444444444f * faustpower<4>(fSlow167))) + (0.00043402777777777775f * faustpower<6>(fSlow167))) + (1.736111111111111e-05f * faustpower<8>(fSlow167))) + (4.822530864197531e-07f * faustpower<10>(fSlow167))) + (9.841899722852104e-09f * faustpower<12>(fSlow167))) + (1.5377968316956413e-10f * faustpower<14>(fSlow167))) + (1.898514607031656e-12f * faustpower<16>(fSlow167))) + (1.898514607031656e-14f * faustpower<18>(fSlow167))) + (1.5690203363897983e-16f * faustpower<20>(fSlow167))) + (1.0895974558262487e-18f * faustpower<22>(fSlow167))) + (6.697330183385451e-20f * faustpower<24>(fSlow167))) + (1.5283966662112614e-19f * faustpower<26>(fSlow167))) + (6.223149226587858e-20f * faustpower<28>(fSlow167))))) / fSlow6));
		float 	fSlow170 = (fSlow169 * min(fSlow1, (0 - fSlow166)));
		float 	fSlow171 = (fConst30 * fSlow0);
		float 	fSlow172 = (0.005134030422319205f * sinf((0 - fSlow171)));
		float 	fSlow173 = (2.2772366926713894f * fSlow3);
		float 	fSlow174 = faustpower<2>(fSlow173);
		float 	fSlow175 = min(1.0f, ((1 + (fSlow174 * ((((((((((((((0.25f + (0.0625f * fSlow174)) + (0.006944444444444444f * faustpower<4>(fSlow173))) + (0.00043402777777777775f * faustpower<6>(fSlow173))) + (1.736111111111111e-05f * faustpower<8>(fSlow173))) + (4.822530864197531e-07f * faustpower<10>(fSlow173))) + (9.841899722852104e-09f * faustpower<12>(fSlow173))) + (1.5377968316956413e-10f * faustpower<14>(fSlow173))) + (1.898514607031656e-12f * faustpower<16>(fSlow173))) + (1.898514607031656e-14f * faustpower<18>(fSlow173))) + (1.5690203363897983e-16f * faustpower<20>(fSlow173))) + (1.0895974558262487e-18f * faustpower<22>(fSlow173))) + (6.697330183385451e-20f * faustpower<24>(fSlow173))) + (1.5283966662112614e-19f * faustpower<26>(fSlow173))) + (6.223149226587858e-20f * faustpower<28>(fSlow173))))) / fSlow6));
		float 	fSlow176 = (fSlow175 * min(fSlow1, (0 - fSlow172)));
		float 	fSlow177 = (fConst31 * fSlow0);
		float 	fSlow178 = (0.005218194855471979f * sinf((0 - fSlow177)));
		float 	fSlow179 = (2.3099088131318055f * fSlow3);
		float 	fSlow180 = faustpower<2>(fSlow179);
		float 	fSlow181 = min(1.0f, ((1 + (fSlow180 * ((((((((((((((0.25f + (0.0625f * fSlow180)) + (0.006944444444444444f * faustpower<4>(fSlow179))) + (0.00043402777777777775f * faustpower<6>(fSlow179))) + (1.736111111111111e-05f * faustpower<8>(fSlow179))) + (4.822530864197531e-07f * faustpower<10>(fSlow179))) + (9.841899722852104e-09f * faustpower<12>(fSlow179))) + (1.5377968316956413e-10f * faustpower<14>(fSlow179))) + (1.898514607031656e-12f * faustpower<16>(fSlow179))) + (1.898514607031656e-14f * faustpower<18>(fSlow179))) + (1.5690203363897983e-16f * faustpower<20>(fSlow179))) + (1.0895974558262487e-18f * faustpower<22>(fSlow179))) + (6.697330183385451e-20f * faustpower<24>(fSlow179))) + (1.5283966662112614e-19f * faustpower<26>(fSlow179))) + (6.223149226587858e-20f * faustpower<28>(fSlow179))))) / fSlow6));
		float 	fSlow182 = (fSlow181 * min(fSlow1, (0 - fSlow178)));
		float 	fSlow183 = (fConst32 * fSlow0);
		float 	fSlow184 = (0.005305164769729845f * sinf((0 - fSlow183)));
		float 	fSlow185 = (2.3416049103469088f * fSlow3);
		float 	fSlow186 = faustpower<2>(fSlow185);
		float 	fSlow187 = min(1.0f, ((1 + (fSlow186 * ((((((((((((((0.25f + (0.0625f * fSlow186)) + (0.006944444444444444f * faustpower<4>(fSlow185))) + (0.00043402777777777775f * faustpower<6>(fSlow185))) + (1.736111111111111e-05f * faustpower<8>(fSlow185))) + (4.822530864197531e-07f * faustpower<10>(fSlow185))) + (9.841899722852104e-09f * faustpower<12>(fSlow185))) + (1.5377968316956413e-10f * faustpower<14>(fSlow185))) + (1.898514607031656e-12f * faustpower<16>(fSlow185))) + (1.898514607031656e-14f * faustpower<18>(fSlow185))) + (1.5690203363897983e-16f * faustpower<20>(fSlow185))) + (1.0895974558262487e-18f * faustpower<22>(fSlow185))) + (6.697330183385451e-20f * faustpower<24>(fSlow185))) + (1.5283966662112614e-19f * faustpower<26>(fSlow185))) + (6.223149226587858e-20f * faustpower<28>(fSlow185))))) / fSlow6));
		float 	fSlow188 = (fSlow187 * min(fSlow1, (0 - fSlow184)));
		float 	fSlow189 = (fConst33 * fSlow0);
		float 	fSlow190 = (0.005395082816674419f * sinf((0 - fSlow189)));
		float 	fSlow191 = (2.3723641052712012f * fSlow3);
		float 	fSlow192 = faustpower<2>(fSlow191);
		float 	fSlow193 = min(1.0f, ((1 + (fSlow192 * ((((((((((((((0.25f + (0.0625f * fSlow192)) + (0.006944444444444444f * faustpower<4>(fSlow191))) + (0.00043402777777777775f * faustpower<6>(fSlow191))) + (1.736111111111111e-05f * faustpower<8>(fSlow191))) + (4.822530864197531e-07f * faustpower<10>(fSlow191))) + (9.841899722852104e-09f * faustpower<12>(fSlow191))) + (1.5377968316956413e-10f * faustpower<14>(fSlow191))) + (1.898514607031656e-12f * faustpower<16>(fSlow191))) + (1.898514607031656e-14f * faustpower<18>(fSlow191))) + (1.5690203363897983e-16f * faustpower<20>(fSlow191))) + (1.0895974558262487e-18f * faustpower<22>(fSlow191))) + (6.697330183385451e-20f * faustpower<24>(fSlow191))) + (1.5283966662112614e-19f * faustpower<26>(fSlow191))) + (6.223149226587858e-20f * faustpower<28>(fSlow191))))) / fSlow6));
		float 	fSlow194 = (fSlow193 * min(fSlow1, (0 - fSlow190)));
		float 	fSlow195 = (fConst34 * fSlow0);
		float 	fSlow196 = (0.0054881014859274255f * sinf((0 - fSlow195)));
		float 	fSlow197 = (2.402222387798308f * fSlow3);
		float 	fSlow198 = faustpower<2>(fSlow197);
		float 	fSlow199 = min(1.0f, ((1 + (fSlow198 * ((((((((((((((0.25f + (0.0625f * fSlow198)) + (0.006944444444444444f * faustpower<4>(fSlow197))) + (0.00043402777777777775f * faustpower<6>(fSlow197))) + (1.736111111111111e-05f * faustpower<8>(fSlow197))) + (4.822530864197531e-07f * faustpower<10>(fSlow197))) + (9.841899722852104e-09f * faustpower<12>(fSlow197))) + (1.5377968316956413e-10f * faustpower<14>(fSlow197))) + (1.898514607031656e-12f * faustpower<16>(fSlow197))) + (1.898514607031656e-14f * faustpower<18>(fSlow197))) + (1.5690203363897983e-16f * faustpower<20>(fSlow197))) + (1.0895974558262487e-18f * faustpower<22>(fSlow197))) + (6.697330183385451e-20f * faustpower<24>(fSlow197))) + (1.5283966662112614e-19f * faustpower<26>(fSlow197))) + (6.223149226587858e-20f * faustpower<28>(fSlow197))))) / fSlow6));
		float 	fSlow200 = (fSlow199 * min(fSlow1, (0 - fSlow196)));
		float 	fSlow201 = (fConst35 * fSlow0);
		float 	fSlow202 = (0.005584383968136679f * sinf((0 - fSlow201)));
		float 	fSlow203 = (2.4312129510886726f * fSlow3);
		float 	fSlow204 = faustpower<2>(fSlow203);
		float 	fSlow205 = min(1.0f, ((1 + (fSlow204 * ((((((((((((((0.25f + (0.0625f * fSlow204)) + (0.006944444444444444f * faustpower<4>(fSlow203))) + (0.00043402777777777775f * faustpower<6>(fSlow203))) + (1.736111111111111e-05f * faustpower<8>(fSlow203))) + (4.822530864197531e-07f * faustpower<10>(fSlow203))) + (9.841899722852104e-09f * faustpower<12>(fSlow203))) + (1.5377968316956413e-10f * faustpower<14>(fSlow203))) + (1.898514607031656e-12f * faustpower<16>(fSlow203))) + (1.898514607031656e-14f * faustpower<18>(fSlow203))) + (1.5690203363897983e-16f * faustpower<20>(fSlow203))) + (1.0895974558262487e-18f * faustpower<22>(fSlow203))) + (6.697330183385451e-20f * faustpower<24>(fSlow203))) + (1.5283966662112614e-19f * faustpower<26>(fSlow203))) + (6.223149226587858e-20f * faustpower<28>(fSlow203))))) / fSlow6));
		float 	fSlow206 = (fSlow205 * min(fSlow1, (0 - fSlow202)));
		float 	fSlow207 = (fConst36 * fSlow0);
		float 	fSlow208 = (0.005684105110424833f * sinf((0 - fSlow207)));
		float 	fSlow209 = (2.4593664808817914f * fSlow3);
		float 	fSlow210 = faustpower<2>(fSlow209);
		float 	fSlow211 = min(1.0f, ((1 + (fSlow210 * ((((((((((((((0.25f + (0.0625f * fSlow210)) + (0.006944444444444444f * faustpower<4>(fSlow209))) + (0.00043402777777777775f * faustpower<6>(fSlow209))) + (1.736111111111111e-05f * faustpower<8>(fSlow209))) + (4.822530864197531e-07f * faustpower<10>(fSlow209))) + (9.841899722852104e-09f * faustpower<12>(fSlow209))) + (1.5377968316956413e-10f * faustpower<14>(fSlow209))) + (1.898514607031656e-12f * faustpower<16>(fSlow209))) + (1.898514607031656e-14f * faustpower<18>(fSlow209))) + (1.5690203363897983e-16f * faustpower<20>(fSlow209))) + (1.0895974558262487e-18f * faustpower<22>(fSlow209))) + (6.697330183385451e-20f * faustpower<24>(fSlow209))) + (1.5283966662112614e-19f * faustpower<26>(fSlow209))) + (6.223149226587858e-20f * faustpower<28>(fSlow209))))) / fSlow6));
		float 	fSlow212 = (fSlow211 * min(fSlow1, (0 - fSlow208)));
		float 	fSlow213 = (fConst37 * fSlow0);
		float 	fSlow214 = (0.0057874524760689215f * sinf((0 - fSlow213)));
		float 	fSlow215 = (2.4867114069932166f * fSlow3);
		float 	fSlow216 = faustpower<2>(fSlow215);
		float 	fSlow217 = min(1.0f, ((1 + (fSlow216 * ((((((((((((((0.25f + (0.0625f * fSlow216)) + (0.006944444444444444f * faustpower<4>(fSlow215))) + (0.00043402777777777775f * faustpower<6>(fSlow215))) + (1.736111111111111e-05f * faustpower<8>(fSlow215))) + (4.822530864197531e-07f * faustpower<10>(fSlow215))) + (9.841899722852104e-09f * faustpower<12>(fSlow215))) + (1.5377968316956413e-10f * faustpower<14>(fSlow215))) + (1.898514607031656e-12f * faustpower<16>(fSlow215))) + (1.898514607031656e-14f * faustpower<18>(fSlow215))) + (1.5690203363897983e-16f * faustpower<20>(fSlow215))) + (1.0895974558262487e-18f * faustpower<22>(fSlow215))) + (6.697330183385451e-20f * faustpower<24>(fSlow215))) + (1.5283966662112614e-19f * faustpower<26>(fSlow215))) + (6.223149226587858e-20f * faustpower<28>(fSlow215))))) / fSlow6));
		float 	fSlow218 = (fSlow217 * min(fSlow1, (0 - fSlow214)));
		float 	fSlow219 = (fConst38 * fSlow0);
		float 	fSlow220 = (0.00589462752192205f * sinf((0 - fSlow219)));
		float 	fSlow221 = (2.5132741228718345f * fSlow3);
		float 	fSlow222 = faustpower<2>(fSlow221);
		float 	fSlow223 = min(1.0f, ((1 + (fSlow222 * ((((((((((((((0.25f + (0.0625f * fSlow222)) + (0.006944444444444444f * faustpower<4>(fSlow221))) + (0.00043402777777777775f * faustpower<6>(fSlow221))) + (1.736111111111111e-05f * faustpower<8>(fSlow221))) + (4.822530864197531e-07f * faustpower<10>(fSlow221))) + (9.841899722852104e-09f * faustpower<12>(fSlow221))) + (1.5377968316956413e-10f * faustpower<14>(fSlow221))) + (1.898514607031656e-12f * faustpower<16>(fSlow221))) + (1.898514607031656e-14f * faustpower<18>(fSlow221))) + (1.5690203363897983e-16f * faustpower<20>(fSlow221))) + (1.0895974558262487e-18f * faustpower<22>(fSlow221))) + (6.697330183385451e-20f * faustpower<24>(fSlow221))) + (1.5283966662112614e-19f * faustpower<26>(fSlow221))) + (6.223149226587858e-20f * faustpower<28>(fSlow221))))) / fSlow6));
		float 	fSlow224 = (fSlow223 * min(fSlow1, (0 - fSlow220)));
		float 	fSlow225 = (fConst39 * fSlow0);
		float 	fSlow226 = (0.006005846909128126f * sinf((0 - fSlow225)));
		float 	fSlow227 = (2.5390791780418938f * fSlow3);
		float 	fSlow228 = faustpower<2>(fSlow227);
		float 	fSlow229 = min(1.0f, ((1 + (fSlow228 * ((((((((((((((0.25f + (0.0625f * fSlow228)) + (0.006944444444444444f * faustpower<4>(fSlow227))) + (0.00043402777777777775f * faustpower<6>(fSlow227))) + (1.736111111111111e-05f * faustpower<8>(fSlow227))) + (4.822530864197531e-07f * faustpower<10>(fSlow227))) + (9.841899722852104e-09f * faustpower<12>(fSlow227))) + (1.5377968316956413e-10f * faustpower<14>(fSlow227))) + (1.898514607031656e-12f * faustpower<16>(fSlow227))) + (1.898514607031656e-14f * faustpower<18>(fSlow227))) + (1.5690203363897983e-16f * faustpower<20>(fSlow227))) + (1.0895974558262487e-18f * faustpower<22>(fSlow227))) + (6.697330183385451e-20f * faustpower<24>(fSlow227))) + (1.5283966662112614e-19f * faustpower<26>(fSlow227))) + (6.223149226587858e-20f * faustpower<28>(fSlow227))))) / fSlow6));
		float 	fSlow230 = (fSlow229 * min(fSlow1, (0 - fSlow226)));
		float 	fSlow231 = (fConst40 * fSlow0);
		float 	fSlow232 = (0.006121343965072897f * sinf((0 - fSlow231)));
		float 	fSlow233 = (2.5641494474145454f * fSlow3);
		float 	fSlow234 = faustpower<2>(fSlow233);
		float 	fSlow235 = min(1.0f, ((1 + (fSlow234 * ((((((((((((((0.25f + (0.0625f * fSlow234)) + (0.006944444444444444f * faustpower<4>(fSlow233))) + (0.00043402777777777775f * faustpower<6>(fSlow233))) + (1.736111111111111e-05f * faustpower<8>(fSlow233))) + (4.822530864197531e-07f * faustpower<10>(fSlow233))) + (9.841899722852104e-09f * faustpower<12>(fSlow233))) + (1.5377968316956413e-10f * faustpower<14>(fSlow233))) + (1.898514607031656e-12f * faustpower<16>(fSlow233))) + (1.898514607031656e-14f * faustpower<18>(fSlow233))) + (1.5690203363897983e-16f * faustpower<20>(fSlow233))) + (1.0895974558262487e-18f * faustpower<22>(fSlow233))) + (6.697330183385451e-20f * faustpower<24>(fSlow233))) + (1.5283966662112614e-19f * faustpower<26>(fSlow233))) + (6.223149226587858e-20f * faustpower<28>(fSlow233))))) / fSlow6));
		float 	fSlow236 = (fSlow235 * min(fSlow1, (0 - fSlow232)));
		float 	fSlow237 = (fConst41 * fSlow0);
		float 	fSlow238 = (0.006241370317329229f * sinf((0 - fSlow237)));
		float 	fSlow239 = (2.588506280778249f * fSlow3);
		float 	fSlow240 = faustpower<2>(fSlow239);
		float 	fSlow241 = min(1.0f, ((1 + (fSlow240 * ((((((((((((((0.25f + (0.0625f * fSlow240)) + (0.006944444444444444f * faustpower<4>(fSlow239))) + (0.00043402777777777775f * faustpower<6>(fSlow239))) + (1.736111111111111e-05f * faustpower<8>(fSlow239))) + (4.822530864197531e-07f * faustpower<10>(fSlow239))) + (9.841899722852104e-09f * faustpower<12>(fSlow239))) + (1.5377968316956413e-10f * faustpower<14>(fSlow239))) + (1.898514607031656e-12f * faustpower<16>(fSlow239))) + (1.898514607031656e-14f * faustpower<18>(fSlow239))) + (1.5690203363897983e-16f * faustpower<20>(fSlow239))) + (1.0895974558262487e-18f * faustpower<22>(fSlow239))) + (6.697330183385451e-20f * faustpower<24>(fSlow239))) + (1.5283966662112614e-19f * faustpower<26>(fSlow239))) + (6.223149226587858e-20f * faustpower<28>(fSlow239))))) / fSlow6));
		float 	fSlow242 = (fSlow241 * min(fSlow1, (0 - fSlow238)));
		float 	fSlow243 = (fConst42 * fSlow0);
		float 	fSlow244 = (0.006366197723675813f * sinf((0 - fSlow243)));
		float 	fSlow245 = (2.6121696352308885f * fSlow3);
		float 	fSlow246 = faustpower<2>(fSlow245);
		float 	fSlow247 = min(1.0f, ((1 + (fSlow246 * ((((((((((((((0.25f + (0.0625f * fSlow246)) + (0.006944444444444444f * faustpower<4>(fSlow245))) + (0.00043402777777777775f * faustpower<6>(fSlow245))) + (1.736111111111111e-05f * faustpower<8>(fSlow245))) + (4.822530864197531e-07f * faustpower<10>(fSlow245))) + (9.841899722852104e-09f * faustpower<12>(fSlow245))) + (1.5377968316956413e-10f * faustpower<14>(fSlow245))) + (1.898514607031656e-12f * faustpower<16>(fSlow245))) + (1.898514607031656e-14f * faustpower<18>(fSlow245))) + (1.5690203363897983e-16f * faustpower<20>(fSlow245))) + (1.0895974558262487e-18f * faustpower<22>(fSlow245))) + (6.697330183385451e-20f * faustpower<24>(fSlow245))) + (1.5283966662112614e-19f * faustpower<26>(fSlow245))) + (6.223149226587858e-20f * faustpower<28>(fSlow245))))) / fSlow6));
		float 	fSlow248 = (fSlow247 * min(fSlow1, (0 - fSlow244)));
		float 	fSlow249 = (fConst43 * fSlow0);
		float 	fSlow250 = (0.00649612012619981f * sinf((0 - fSlow249)));
		float 	fSlow251 = (2.6351581928715038f * fSlow3);
		float 	fSlow252 = faustpower<2>(fSlow251);
		float 	fSlow253 = min(1.0f, ((1 + (fSlow252 * ((((((((((((((0.25f + (0.0625f * fSlow252)) + (0.006944444444444444f * faustpower<4>(fSlow251))) + (0.00043402777777777775f * faustpower<6>(fSlow251))) + (1.736111111111111e-05f * faustpower<8>(fSlow251))) + (4.822530864197531e-07f * faustpower<10>(fSlow251))) + (9.841899722852104e-09f * faustpower<12>(fSlow251))) + (1.5377968316956413e-10f * faustpower<14>(fSlow251))) + (1.898514607031656e-12f * faustpower<16>(fSlow251))) + (1.898514607031656e-14f * faustpower<18>(fSlow251))) + (1.5690203363897983e-16f * faustpower<20>(fSlow251))) + (1.0895974558262487e-18f * faustpower<22>(fSlow251))) + (6.697330183385451e-20f * faustpower<24>(fSlow251))) + (1.5283966662112614e-19f * faustpower<26>(fSlow251))) + (6.223149226587858e-20f * faustpower<28>(fSlow251))))) / fSlow6));
		float 	fSlow254 = (fSlow253 * min(fSlow1, (0 - fSlow250)));
		float 	fSlow255 = (fConst44 * fSlow0);
		float 	fSlow256 = (0.006631455962162306f * sinf((0 - fSlow255)));
		float 	fSlow257 = (2.657489465705377f * fSlow3);
		float 	fSlow258 = faustpower<2>(fSlow257);
		float 	fSlow259 = min(1.0f, ((1 + (fSlow258 * ((((((((((((((0.25f + (0.0625f * fSlow258)) + (0.006944444444444444f * faustpower<4>(fSlow257))) + (0.00043402777777777775f * faustpower<6>(fSlow257))) + (1.736111111111111e-05f * faustpower<8>(fSlow257))) + (4.822530864197531e-07f * faustpower<10>(fSlow257))) + (9.841899722852104e-09f * faustpower<12>(fSlow257))) + (1.5377968316956413e-10f * faustpower<14>(fSlow257))) + (1.898514607031656e-12f * faustpower<16>(fSlow257))) + (1.898514607031656e-14f * faustpower<18>(fSlow257))) + (1.5690203363897983e-16f * faustpower<20>(fSlow257))) + (1.0895974558262487e-18f * faustpower<22>(fSlow257))) + (6.697330183385451e-20f * faustpower<24>(fSlow257))) + (1.5283966662112614e-19f * faustpower<26>(fSlow257))) + (6.223149226587858e-20f * faustpower<28>(fSlow257))))) / fSlow6));
		float 	fSlow260 = (fSlow259 * min(fSlow1, (0 - fSlow256)));
		float 	fSlow261 = (fConst45 * fSlow0);
		float 	fSlow262 = (0.006772550769867886f * sinf((0 - fSlow261)));
		float 	fSlow263 = (2.679179889416536f * fSlow3);
		float 	fSlow264 = faustpower<2>(fSlow263);
		float 	fSlow265 = min(1.0f, ((1 + (fSlow264 * ((((((((((((((0.25f + (0.0625f * fSlow264)) + (0.006944444444444444f * faustpower<4>(fSlow263))) + (0.00043402777777777775f * faustpower<6>(fSlow263))) + (1.736111111111111e-05f * faustpower<8>(fSlow263))) + (4.822530864197531e-07f * faustpower<10>(fSlow263))) + (9.841899722852104e-09f * faustpower<12>(fSlow263))) + (1.5377968316956413e-10f * faustpower<14>(fSlow263))) + (1.898514607031656e-12f * faustpower<16>(fSlow263))) + (1.898514607031656e-14f * faustpower<18>(fSlow263))) + (1.5690203363897983e-16f * faustpower<20>(fSlow263))) + (1.0895974558262487e-18f * faustpower<22>(fSlow263))) + (6.697330183385451e-20f * faustpower<24>(fSlow263))) + (1.5283966662112614e-19f * faustpower<26>(fSlow263))) + (6.223149226587858e-20f * faustpower<28>(fSlow263))))) / fSlow6));
		float 	fSlow266 = (fSlow265 * min(fSlow1, (0 - fSlow262)));
		float 	fSlow267 = (fConst46 * fSlow0);
		float 	fSlow268 = (0.006919780134430233f * sinf((0 - fSlow267)));
		float 	fSlow269 = (2.700244907413892f * fSlow3);
		float 	fSlow270 = faustpower<2>(fSlow269);
		float 	fSlow271 = min(1.0f, ((1 + (fSlow270 * ((((((((((((((0.25f + (0.0625f * fSlow270)) + (0.006944444444444444f * faustpower<4>(fSlow269))) + (0.00043402777777777775f * faustpower<6>(fSlow269))) + (1.736111111111111e-05f * faustpower<8>(fSlow269))) + (4.822530864197531e-07f * faustpower<10>(fSlow269))) + (9.841899722852104e-09f * faustpower<12>(fSlow269))) + (1.5377968316956413e-10f * faustpower<14>(fSlow269))) + (1.898514607031656e-12f * faustpower<16>(fSlow269))) + (1.898514607031656e-14f * faustpower<18>(fSlow269))) + (1.5690203363897983e-16f * faustpower<20>(fSlow269))) + (1.0895974558262487e-18f * faustpower<22>(fSlow269))) + (6.697330183385451e-20f * faustpower<24>(fSlow269))) + (1.5283966662112614e-19f * faustpower<26>(fSlow269))) + (6.223149226587858e-20f * faustpower<28>(fSlow269))))) / fSlow6));
		float 	fSlow272 = (fSlow271 * min(fSlow1, (0 - fSlow268)));
		float 	fSlow273 = (fConst47 * fSlow0);
		float 	fSlow274 = (0.007073553026306459f * sinf((0 - fSlow273)));
		float 	fSlow275 = (2.7206990463513265f * fSlow3);
		float 	fSlow276 = faustpower<2>(fSlow275);
		float 	fSlow277 = min(1.0f, ((1 + (fSlow276 * ((((((((((((((0.25f + (0.0625f * fSlow276)) + (0.006944444444444444f * faustpower<4>(fSlow275))) + (0.00043402777777777775f * faustpower<6>(fSlow275))) + (1.736111111111111e-05f * faustpower<8>(fSlow275))) + (4.822530864197531e-07f * faustpower<10>(fSlow275))) + (9.841899722852104e-09f * faustpower<12>(fSlow275))) + (1.5377968316956413e-10f * faustpower<14>(fSlow275))) + (1.898514607031656e-12f * faustpower<16>(fSlow275))) + (1.898514607031656e-14f * faustpower<18>(fSlow275))) + (1.5690203363897983e-16f * faustpower<20>(fSlow275))) + (1.0895974558262487e-18f * faustpower<22>(fSlow275))) + (6.697330183385451e-20f * faustpower<24>(fSlow275))) + (1.5283966662112614e-19f * faustpower<26>(fSlow275))) + (6.223149226587858e-20f * faustpower<28>(fSlow275))))) / fSlow6));
		float 	fSlow278 = (fSlow277 * min(fSlow1, (0 - fSlow274)));
		float 	fSlow279 = (fConst48 * fSlow0);
		float 	fSlow280 = (0.007234315595086153f * sinf((0 - fSlow279)));
		float 	fSlow281 = (2.74055598415013f * fSlow3);
		float 	fSlow282 = faustpower<2>(fSlow281);
		float 	fSlow283 = min(1.0f, ((1 + (fSlow282 * ((((((((((((((0.25f + (0.0625f * fSlow282)) + (0.006944444444444444f * faustpower<4>(fSlow281))) + (0.00043402777777777775f * faustpower<6>(fSlow281))) + (1.736111111111111e-05f * faustpower<8>(fSlow281))) + (4.822530864197531e-07f * faustpower<10>(fSlow281))) + (9.841899722852104e-09f * faustpower<12>(fSlow281))) + (1.5377968316956413e-10f * faustpower<14>(fSlow281))) + (1.898514607031656e-12f * faustpower<16>(fSlow281))) + (1.898514607031656e-14f * faustpower<18>(fSlow281))) + (1.5690203363897983e-16f * faustpower<20>(fSlow281))) + (1.0895974558262487e-18f * faustpower<22>(fSlow281))) + (6.697330183385451e-20f * faustpower<24>(fSlow281))) + (1.5283966662112614e-19f * faustpower<26>(fSlow281))) + (6.223149226587858e-20f * faustpower<28>(fSlow281))))) / fSlow6));
		float 	fSlow284 = (fSlow283 * min(fSlow1, (0 - fSlow280)));
		float 	fSlow285 = (fConst49 * fSlow0);
		float 	fSlow286 = (0.007402555492646295f * sinf((0 - fSlow285)));
		float 	fSlow287 = (2.759828611408118f * fSlow3);
		float 	fSlow288 = faustpower<2>(fSlow287);
		float 	fSlow289 = min(1.0f, ((1 + (fSlow288 * ((((((((((((((0.25f + (0.0625f * fSlow288)) + (0.006944444444444444f * faustpower<4>(fSlow287))) + (0.00043402777777777775f * faustpower<6>(fSlow287))) + (1.736111111111111e-05f * faustpower<8>(fSlow287))) + (4.822530864197531e-07f * faustpower<10>(fSlow287))) + (9.841899722852104e-09f * faustpower<12>(fSlow287))) + (1.5377968316956413e-10f * faustpower<14>(fSlow287))) + (1.898514607031656e-12f * faustpower<16>(fSlow287))) + (1.898514607031656e-14f * faustpower<18>(fSlow287))) + (1.5690203363897983e-16f * faustpower<20>(fSlow287))) + (1.0895974558262487e-18f * faustpower<22>(fSlow287))) + (6.697330183385451e-20f * faustpower<24>(fSlow287))) + (1.5283966662112614e-19f * faustpower<26>(fSlow287))) + (6.223149226587858e-20f * faustpower<28>(fSlow287))))) / fSlow6));
		float 	fSlow290 = (fSlow289 * min(fSlow1, (0 - fSlow286)));
		float 	fSlow291 = (fConst50 * fSlow0);
		float 	fSlow292 = (0.007578806813899778f * sinf((0 - fSlow291)));
		float 	fSlow293 = (2.7785290869584833f * fSlow3);
		float 	fSlow294 = faustpower<2>(fSlow293);
		float 	fSlow295 = min(1.0f, ((1 + (fSlow294 * ((((((((((((((0.25f + (0.0625f * fSlow294)) + (0.006944444444444444f * faustpower<4>(fSlow293))) + (0.00043402777777777775f * faustpower<6>(fSlow293))) + (1.736111111111111e-05f * faustpower<8>(fSlow293))) + (4.822530864197531e-07f * faustpower<10>(fSlow293))) + (9.841899722852104e-09f * faustpower<12>(fSlow293))) + (1.5377968316956413e-10f * faustpower<14>(fSlow293))) + (1.898514607031656e-12f * faustpower<16>(fSlow293))) + (1.898514607031656e-14f * faustpower<18>(fSlow293))) + (1.5690203363897983e-16f * faustpower<20>(fSlow293))) + (1.0895974558262487e-18f * faustpower<22>(fSlow293))) + (6.697330183385451e-20f * faustpower<24>(fSlow293))) + (1.5283966662112614e-19f * faustpower<26>(fSlow293))) + (6.223149226587858e-20f * faustpower<28>(fSlow293))))) / fSlow6));
		float 	fSlow296 = (fSlow295 * min(fSlow1, (0 - fSlow292)));
		float 	fSlow297 = (fConst51 * fSlow0);
		float 	fSlow298 = (0.0077636557605802615f * sinf((0 - fSlow297)));
		float 	fSlow299 = (2.7966688882389223f * fSlow3);
		float 	fSlow300 = faustpower<2>(fSlow299);
		float 	fSlow301 = min(1.0f, ((1 + (fSlow300 * ((((((((((((((0.25f + (0.0625f * fSlow300)) + (0.006944444444444444f * faustpower<4>(fSlow299))) + (0.00043402777777777775f * faustpower<6>(fSlow299))) + (1.736111111111111e-05f * faustpower<8>(fSlow299))) + (4.822530864197531e-07f * faustpower<10>(fSlow299))) + (9.841899722852104e-09f * faustpower<12>(fSlow299))) + (1.5377968316956413e-10f * faustpower<14>(fSlow299))) + (1.898514607031656e-12f * faustpower<16>(fSlow299))) + (1.898514607031656e-14f * faustpower<18>(fSlow299))) + (1.5690203363897983e-16f * faustpower<20>(fSlow299))) + (1.0895974558262487e-18f * faustpower<22>(fSlow299))) + (6.697330183385451e-20f * faustpower<24>(fSlow299))) + (1.5283966662112614e-19f * faustpower<26>(fSlow299))) + (6.223149226587858e-20f * faustpower<28>(fSlow299))))) / fSlow6));
		float 	fSlow302 = (fSlow301 * min(fSlow1, (0 - fSlow298)));
		float 	fSlow303 = (fConst52 * fSlow0);
		float 	fSlow304 = (0.007957747154594767f * sinf((0 - fSlow303)));
		float 	fSlow305 = (2.814258857044679f * fSlow3);
		float 	fSlow306 = faustpower<2>(fSlow305);
		float 	fSlow307 = min(1.0f, ((1 + (fSlow306 * ((((((((((((((0.25f + (0.0625f * fSlow306)) + (0.006944444444444444f * faustpower<4>(fSlow305))) + (0.00043402777777777775f * faustpower<6>(fSlow305))) + (1.736111111111111e-05f * faustpower<8>(fSlow305))) + (4.822530864197531e-07f * faustpower<10>(fSlow305))) + (9.841899722852104e-09f * faustpower<12>(fSlow305))) + (1.5377968316956413e-10f * faustpower<14>(fSlow305))) + (1.898514607031656e-12f * faustpower<16>(fSlow305))) + (1.898514607031656e-14f * faustpower<18>(fSlow305))) + (1.5690203363897983e-16f * faustpower<20>(fSlow305))) + (1.0895974558262487e-18f * faustpower<22>(fSlow305))) + (6.697330183385451e-20f * faustpower<24>(fSlow305))) + (1.5283966662112614e-19f * faustpower<26>(fSlow305))) + (6.223149226587858e-20f * faustpower<28>(fSlow305))))) / fSlow6));
		float 	fSlow308 = (fSlow307 * min(fSlow1, (0 - fSlow304)));
		float 	fSlow309 = (fConst53 * fSlow0);
		float 	fSlow310 = (0.00816179195343053f * sinf((0 - fSlow309)));
		float 	fSlow311 = (2.8313092411651226f * fSlow3);
		float 	fSlow312 = faustpower<2>(fSlow311);
		float 	fSlow313 = min(1.0f, ((1 + (fSlow312 * ((((((((((((((0.25f + (0.0625f * fSlow312)) + (0.006944444444444444f * faustpower<4>(fSlow311))) + (0.00043402777777777775f * faustpower<6>(fSlow311))) + (1.736111111111111e-05f * faustpower<8>(fSlow311))) + (4.822530864197531e-07f * faustpower<10>(fSlow311))) + (9.841899722852104e-09f * faustpower<12>(fSlow311))) + (1.5377968316956413e-10f * faustpower<14>(fSlow311))) + (1.898514607031656e-12f * faustpower<16>(fSlow311))) + (1.898514607031656e-14f * faustpower<18>(fSlow311))) + (1.5690203363897983e-16f * faustpower<20>(fSlow311))) + (1.0895974558262487e-18f * faustpower<22>(fSlow311))) + (6.697330183385451e-20f * faustpower<24>(fSlow311))) + (1.5283966662112614e-19f * faustpower<26>(fSlow311))) + (6.223149226587858e-20f * faustpower<28>(fSlow311))))) / fSlow6));
		float 	fSlow314 = (fSlow313 * min(fSlow1, (0 - fSlow310)));
		float 	fSlow315 = (fConst54 * fSlow0);
		float 	fSlow316 = (0.008376575952205019f * sinf((0 - fSlow315)));
		float 	fSlow317 = (2.847829732340283f * fSlow3);
		float 	fSlow318 = faustpower<2>(fSlow317);
		float 	fSlow319 = min(1.0f, ((1 + (fSlow318 * ((((((((((((((0.25f + (0.0625f * fSlow318)) + (0.006944444444444444f * faustpower<4>(fSlow317))) + (0.00043402777777777775f * faustpower<6>(fSlow317))) + (1.736111111111111e-05f * faustpower<8>(fSlow317))) + (4.822530864197531e-07f * faustpower<10>(fSlow317))) + (9.841899722852104e-09f * faustpower<12>(fSlow317))) + (1.5377968316956413e-10f * faustpower<14>(fSlow317))) + (1.898514607031656e-12f * faustpower<16>(fSlow317))) + (1.898514607031656e-14f * faustpower<18>(fSlow317))) + (1.5690203363897983e-16f * faustpower<20>(fSlow317))) + (1.0895974558262487e-18f * faustpower<22>(fSlow317))) + (6.697330183385451e-20f * faustpower<24>(fSlow317))) + (1.5283966662112614e-19f * faustpower<26>(fSlow317))) + (6.223149226587858e-20f * faustpower<28>(fSlow317))))) / fSlow6));
		float 	fSlow320 = (fSlow319 * min(fSlow1, (0 - fSlow316)));
		float 	fSlow321 = (fConst55 * fSlow0);
		float 	fSlow322 = (0.008602969896859207f * sinf((0 - fSlow321)));
		float 	fSlow323 = (2.863829500919589f * fSlow3);
		float 	fSlow324 = faustpower<2>(fSlow323);
		float 	fSlow325 = min(1.0f, ((1 + (fSlow324 * ((((((((((((((0.25f + (0.0625f * fSlow324)) + (0.006944444444444444f * faustpower<4>(fSlow323))) + (0.00043402777777777775f * faustpower<6>(fSlow323))) + (1.736111111111111e-05f * faustpower<8>(fSlow323))) + (4.822530864197531e-07f * faustpower<10>(fSlow323))) + (9.841899722852104e-09f * faustpower<12>(fSlow323))) + (1.5377968316956413e-10f * faustpower<14>(fSlow323))) + (1.898514607031656e-12f * faustpower<16>(fSlow323))) + (1.898514607031656e-14f * faustpower<18>(fSlow323))) + (1.5690203363897983e-16f * faustpower<20>(fSlow323))) + (1.0895974558262487e-18f * faustpower<22>(fSlow323))) + (6.697330183385451e-20f * faustpower<24>(fSlow323))) + (1.5283966662112614e-19f * faustpower<26>(fSlow323))) + (6.223149226587858e-20f * faustpower<28>(fSlow323))))) / fSlow6));
		float 	fSlow326 = (fSlow325 * min(fSlow1, (0 - fSlow322)));
		float 	fSlow327 = (fConst56 * fSlow0);
		float 	fSlow328 = (0.008841941282883075f * sinf((0 - fSlow327)));
		float 	fSlow329 = (2.8793172275584813f * fSlow3);
		float 	fSlow330 = faustpower<2>(fSlow329);
		float 	fSlow331 = min(1.0f, ((1 + (fSlow330 * ((((((((((((((0.25f + (0.0625f * fSlow330)) + (0.006944444444444444f * faustpower<4>(fSlow329))) + (0.00043402777777777775f * faustpower<6>(fSlow329))) + (1.736111111111111e-05f * faustpower<8>(fSlow329))) + (4.822530864197531e-07f * faustpower<10>(fSlow329))) + (9.841899722852104e-09f * faustpower<12>(fSlow329))) + (1.5377968316956413e-10f * faustpower<14>(fSlow329))) + (1.898514607031656e-12f * faustpower<16>(fSlow329))) + (1.898514607031656e-14f * faustpower<18>(fSlow329))) + (1.5690203363897983e-16f * faustpower<20>(fSlow329))) + (1.0895974558262487e-18f * faustpower<22>(fSlow329))) + (6.697330183385451e-20f * faustpower<24>(fSlow329))) + (1.5283966662112614e-19f * faustpower<26>(fSlow329))) + (6.223149226587858e-20f * faustpower<28>(fSlow329))))) / fSlow6));
		float 	fSlow332 = (fSlow331 * min(fSlow1, (0 - fSlow328)));
		float 	fSlow333 = (fConst57 * fSlow0);
		float 	fSlow334 = (0.009094568176679734f * sinf((0 - fSlow333)));
		float 	fSlow335 = (2.8943011322484202f * fSlow3);
		float 	fSlow336 = faustpower<2>(fSlow335);
		float 	fSlow337 = min(1.0f, ((1 + (fSlow336 * ((((((((((((((0.25f + (0.0625f * fSlow336)) + (0.006944444444444444f * faustpower<4>(fSlow335))) + (0.00043402777777777775f * faustpower<6>(fSlow335))) + (1.736111111111111e-05f * faustpower<8>(fSlow335))) + (4.822530864197531e-07f * faustpower<10>(fSlow335))) + (9.841899722852104e-09f * faustpower<12>(fSlow335))) + (1.5377968316956413e-10f * faustpower<14>(fSlow335))) + (1.898514607031656e-12f * faustpower<16>(fSlow335))) + (1.898514607031656e-14f * faustpower<18>(fSlow335))) + (1.5690203363897983e-16f * faustpower<20>(fSlow335))) + (1.0895974558262487e-18f * faustpower<22>(fSlow335))) + (6.697330183385451e-20f * faustpower<24>(fSlow335))) + (1.5283966662112614e-19f * faustpower<26>(fSlow335))) + (6.223149226587858e-20f * faustpower<28>(fSlow335))))) / fSlow6));
		float 	fSlow338 = (fSlow337 * min(fSlow1, (0 - fSlow334)));
		float 	fSlow339 = (fConst58 * fSlow0);
		float 	fSlow340 = (0.009362055475993843f * sinf((0 - fSlow339)));
		float 	fSlow341 = (2.9087890009410478f * fSlow3);
		float 	fSlow342 = faustpower<2>(fSlow341);
		float 	fSlow343 = min(1.0f, ((1 + (fSlow342 * ((((((((((((((0.25f + (0.0625f * fSlow342)) + (0.006944444444444444f * faustpower<4>(fSlow341))) + (0.00043402777777777775f * faustpower<6>(fSlow341))) + (1.736111111111111e-05f * faustpower<8>(fSlow341))) + (4.822530864197531e-07f * faustpower<10>(fSlow341))) + (9.841899722852104e-09f * faustpower<12>(fSlow341))) + (1.5377968316956413e-10f * faustpower<14>(fSlow341))) + (1.898514607031656e-12f * faustpower<16>(fSlow341))) + (1.898514607031656e-14f * faustpower<18>(fSlow341))) + (1.5690203363897983e-16f * faustpower<20>(fSlow341))) + (1.0895974558262487e-18f * faustpower<22>(fSlow341))) + (6.697330183385451e-20f * faustpower<24>(fSlow341))) + (1.5283966662112614e-19f * faustpower<26>(fSlow341))) + (6.223149226587858e-20f * faustpower<28>(fSlow341))))) / fSlow6));
		float 	fSlow344 = (fSlow343 * min(fSlow1, (0 - fSlow340)));
		float 	fSlow345 = (fConst59 * fSlow0);
		float 	fSlow346 = (0.009645754126781536f * sinf((0 - fSlow345)));
		float 	fSlow347 = (2.922788209997169f * fSlow3);
		float 	fSlow348 = faustpower<2>(fSlow347);
		float 	fSlow349 = min(1.0f, ((1 + (fSlow348 * ((((((((((((((0.25f + (0.0625f * fSlow348)) + (0.006944444444444444f * faustpower<4>(fSlow347))) + (0.00043402777777777775f * faustpower<6>(fSlow347))) + (1.736111111111111e-05f * faustpower<8>(fSlow347))) + (4.822530864197531e-07f * faustpower<10>(fSlow347))) + (9.841899722852104e-09f * faustpower<12>(fSlow347))) + (1.5377968316956413e-10f * faustpower<14>(fSlow347))) + (1.898514607031656e-12f * faustpower<16>(fSlow347))) + (1.898514607031656e-14f * faustpower<18>(fSlow347))) + (1.5690203363897983e-16f * faustpower<20>(fSlow347))) + (1.0895974558262487e-18f * faustpower<22>(fSlow347))) + (6.697330183385451e-20f * faustpower<24>(fSlow347))) + (1.5283966662112614e-19f * faustpower<26>(fSlow347))) + (6.223149226587858e-20f * faustpower<28>(fSlow347))))) / fSlow6));
		float 	fSlow350 = (fSlow349 * min(fSlow1, (0 - fSlow346)));
		float 	fSlow351 = (fConst60 * fSlow0);
		float 	fSlow352 = (0.009947183943243459f * sinf((0 - fSlow351)));
		float 	fSlow353 = (2.9363057486649784f * fSlow3);
		float 	fSlow354 = faustpower<2>(fSlow353);
		float 	fSlow355 = min(1.0f, ((1 + (fSlow354 * ((((((((((((((0.25f + (0.0625f * fSlow354)) + (0.006944444444444444f * faustpower<4>(fSlow353))) + (0.00043402777777777775f * faustpower<6>(fSlow353))) + (1.736111111111111e-05f * faustpower<8>(fSlow353))) + (4.822530864197531e-07f * faustpower<10>(fSlow353))) + (9.841899722852104e-09f * faustpower<12>(fSlow353))) + (1.5377968316956413e-10f * faustpower<14>(fSlow353))) + (1.898514607031656e-12f * faustpower<16>(fSlow353))) + (1.898514607031656e-14f * faustpower<18>(fSlow353))) + (1.5690203363897983e-16f * faustpower<20>(fSlow353))) + (1.0895974558262487e-18f * faustpower<22>(fSlow353))) + (6.697330183385451e-20f * faustpower<24>(fSlow353))) + (1.5283966662112614e-19f * faustpower<26>(fSlow353))) + (6.223149226587858e-20f * faustpower<28>(fSlow353))))) / fSlow6));
		float 	fSlow356 = (fSlow355 * min(fSlow1, (0 - fSlow352)));
		float 	fSlow357 = (fConst61 * fSlow0);
		float 	fSlow358 = (0.01026806084463841f * sinf((0 - fSlow357)));
		float 	fSlow359 = (2.9493482397691277f * fSlow3);
		float 	fSlow360 = faustpower<2>(fSlow359);
		float 	fSlow361 = min(1.0f, ((1 + (fSlow360 * ((((((((((((((0.25f + (0.0625f * fSlow360)) + (0.006944444444444444f * faustpower<4>(fSlow359))) + (0.00043402777777777775f * faustpower<6>(fSlow359))) + (1.736111111111111e-05f * faustpower<8>(fSlow359))) + (4.822530864197531e-07f * faustpower<10>(fSlow359))) + (9.841899722852104e-09f * faustpower<12>(fSlow359))) + (1.5377968316956413e-10f * faustpower<14>(fSlow359))) + (1.898514607031656e-12f * faustpower<16>(fSlow359))) + (1.898514607031656e-14f * faustpower<18>(fSlow359))) + (1.5690203363897983e-16f * faustpower<20>(fSlow359))) + (1.0895974558262487e-18f * faustpower<22>(fSlow359))) + (6.697330183385451e-20f * faustpower<24>(fSlow359))) + (1.5283966662112614e-19f * faustpower<26>(fSlow359))) + (6.223149226587858e-20f * faustpower<28>(fSlow359))))) / fSlow6));
		float 	fSlow362 = (fSlow361 * min(fSlow1, (0 - fSlow358)));
		float 	fSlow363 = (fConst62 * fSlow0);
		float 	fSlow364 = (0.01061032953945969f * sinf((0 - fSlow363)));
		float 	fSlow365 = (2.961921958772244f * fSlow3);
		float 	fSlow366 = faustpower<2>(fSlow365);
		float 	fSlow367 = min(1.0f, ((1 + (fSlow366 * ((((((((((((((0.25f + (0.0625f * fSlow366)) + (0.006944444444444444f * faustpower<4>(fSlow365))) + (0.00043402777777777775f * faustpower<6>(fSlow365))) + (1.736111111111111e-05f * faustpower<8>(fSlow365))) + (4.822530864197531e-07f * faustpower<10>(fSlow365))) + (9.841899722852104e-09f * faustpower<12>(fSlow365))) + (1.5377968316956413e-10f * faustpower<14>(fSlow365))) + (1.898514607031656e-12f * faustpower<16>(fSlow365))) + (1.898514607031656e-14f * faustpower<18>(fSlow365))) + (1.5690203363897983e-16f * faustpower<20>(fSlow365))) + (1.0895974558262487e-18f * faustpower<22>(fSlow365))) + (6.697330183385451e-20f * faustpower<24>(fSlow365))) + (1.5283966662112614e-19f * faustpower<26>(fSlow365))) + (6.223149226587858e-20f * faustpower<28>(fSlow365))))) / fSlow6));
		float 	fSlow368 = (fSlow367 * min(fSlow1, (0 - fSlow364)));
		float 	fSlow369 = (fConst63 * fSlow0);
		float 	fSlow370 = (0.010976202971854851f * sinf((0 - fSlow369)));
		float 	fSlow371 = (2.974032851353002f * fSlow3);
		float 	fSlow372 = faustpower<2>(fSlow371);
		float 	fSlow373 = min(1.0f, ((1 + (fSlow372 * ((((((((((((((0.25f + (0.0625f * fSlow372)) + (0.006944444444444444f * faustpower<4>(fSlow371))) + (0.00043402777777777775f * faustpower<6>(fSlow371))) + (1.736111111111111e-05f * faustpower<8>(fSlow371))) + (4.822530864197531e-07f * faustpower<10>(fSlow371))) + (9.841899722852104e-09f * faustpower<12>(fSlow371))) + (1.5377968316956413e-10f * faustpower<14>(fSlow371))) + (1.898514607031656e-12f * faustpower<16>(fSlow371))) + (1.898514607031656e-14f * faustpower<18>(fSlow371))) + (1.5690203363897983e-16f * faustpower<20>(fSlow371))) + (1.0895974558262487e-18f * faustpower<22>(fSlow371))) + (6.697330183385451e-20f * faustpower<24>(fSlow371))) + (1.5283966662112614e-19f * faustpower<26>(fSlow371))) + (6.223149226587858e-20f * faustpower<28>(fSlow371))))) / fSlow6));
		float 	fSlow374 = (fSlow373 * min(fSlow1, (0 - fSlow370)));
		float 	fSlow375 = (fConst64 * fSlow0);
		float 	fSlow376 = (0.011368210220849667f * sinf((0 - fSlow375)));
		float 	fSlow377 = (2.9856865496294547f * fSlow3);
		float 	fSlow378 = faustpower<2>(fSlow377);
		float 	fSlow379 = min(1.0f, ((1 + (fSlow378 * ((((((((((((((0.25f + (0.0625f * fSlow378)) + (0.006944444444444444f * faustpower<4>(fSlow377))) + (0.00043402777777777775f * faustpower<6>(fSlow377))) + (1.736111111111111e-05f * faustpower<8>(fSlow377))) + (4.822530864197531e-07f * faustpower<10>(fSlow377))) + (9.841899722852104e-09f * faustpower<12>(fSlow377))) + (1.5377968316956413e-10f * faustpower<14>(fSlow377))) + (1.898514607031656e-12f * faustpower<16>(fSlow377))) + (1.898514607031656e-14f * faustpower<18>(fSlow377))) + (1.5690203363897983e-16f * faustpower<20>(fSlow377))) + (1.0895974558262487e-18f * faustpower<22>(fSlow377))) + (6.697330183385451e-20f * faustpower<24>(fSlow377))) + (1.5283966662112614e-19f * faustpower<26>(fSlow377))) + (6.223149226587858e-20f * faustpower<28>(fSlow377))))) / fSlow6));
		float 	fSlow380 = (fSlow379 * min(fSlow1, (0 - fSlow376)));
		float 	fSlow381 = (fConst65 * fSlow0);
		float 	fSlow382 = (0.0117892550438441f * sinf((0 - fSlow381)));
		float 	fSlow383 = (2.9968883871427905f * fSlow3);
		float 	fSlow384 = faustpower<2>(fSlow383);
		float 	fSlow385 = min(1.0f, ((1 + (fSlow384 * ((((((((((((((0.25f + (0.0625f * fSlow384)) + (0.006944444444444444f * faustpower<4>(fSlow383))) + (0.00043402777777777775f * faustpower<6>(fSlow383))) + (1.736111111111111e-05f * faustpower<8>(fSlow383))) + (4.822530864197531e-07f * faustpower<10>(fSlow383))) + (9.841899722852104e-09f * faustpower<12>(fSlow383))) + (1.5377968316956413e-10f * faustpower<14>(fSlow383))) + (1.898514607031656e-12f * faustpower<16>(fSlow383))) + (1.898514607031656e-14f * faustpower<18>(fSlow383))) + (1.5690203363897983e-16f * faustpower<20>(fSlow383))) + (1.0895974558262487e-18f * faustpower<22>(fSlow383))) + (6.697330183385451e-20f * faustpower<24>(fSlow383))) + (1.5283966662112614e-19f * faustpower<26>(fSlow383))) + (6.223149226587858e-20f * faustpower<28>(fSlow383))))) / fSlow6));
		float 	fSlow386 = (fSlow385 * min(fSlow1, (0 - fSlow382)));
		float 	fSlow387 = (fConst66 * fSlow0);
		float 	fSlow388 = (0.012242687930145794f * sinf((0 - fSlow387)));
		float 	fSlow389 = (3.0076434127047205f * fSlow3);
		float 	fSlow390 = faustpower<2>(fSlow389);
		float 	fSlow391 = min(1.0f, ((1 + (fSlow390 * ((((((((((((((0.25f + (0.0625f * fSlow390)) + (0.006944444444444444f * faustpower<4>(fSlow389))) + (0.00043402777777777775f * faustpower<6>(fSlow389))) + (1.736111111111111e-05f * faustpower<8>(fSlow389))) + (4.822530864197531e-07f * faustpower<10>(fSlow389))) + (9.841899722852104e-09f * faustpower<12>(fSlow389))) + (1.5377968316956413e-10f * faustpower<14>(fSlow389))) + (1.898514607031656e-12f * faustpower<16>(fSlow389))) + (1.898514607031656e-14f * faustpower<18>(fSlow389))) + (1.5690203363897983e-16f * faustpower<20>(fSlow389))) + (1.0895974558262487e-18f * faustpower<22>(fSlow389))) + (6.697330183385451e-20f * faustpower<24>(fSlow389))) + (1.5283966662112614e-19f * faustpower<26>(fSlow389))) + (6.223149226587858e-20f * faustpower<28>(fSlow389))))) / fSlow6));
		float 	fSlow392 = (fSlow391 * min(fSlow1, (0 - fSlow388)));
		float 	fSlow393 = (fConst67 * fSlow0);
		float 	fSlow394 = (0.012732395447351627f * sinf((0 - fSlow393)));
		float 	fSlow395 = (3.017956403201111f * fSlow3);
		float 	fSlow396 = faustpower<2>(fSlow395);
		float 	fSlow397 = min(1.0f, ((1 + (fSlow396 * ((((((((((((((0.25f + (0.0625f * fSlow396)) + (0.006944444444444444f * faustpower<4>(fSlow395))) + (0.00043402777777777775f * faustpower<6>(fSlow395))) + (1.736111111111111e-05f * faustpower<8>(fSlow395))) + (4.822530864197531e-07f * faustpower<10>(fSlow395))) + (9.841899722852104e-09f * faustpower<12>(fSlow395))) + (1.5377968316956413e-10f * faustpower<14>(fSlow395))) + (1.898514607031656e-12f * faustpower<16>(fSlow395))) + (1.898514607031656e-14f * faustpower<18>(fSlow395))) + (1.5690203363897983e-16f * faustpower<20>(fSlow395))) + (1.0895974558262487e-18f * faustpower<22>(fSlow395))) + (6.697330183385451e-20f * faustpower<24>(fSlow395))) + (1.5283966662112614e-19f * faustpower<26>(fSlow395))) + (6.223149226587858e-20f * faustpower<28>(fSlow395))))) / fSlow6));
		float 	fSlow398 = (fSlow397 * min(fSlow1, (0 - fSlow394)));
		float 	fSlow399 = (fConst68 * fSlow0);
		float 	fSlow400 = (0.013262911924324612f * sinf((0 - fSlow399)));
		float 	fSlow401 = (3.027831875435091f * fSlow3);
		float 	fSlow402 = faustpower<2>(fSlow401);
		float 	fSlow403 = min(1.0f, ((1 + (fSlow402 * ((((((((((((((0.25f + (0.0625f * fSlow402)) + (0.006944444444444444f * faustpower<4>(fSlow401))) + (0.00043402777777777775f * faustpower<6>(fSlow401))) + (1.736111111111111e-05f * faustpower<8>(fSlow401))) + (4.822530864197531e-07f * faustpower<10>(fSlow401))) + (9.841899722852104e-09f * faustpower<12>(fSlow401))) + (1.5377968316956413e-10f * faustpower<14>(fSlow401))) + (1.898514607031656e-12f * faustpower<16>(fSlow401))) + (1.898514607031656e-14f * faustpower<18>(fSlow401))) + (1.5690203363897983e-16f * faustpower<20>(fSlow401))) + (1.0895974558262487e-18f * faustpower<22>(fSlow401))) + (6.697330183385451e-20f * faustpower<24>(fSlow401))) + (1.5283966662112614e-19f * faustpower<26>(fSlow401))) + (6.223149226587858e-20f * faustpower<28>(fSlow401))))) / fSlow6));
		float 	fSlow404 = (fSlow403 * min(fSlow1, (0 - fSlow400)));
		float 	fSlow405 = (fConst69 * fSlow0);
		float 	fSlow406 = (0.013839560268860466f * sinf((0 - fSlow405)));
		float 	fSlow407 = (3.0372740970845356f * fSlow3);
		float 	fSlow408 = faustpower<2>(fSlow407);
		float 	fSlow409 = min(1.0f, ((1 + (fSlow408 * ((((((((((((((0.25f + (0.0625f * fSlow408)) + (0.006944444444444444f * faustpower<4>(fSlow407))) + (0.00043402777777777775f * faustpower<6>(fSlow407))) + (1.736111111111111e-05f * faustpower<8>(fSlow407))) + (4.822530864197531e-07f * faustpower<10>(fSlow407))) + (9.841899722852104e-09f * faustpower<12>(fSlow407))) + (1.5377968316956413e-10f * faustpower<14>(fSlow407))) + (1.898514607031656e-12f * faustpower<16>(fSlow407))) + (1.898514607031656e-14f * faustpower<18>(fSlow407))) + (1.5690203363897983e-16f * faustpower<20>(fSlow407))) + (1.0895974558262487e-18f * faustpower<22>(fSlow407))) + (6.697330183385451e-20f * faustpower<24>(fSlow407))) + (1.5283966662112614e-19f * faustpower<26>(fSlow407))) + (6.223149226587858e-20f * faustpower<28>(fSlow407))))) / fSlow6));
		float 	fSlow410 = (fSlow409 * min(fSlow1, (0 - fSlow406)));
		float 	fSlow411 = (fConst70 * fSlow0);
		float 	fSlow412 = (0.014468631190172306f * sinf((0 - fSlow411)));
		float 	fSlow413 = (3.046287096841381f * fSlow3);
		float 	fSlow414 = faustpower<2>(fSlow413);
		float 	fSlow415 = min(1.0f, ((1 + (fSlow414 * ((((((((((((((0.25f + (0.0625f * fSlow414)) + (0.006944444444444444f * faustpower<4>(fSlow413))) + (0.00043402777777777775f * faustpower<6>(fSlow413))) + (1.736111111111111e-05f * faustpower<8>(fSlow413))) + (4.822530864197531e-07f * faustpower<10>(fSlow413))) + (9.841899722852104e-09f * faustpower<12>(fSlow413))) + (1.5377968316956413e-10f * faustpower<14>(fSlow413))) + (1.898514607031656e-12f * faustpower<16>(fSlow413))) + (1.898514607031656e-14f * faustpower<18>(fSlow413))) + (1.5690203363897983e-16f * faustpower<20>(fSlow413))) + (1.0895974558262487e-18f * faustpower<22>(fSlow413))) + (6.697330183385451e-20f * faustpower<24>(fSlow413))) + (1.5283966662112614e-19f * faustpower<26>(fSlow413))) + (6.223149226587858e-20f * faustpower<28>(fSlow413))))) / fSlow6));
		float 	fSlow416 = (fSlow415 * min(fSlow1, (0 - fSlow412)));
		float 	fSlow417 = (fConst71 * fSlow0);
		float 	fSlow418 = (0.015157613627799556f * sinf((0 - fSlow417)));
		float 	fSlow419 = (3.054874673793608f * fSlow3);
		float 	fSlow420 = faustpower<2>(fSlow419);
		float 	fSlow421 = min(1.0f, ((1 + (fSlow420 * ((((((((((((((0.25f + (0.0625f * fSlow420)) + (0.006944444444444444f * faustpower<4>(fSlow419))) + (0.00043402777777777775f * faustpower<6>(fSlow419))) + (1.736111111111111e-05f * faustpower<8>(fSlow419))) + (4.822530864197531e-07f * faustpower<10>(fSlow419))) + (9.841899722852104e-09f * faustpower<12>(fSlow419))) + (1.5377968316956413e-10f * faustpower<14>(fSlow419))) + (1.898514607031656e-12f * faustpower<16>(fSlow419))) + (1.898514607031656e-14f * faustpower<18>(fSlow419))) + (1.5690203363897983e-16f * faustpower<20>(fSlow419))) + (1.0895974558262487e-18f * faustpower<22>(fSlow419))) + (6.697330183385451e-20f * faustpower<24>(fSlow419))) + (1.5283966662112614e-19f * faustpower<26>(fSlow419))) + (6.223149226587858e-20f * faustpower<28>(fSlow419))))) / fSlow6));
		float 	fSlow422 = (fSlow421 * min(fSlow1, (0 - fSlow418)));
		float 	fSlow423 = (fConst72 * fSlow0);
		float 	fSlow424 = (0.015915494309189534f * sinf((0 - fSlow423)));
		float 	fSlow425 = (3.0630404061047947f * fSlow3);
		float 	fSlow426 = faustpower<2>(fSlow425);
		float 	fSlow427 = min(1.0f, ((1 + (fSlow426 * ((((((((((((((0.25f + (0.0625f * fSlow426)) + (0.006944444444444444f * faustpower<4>(fSlow425))) + (0.00043402777777777775f * faustpower<6>(fSlow425))) + (1.736111111111111e-05f * faustpower<8>(fSlow425))) + (4.822530864197531e-07f * faustpower<10>(fSlow425))) + (9.841899722852104e-09f * faustpower<12>(fSlow425))) + (1.5377968316956413e-10f * faustpower<14>(fSlow425))) + (1.898514607031656e-12f * faustpower<16>(fSlow425))) + (1.898514607031656e-14f * faustpower<18>(fSlow425))) + (1.5690203363897983e-16f * faustpower<20>(fSlow425))) + (1.0895974558262487e-18f * faustpower<22>(fSlow425))) + (6.697330183385451e-20f * faustpower<24>(fSlow425))) + (1.5283966662112614e-19f * faustpower<26>(fSlow425))) + (6.223149226587858e-20f * faustpower<28>(fSlow425))))) / fSlow6));
		float 	fSlow428 = (fSlow427 * min(fSlow1, (0 - fSlow424)));
		float 	fSlow429 = (fConst73 * fSlow0);
		float 	fSlow430 = (0.016753151904410037f * sinf((0 - fSlow429)));
		float 	fSlow431 = (3.070787659040812f * fSlow3);
		float 	fSlow432 = faustpower<2>(fSlow431);
		float 	fSlow433 = min(1.0f, ((1 + (fSlow432 * ((((((((((((((0.25f + (0.0625f * fSlow432)) + (0.006944444444444444f * faustpower<4>(fSlow431))) + (0.00043402777777777775f * faustpower<6>(fSlow431))) + (1.736111111111111e-05f * faustpower<8>(fSlow431))) + (4.822530864197531e-07f * faustpower<10>(fSlow431))) + (9.841899722852104e-09f * faustpower<12>(fSlow431))) + (1.5377968316956413e-10f * faustpower<14>(fSlow431))) + (1.898514607031656e-12f * faustpower<16>(fSlow431))) + (1.898514607031656e-14f * faustpower<18>(fSlow431))) + (1.5690203363897983e-16f * faustpower<20>(fSlow431))) + (1.0895974558262487e-18f * faustpower<22>(fSlow431))) + (6.697330183385451e-20f * faustpower<24>(fSlow431))) + (1.5283966662112614e-19f * faustpower<26>(fSlow431))) + (6.223149226587858e-20f * faustpower<28>(fSlow431))))) / fSlow6));
		float 	fSlow434 = (fSlow433 * min(fSlow1, (0 - fSlow430)));
		float 	fSlow435 = (fConst74 * fSlow0);
		float 	fSlow436 = (0.01768388256576615f * sinf((0 - fSlow435)));
		float 	fSlow437 = (3.0781195923884734f * fSlow3);
		float 	fSlow438 = faustpower<2>(fSlow437);
		float 	fSlow439 = min(1.0f, ((1 + (fSlow438 * ((((((((((((((0.25f + (0.0625f * fSlow438)) + (0.006944444444444444f * faustpower<4>(fSlow437))) + (0.00043402777777777775f * faustpower<6>(fSlow437))) + (1.736111111111111e-05f * faustpower<8>(fSlow437))) + (4.822530864197531e-07f * faustpower<10>(fSlow437))) + (9.841899722852104e-09f * faustpower<12>(fSlow437))) + (1.5377968316956413e-10f * faustpower<14>(fSlow437))) + (1.898514607031656e-12f * faustpower<16>(fSlow437))) + (1.898514607031656e-14f * faustpower<18>(fSlow437))) + (1.5690203363897983e-16f * faustpower<20>(fSlow437))) + (1.0895974558262487e-18f * faustpower<22>(fSlow437))) + (6.697330183385451e-20f * faustpower<24>(fSlow437))) + (1.5283966662112614e-19f * faustpower<26>(fSlow437))) + (6.223149226587858e-20f * faustpower<28>(fSlow437))))) / fSlow6));
		float 	fSlow440 = (fSlow439 * min(fSlow1, (0 - fSlow436)));
		float 	fSlow441 = (fConst75 * fSlow0);
		float 	fSlow442 = (0.018724110951987685f * sinf((0 - fSlow441)));
		float 	fSlow443 = (3.0850391673066198f * fSlow3);
		float 	fSlow444 = faustpower<2>(fSlow443);
		float 	fSlow445 = min(1.0f, ((1 + (fSlow444 * ((((((((((((((0.25f + (0.0625f * fSlow444)) + (0.006944444444444444f * faustpower<4>(fSlow443))) + (0.00043402777777777775f * faustpower<6>(fSlow443))) + (1.736111111111111e-05f * faustpower<8>(fSlow443))) + (4.822530864197531e-07f * faustpower<10>(fSlow443))) + (9.841899722852104e-09f * faustpower<12>(fSlow443))) + (1.5377968316956413e-10f * faustpower<14>(fSlow443))) + (1.898514607031656e-12f * faustpower<16>(fSlow443))) + (1.898514607031656e-14f * faustpower<18>(fSlow443))) + (1.5690203363897983e-16f * faustpower<20>(fSlow443))) + (1.0895974558262487e-18f * faustpower<22>(fSlow443))) + (6.697330183385451e-20f * faustpower<24>(fSlow443))) + (1.5283966662112614e-19f * faustpower<26>(fSlow443))) + (6.223149226587858e-20f * faustpower<28>(fSlow443))))) / fSlow6));
		float 	fSlow446 = (fSlow445 * min(fSlow1, (0 - fSlow442)));
		float 	fSlow447 = (fConst76 * fSlow0);
		float 	fSlow448 = (0.019894367886486918f * sinf((0 - fSlow447)));
		float 	fSlow449 = (3.0915491526462535f * fSlow3);
		float 	fSlow450 = faustpower<2>(fSlow449);
		float 	fSlow451 = min(1.0f, ((1 + (fSlow450 * ((((((((((((((0.25f + (0.0625f * fSlow450)) + (0.006944444444444444f * faustpower<4>(fSlow449))) + (0.00043402777777777775f * faustpower<6>(fSlow449))) + (1.736111111111111e-05f * faustpower<8>(fSlow449))) + (4.822530864197531e-07f * faustpower<10>(fSlow449))) + (9.841899722852104e-09f * faustpower<12>(fSlow449))) + (1.5377968316956413e-10f * faustpower<14>(fSlow449))) + (1.898514607031656e-12f * faustpower<16>(fSlow449))) + (1.898514607031656e-14f * faustpower<18>(fSlow449))) + (1.5690203363897983e-16f * faustpower<20>(fSlow449))) + (1.0895974558262487e-18f * faustpower<22>(fSlow449))) + (6.697330183385451e-20f * faustpower<24>(fSlow449))) + (1.5283966662112614e-19f * faustpower<26>(fSlow449))) + (6.223149226587858e-20f * faustpower<28>(fSlow449))))) / fSlow6));
		float 	fSlow452 = (fSlow451 * min(fSlow1, (0 - fSlow448)));
		float 	fSlow453 = (fConst77 * fSlow0);
		float 	fSlow454 = (0.02122065907891938f * sinf((0 - fSlow453)));
		float 	fSlow455 = (3.0976521307728087f * fSlow3);
		float 	fSlow456 = faustpower<2>(fSlow455);
		float 	fSlow457 = min(1.0f, ((1 + (fSlow456 * ((((((((((((((0.25f + (0.0625f * fSlow456)) + (0.006944444444444444f * faustpower<4>(fSlow455))) + (0.00043402777777777775f * faustpower<6>(fSlow455))) + (1.736111111111111e-05f * faustpower<8>(fSlow455))) + (4.822530864197531e-07f * faustpower<10>(fSlow455))) + (9.841899722852104e-09f * faustpower<12>(fSlow455))) + (1.5377968316956413e-10f * faustpower<14>(fSlow455))) + (1.898514607031656e-12f * faustpower<16>(fSlow455))) + (1.898514607031656e-14f * faustpower<18>(fSlow455))) + (1.5690203363897983e-16f * faustpower<20>(fSlow455))) + (1.0895974558262487e-18f * faustpower<22>(fSlow455))) + (6.697330183385451e-20f * faustpower<24>(fSlow455))) + (1.5283966662112614e-19f * faustpower<26>(fSlow455))) + (6.223149226587858e-20f * faustpower<28>(fSlow455))))) / fSlow6));
		float 	fSlow458 = (fSlow457 * min(fSlow1, (0 - fSlow454)));
		float 	fSlow459 = (fConst78 * fSlow0);
		float 	fSlow460 = (0.022736420441699334f * sinf((0 - fSlow459)));
		float 	fSlow461 = (3.103350502920445f * fSlow3);
		float 	fSlow462 = faustpower<2>(fSlow461);
		float 	fSlow463 = min(1.0f, ((1 + (fSlow462 * ((((((((((((((0.25f + (0.0625f * fSlow462)) + (0.006944444444444444f * faustpower<4>(fSlow461))) + (0.00043402777777777775f * faustpower<6>(fSlow461))) + (1.736111111111111e-05f * faustpower<8>(fSlow461))) + (4.822530864197531e-07f * faustpower<10>(fSlow461))) + (9.841899722852104e-09f * faustpower<12>(fSlow461))) + (1.5377968316956413e-10f * faustpower<14>(fSlow461))) + (1.898514607031656e-12f * faustpower<16>(fSlow461))) + (1.898514607031656e-14f * faustpower<18>(fSlow461))) + (1.5690203363897983e-16f * faustpower<20>(fSlow461))) + (1.0895974558262487e-18f * faustpower<22>(fSlow461))) + (6.697330183385451e-20f * faustpower<24>(fSlow461))) + (1.5283966662112614e-19f * faustpower<26>(fSlow461))) + (6.223149226587858e-20f * faustpower<28>(fSlow461))))) / fSlow6));
		float 	fSlow464 = (fSlow463 * min(fSlow1, (0 - fSlow460)));
		float 	fSlow465 = (fConst79 * fSlow0);
		float 	fSlow466 = (0.024485375860291588f * sinf((0 - fSlow465)));
		float 	fSlow467 = (3.1086464941053595f * fSlow3);
		float 	fSlow468 = faustpower<2>(fSlow467);
		float 	fSlow469 = min(1.0f, ((1 + (fSlow468 * ((((((((((((((0.25f + (0.0625f * fSlow468)) + (0.006944444444444444f * faustpower<4>(fSlow467))) + (0.00043402777777777775f * faustpower<6>(fSlow467))) + (1.736111111111111e-05f * faustpower<8>(fSlow467))) + (4.822530864197531e-07f * faustpower<10>(fSlow467))) + (9.841899722852104e-09f * faustpower<12>(fSlow467))) + (1.5377968316956413e-10f * faustpower<14>(fSlow467))) + (1.898514607031656e-12f * faustpower<16>(fSlow467))) + (1.898514607031656e-14f * faustpower<18>(fSlow467))) + (1.5690203363897983e-16f * faustpower<20>(fSlow467))) + (1.0895974558262487e-18f * faustpower<22>(fSlow467))) + (6.697330183385451e-20f * faustpower<24>(fSlow467))) + (1.5283966662112614e-19f * faustpower<26>(fSlow467))) + (6.223149226587858e-20f * faustpower<28>(fSlow467))))) / fSlow6));
		float 	fSlow470 = (fSlow469 * min(fSlow1, (0 - fSlow466)));
		float 	fSlow471 = (fConst80 * fSlow0);
		float 	fSlow472 = (0.026525823848649224f * sinf((0 - fSlow471)));
		float 	fSlow473 = (3.1135421576224425f * fSlow3);
		float 	fSlow474 = faustpower<2>(fSlow473);
		float 	fSlow475 = min(1.0f, ((1 + (fSlow474 * ((((((((((((((0.25f + (0.0625f * fSlow474)) + (0.006944444444444444f * faustpower<4>(fSlow473))) + (0.00043402777777777775f * faustpower<6>(fSlow473))) + (1.736111111111111e-05f * faustpower<8>(fSlow473))) + (4.822530864197531e-07f * faustpower<10>(fSlow473))) + (9.841899722852104e-09f * faustpower<12>(fSlow473))) + (1.5377968316956413e-10f * faustpower<14>(fSlow473))) + (1.898514607031656e-12f * faustpower<16>(fSlow473))) + (1.898514607031656e-14f * faustpower<18>(fSlow473))) + (1.5690203363897983e-16f * faustpower<20>(fSlow473))) + (1.0895974558262487e-18f * faustpower<22>(fSlow473))) + (6.697330183385451e-20f * faustpower<24>(fSlow473))) + (1.5283966662112614e-19f * faustpower<26>(fSlow473))) + (6.223149226587858e-20f * faustpower<28>(fSlow473))))) / fSlow6));
		float 	fSlow476 = (fSlow475 * min(fSlow1, (0 - fSlow472)));
		float 	fSlow477 = (fConst81 * fSlow0);
		float 	fSlow478 = (0.028937262380344612f * sinf((0 - fSlow477)));
		float 	fSlow479 = (3.1180393791471896f * fSlow3);
		float 	fSlow480 = faustpower<2>(fSlow479);
		float 	fSlow481 = min(1.0f, ((1 + (fSlow480 * ((((((((((((((0.25f + (0.0625f * fSlow480)) + (0.006944444444444444f * faustpower<4>(fSlow479))) + (0.00043402777777777775f * faustpower<6>(fSlow479))) + (1.736111111111111e-05f * faustpower<8>(fSlow479))) + (4.822530864197531e-07f * faustpower<10>(fSlow479))) + (9.841899722852104e-09f * faustpower<12>(fSlow479))) + (1.5377968316956413e-10f * faustpower<14>(fSlow479))) + (1.898514607031656e-12f * faustpower<16>(fSlow479))) + (1.898514607031656e-14f * faustpower<18>(fSlow479))) + (1.5690203363897983e-16f * faustpower<20>(fSlow479))) + (1.0895974558262487e-18f * faustpower<22>(fSlow479))) + (6.697330183385451e-20f * faustpower<24>(fSlow479))) + (1.5283966662112614e-19f * faustpower<26>(fSlow479))) + (6.223149226587858e-20f * faustpower<28>(fSlow479))))) / fSlow6));
		float 	fSlow482 = (fSlow481 * min(fSlow1, (0 - fSlow478)));
		float 	fSlow483 = (fConst82 * fSlow0);
		float 	fSlow484 = (0.03183098861837907f * sinf((0 - fSlow483)));
		float 	fSlow485 = (3.122139880462545f * fSlow3);
		float 	fSlow486 = faustpower<2>(fSlow485);
		float 	fSlow487 = min(1.0f, ((1 + (fSlow486 * ((((((((((((((0.25f + (0.0625f * fSlow486)) + (0.006944444444444444f * faustpower<4>(fSlow485))) + (0.00043402777777777775f * faustpower<6>(fSlow485))) + (1.736111111111111e-05f * faustpower<8>(fSlow485))) + (4.822530864197531e-07f * faustpower<10>(fSlow485))) + (9.841899722852104e-09f * faustpower<12>(fSlow485))) + (1.5377968316956413e-10f * faustpower<14>(fSlow485))) + (1.898514607031656e-12f * faustpower<16>(fSlow485))) + (1.898514607031656e-14f * faustpower<18>(fSlow485))) + (1.5690203363897983e-16f * faustpower<20>(fSlow485))) + (1.0895974558262487e-18f * faustpower<22>(fSlow485))) + (6.697330183385451e-20f * faustpower<24>(fSlow485))) + (1.5283966662112614e-19f * faustpower<26>(fSlow485))) + (6.223149226587858e-20f * faustpower<28>(fSlow485))))) / fSlow6));
		float 	fSlow488 = (fSlow487 * min(fSlow1, (0 - fSlow484)));
		float 	fSlow489 = (fConst83 * fSlow0);
		float 	fSlow490 = (0.0353677651315323f * sinf((0 - fSlow489)));
		float 	fSlow491 = (3.1258452228282936f * fSlow3);
		float 	fSlow492 = faustpower<2>(fSlow491);
		float 	fSlow493 = min(1.0f, ((1 + (fSlow492 * ((((((((((((((0.25f + (0.0625f * fSlow492)) + (0.006944444444444444f * faustpower<4>(fSlow491))) + (0.00043402777777777775f * faustpower<6>(fSlow491))) + (1.736111111111111e-05f * faustpower<8>(fSlow491))) + (4.822530864197531e-07f * faustpower<10>(fSlow491))) + (9.841899722852104e-09f * faustpower<12>(fSlow491))) + (1.5377968316956413e-10f * faustpower<14>(fSlow491))) + (1.898514607031656e-12f * faustpower<16>(fSlow491))) + (1.898514607031656e-14f * faustpower<18>(fSlow491))) + (1.5690203363897983e-16f * faustpower<20>(fSlow491))) + (1.0895974558262487e-18f * faustpower<22>(fSlow491))) + (6.697330183385451e-20f * faustpower<24>(fSlow491))) + (1.5283966662112614e-19f * faustpower<26>(fSlow491))) + (6.223149226587858e-20f * faustpower<28>(fSlow491))))) / fSlow6));
		float 	fSlow494 = (fSlow493 * min(fSlow1, (0 - fSlow490)));
		float 	fSlow495 = (fConst84 * fSlow0);
		float 	fSlow496 = (0.039788735772973836f * sinf((0 - fSlow495)));
		float 	fSlow497 = (3.129156810008722f * fSlow3);
		float 	fSlow498 = faustpower<2>(fSlow497);
		float 	fSlow499 = min(1.0f, ((1 + (fSlow498 * ((((((((((((((0.25f + (0.0625f * fSlow498)) + (0.006944444444444444f * faustpower<4>(fSlow497))) + (0.00043402777777777775f * faustpower<6>(fSlow497))) + (1.736111111111111e-05f * faustpower<8>(fSlow497))) + (4.822530864197531e-07f * faustpower<10>(fSlow497))) + (9.841899722852104e-09f * faustpower<12>(fSlow497))) + (1.5377968316956413e-10f * faustpower<14>(fSlow497))) + (1.898514607031656e-12f * faustpower<16>(fSlow497))) + (1.898514607031656e-14f * faustpower<18>(fSlow497))) + (1.5690203363897983e-16f * faustpower<20>(fSlow497))) + (1.0895974558262487e-18f * faustpower<22>(fSlow497))) + (6.697330183385451e-20f * faustpower<24>(fSlow497))) + (1.5283966662112614e-19f * faustpower<26>(fSlow497))) + (6.223149226587858e-20f * faustpower<28>(fSlow497))))) / fSlow6));
		float 	fSlow500 = (fSlow499 * min(fSlow1, (0 - fSlow496)));
		float 	fSlow501 = (fConst85 * fSlow0);
		float 	fSlow502 = (0.04547284088339867f * sinf((0 - fSlow501)));
		float 	fSlow503 = (3.1320758909724975f * fSlow3);
		float 	fSlow504 = faustpower<2>(fSlow503);
		float 	fSlow505 = min(1.0f, ((1 + (fSlow504 * ((((((((((((((0.25f + (0.0625f * fSlow504)) + (0.006944444444444444f * faustpower<4>(fSlow503))) + (0.00043402777777777775f * faustpower<6>(fSlow503))) + (1.736111111111111e-05f * faustpower<8>(fSlow503))) + (4.822530864197531e-07f * faustpower<10>(fSlow503))) + (9.841899722852104e-09f * faustpower<12>(fSlow503))) + (1.5377968316956413e-10f * faustpower<14>(fSlow503))) + (1.898514607031656e-12f * faustpower<16>(fSlow503))) + (1.898514607031656e-14f * faustpower<18>(fSlow503))) + (1.5690203363897983e-16f * faustpower<20>(fSlow503))) + (1.0895974558262487e-18f * faustpower<22>(fSlow503))) + (6.697330183385451e-20f * faustpower<24>(fSlow503))) + (1.5283966662112614e-19f * faustpower<26>(fSlow503))) + (6.223149226587858e-20f * faustpower<28>(fSlow503))))) / fSlow6));
		float 	fSlow506 = (fSlow505 * min(fSlow1, (0 - fSlow502)));
		float 	fSlow507 = (fConst86 * fSlow0);
		float 	fSlow508 = (0.05305164769729845f * sinf((0 - fSlow507)));
		float 	fSlow509 = (3.134603562277066f * fSlow3);
		float 	fSlow510 = faustpower<2>(fSlow509);
		float 	fSlow511 = min(1.0f, ((1 + (fSlow510 * ((((((((((((((0.25f + (0.0625f * fSlow510)) + (0.006944444444444444f * faustpower<4>(fSlow509))) + (0.00043402777777777775f * faustpower<6>(fSlow509))) + (1.736111111111111e-05f * faustpower<8>(fSlow509))) + (4.822530864197531e-07f * faustpower<10>(fSlow509))) + (9.841899722852104e-09f * faustpower<12>(fSlow509))) + (1.5377968316956413e-10f * faustpower<14>(fSlow509))) + (1.898514607031656e-12f * faustpower<16>(fSlow509))) + (1.898514607031656e-14f * faustpower<18>(fSlow509))) + (1.5690203363897983e-16f * faustpower<20>(fSlow509))) + (1.0895974558262487e-18f * faustpower<22>(fSlow509))) + (6.697330183385451e-20f * faustpower<24>(fSlow509))) + (1.5283966662112614e-19f * faustpower<26>(fSlow509))) + (6.223149226587858e-20f * faustpower<28>(fSlow509))))) / fSlow6));
		float 	fSlow512 = (fSlow511 * min(fSlow1, (0 - fSlow508)));
		float 	fSlow513 = (fConst87 * fSlow0);
		float 	fSlow514 = (0.06366197723675814f * sinf((0 - fSlow513)));
		float 	fSlow515 = (3.136740770148322f * fSlow3);
		float 	fSlow516 = faustpower<2>(fSlow515);
		float 	fSlow517 = min(1.0f, ((1 + (fSlow516 * ((((((((((((((0.25f + (0.0625f * fSlow516)) + (0.006944444444444444f * faustpower<4>(fSlow515))) + (0.00043402777777777775f * faustpower<6>(fSlow515))) + (1.736111111111111e-05f * faustpower<8>(fSlow515))) + (4.822530864197531e-07f * faustpower<10>(fSlow515))) + (9.841899722852104e-09f * faustpower<12>(fSlow515))) + (1.5377968316956413e-10f * faustpower<14>(fSlow515))) + (1.898514607031656e-12f * faustpower<16>(fSlow515))) + (1.898514607031656e-14f * faustpower<18>(fSlow515))) + (1.5690203363897983e-16f * faustpower<20>(fSlow515))) + (1.0895974558262487e-18f * faustpower<22>(fSlow515))) + (6.697330183385451e-20f * faustpower<24>(fSlow515))) + (1.5283966662112614e-19f * faustpower<26>(fSlow515))) + (6.223149226587858e-20f * faustpower<28>(fSlow515))))) / fSlow6));
		float 	fSlow518 = (fSlow517 * min(fSlow1, (0 - fSlow514)));
		float 	fSlow519 = (fConst88 * fSlow0);
		float 	fSlow520 = (0.07957747154594767f * sinf((0 - fSlow519)));
		float 	fSlow521 = (3.138488312264841f * fSlow3);
		float 	fSlow522 = faustpower<2>(fSlow521);
		float 	fSlow523 = min(1.0f, ((1 + (fSlow522 * ((((((((((((((0.25f + (0.0625f * fSlow522)) + (0.006944444444444444f * faustpower<4>(fSlow521))) + (0.00043402777777777775f * faustpower<6>(fSlow521))) + (1.736111111111111e-05f * faustpower<8>(fSlow521))) + (4.822530864197531e-07f * faustpower<10>(fSlow521))) + (9.841899722852104e-09f * faustpower<12>(fSlow521))) + (1.5377968316956413e-10f * faustpower<14>(fSlow521))) + (1.898514607031656e-12f * faustpower<16>(fSlow521))) + (1.898514607031656e-14f * faustpower<18>(fSlow521))) + (1.5690203363897983e-16f * faustpower<20>(fSlow521))) + (1.0895974558262487e-18f * faustpower<22>(fSlow521))) + (6.697330183385451e-20f * faustpower<24>(fSlow521))) + (1.5283966662112614e-19f * faustpower<26>(fSlow521))) + (6.223149226587858e-20f * faustpower<28>(fSlow521))))) / fSlow6));
		float 	fSlow524 = (fSlow523 * min(fSlow1, (0 - fSlow520)));
		float 	fSlow525 = (fConst89 * fSlow0);
		float 	fSlow526 = (0.1061032953945969f * sinf((0 - fSlow525)));
		float 	fSlow527 = (3.1398468392545897f * fSlow3);
		float 	fSlow528 = faustpower<2>(fSlow527);
		float 	fSlow529 = min(1.0f, ((1 + (fSlow528 * ((((((((((((((0.25f + (0.0625f * fSlow528)) + (0.006944444444444444f * faustpower<4>(fSlow527))) + (0.00043402777777777775f * faustpower<6>(fSlow527))) + (1.736111111111111e-05f * faustpower<8>(fSlow527))) + (4.822530864197531e-07f * faustpower<10>(fSlow527))) + (9.841899722852104e-09f * faustpower<12>(fSlow527))) + (1.5377968316956413e-10f * faustpower<14>(fSlow527))) + (1.898514607031656e-12f * faustpower<16>(fSlow527))) + (1.898514607031656e-14f * faustpower<18>(fSlow527))) + (1.5690203363897983e-16f * faustpower<20>(fSlow527))) + (1.0895974558262487e-18f * faustpower<22>(fSlow527))) + (6.697330183385451e-20f * faustpower<24>(fSlow527))) + (1.5283966662112614e-19f * faustpower<26>(fSlow527))) + (6.223149226587858e-20f * faustpower<28>(fSlow527))))) / fSlow6));
		float 	fSlow530 = (fSlow529 * min(fSlow1, (0 - fSlow526)));
		float 	fSlow531 = (fConst90 * fSlow0);
		float 	fSlow532 = (0.15915494309189535f * sinf((0 - fSlow531)));
		float 	fSlow533 = (3.1408168559106993f * fSlow3);
		float 	fSlow534 = faustpower<2>(fSlow533);
		float 	fSlow535 = min(1.0f, ((1 + (fSlow534 * ((((((((((((((0.25f + (0.0625f * fSlow534)) + (0.006944444444444444f * faustpower<4>(fSlow533))) + (0.00043402777777777775f * faustpower<6>(fSlow533))) + (1.736111111111111e-05f * faustpower<8>(fSlow533))) + (4.822530864197531e-07f * faustpower<10>(fSlow533))) + (9.841899722852104e-09f * faustpower<12>(fSlow533))) + (1.5377968316956413e-10f * faustpower<14>(fSlow533))) + (1.898514607031656e-12f * faustpower<16>(fSlow533))) + (1.898514607031656e-14f * faustpower<18>(fSlow533))) + (1.5690203363897983e-16f * faustpower<20>(fSlow533))) + (1.0895974558262487e-18f * faustpower<22>(fSlow533))) + (6.697330183385451e-20f * faustpower<24>(fSlow533))) + (1.5283966662112614e-19f * faustpower<26>(fSlow533))) + (6.223149226587858e-20f * faustpower<28>(fSlow533))))) / fSlow6));
		float 	fSlow536 = (fSlow535 * min(fSlow1, (0 - fSlow532)));
		float 	fSlow537 = (fConst91 * fSlow0);
		float 	fSlow538 = (0.3183098861837907f * sinf((0 - fSlow537)));
		float 	fSlow539 = (3.1413987221316257f * fSlow3);
		float 	fSlow540 = faustpower<2>(fSlow539);
		float 	fSlow541 = min(1.0f, ((1 + (fSlow540 * ((((((((((((((0.25f + (0.0625f * fSlow540)) + (0.006944444444444444f * faustpower<4>(fSlow539))) + (0.00043402777777777775f * faustpower<6>(fSlow539))) + (1.736111111111111e-05f * faustpower<8>(fSlow539))) + (4.822530864197531e-07f * faustpower<10>(fSlow539))) + (9.841899722852104e-09f * faustpower<12>(fSlow539))) + (1.5377968316956413e-10f * faustpower<14>(fSlow539))) + (1.898514607031656e-12f * faustpower<16>(fSlow539))) + (1.898514607031656e-14f * faustpower<18>(fSlow539))) + (1.5690203363897983e-16f * faustpower<20>(fSlow539))) + (1.0895974558262487e-18f * faustpower<22>(fSlow539))) + (6.697330183385451e-20f * faustpower<24>(fSlow539))) + (1.5283966662112614e-19f * faustpower<26>(fSlow539))) + (6.223149226587858e-20f * faustpower<28>(fSlow539))))) / fSlow6));
		float 	fSlow542 = (fSlow541 * min(fSlow1, (0 - fSlow538)));
		float 	fSlow543 = min(fSlow1, fSlow1);
		float 	fSlow544 = (0.3183098861837907f * sinf(fSlow537));
		float 	fSlow545 = (fSlow541 * min(fSlow1, fSlow544));
		float 	fSlow546 = (0.15915494309189535f * sinf(fSlow531));
		float 	fSlow547 = (fSlow535 * min(fSlow1, fSlow546));
		float 	fSlow548 = (0.1061032953945969f * sinf(fSlow525));
		float 	fSlow549 = (fSlow529 * min(fSlow1, fSlow548));
		float 	fSlow550 = (0.07957747154594767f * sinf(fSlow519));
		float 	fSlow551 = (fSlow523 * min(fSlow1, fSlow550));
		float 	fSlow552 = (0.06366197723675814f * sinf(fSlow513));
		float 	fSlow553 = (fSlow517 * min(fSlow1, fSlow552));
		float 	fSlow554 = (0.05305164769729845f * sinf(fSlow507));
		float 	fSlow555 = (fSlow511 * min(fSlow1, fSlow554));
		float 	fSlow556 = (0.04547284088339867f * sinf(fSlow501));
		float 	fSlow557 = (fSlow505 * min(fSlow1, fSlow556));
		float 	fSlow558 = (0.039788735772973836f * sinf(fSlow495));
		float 	fSlow559 = (fSlow499 * min(fSlow1, fSlow558));
		float 	fSlow560 = (0.0353677651315323f * sinf(fSlow489));
		float 	fSlow561 = (fSlow493 * min(fSlow1, fSlow560));
		float 	fSlow562 = (0.03183098861837907f * sinf(fSlow483));
		float 	fSlow563 = (fSlow487 * min(fSlow1, fSlow562));
		float 	fSlow564 = (0.028937262380344612f * sinf(fSlow477));
		float 	fSlow565 = (fSlow481 * min(fSlow1, fSlow564));
		float 	fSlow566 = (0.026525823848649224f * sinf(fSlow471));
		float 	fSlow567 = (fSlow475 * min(fSlow1, fSlow566));
		float 	fSlow568 = (0.024485375860291588f * sinf(fSlow465));
		float 	fSlow569 = (fSlow469 * min(fSlow1, fSlow568));
		float 	fSlow570 = (0.022736420441699334f * sinf(fSlow459));
		float 	fSlow571 = (fSlow463 * min(fSlow1, fSlow570));
		float 	fSlow572 = (0.02122065907891938f * sinf(fSlow453));
		float 	fSlow573 = (fSlow457 * min(fSlow1, fSlow572));
		float 	fSlow574 = (0.019894367886486918f * sinf(fSlow447));
		float 	fSlow575 = (fSlow451 * min(fSlow1, fSlow574));
		float 	fSlow576 = (0.018724110951987685f * sinf(fSlow441));
		float 	fSlow577 = (fSlow445 * min(fSlow1, fSlow576));
		float 	fSlow578 = (0.01768388256576615f * sinf(fSlow435));
		float 	fSlow579 = (fSlow439 * min(fSlow1, fSlow578));
		float 	fSlow580 = (0.016753151904410037f * sinf(fSlow429));
		float 	fSlow581 = (fSlow433 * min(fSlow1, fSlow580));
		float 	fSlow582 = (0.015915494309189534f * sinf(fSlow423));
		float 	fSlow583 = (fSlow427 * min(fSlow1, fSlow582));
		float 	fSlow584 = (0.015157613627799556f * sinf(fSlow417));
		float 	fSlow585 = (fSlow421 * min(fSlow1, fSlow584));
		float 	fSlow586 = (0.014468631190172306f * sinf(fSlow411));
		float 	fSlow587 = (fSlow415 * min(fSlow1, fSlow586));
		float 	fSlow588 = (0.013839560268860466f * sinf(fSlow405));
		float 	fSlow589 = (fSlow409 * min(fSlow1, fSlow588));
		float 	fSlow590 = (0.013262911924324612f * sinf(fSlow399));
		float 	fSlow591 = (fSlow403 * min(fSlow1, fSlow590));
		float 	fSlow592 = (0.012732395447351627f * sinf(fSlow393));
		float 	fSlow593 = (fSlow397 * min(fSlow1, fSlow592));
		float 	fSlow594 = (0.012242687930145794f * sinf(fSlow387));
		float 	fSlow595 = (fSlow391 * min(fSlow1, fSlow594));
		float 	fSlow596 = (0.0117892550438441f * sinf(fSlow381));
		float 	fSlow597 = (fSlow385 * min(fSlow1, fSlow596));
		float 	fSlow598 = (0.011368210220849667f * sinf(fSlow375));
		float 	fSlow599 = (fSlow379 * min(fSlow1, fSlow598));
		float 	fSlow600 = (0.010976202971854851f * sinf(fSlow369));
		float 	fSlow601 = (fSlow373 * min(fSlow1, fSlow600));
		float 	fSlow602 = (0.01061032953945969f * sinf(fSlow363));
		float 	fSlow603 = (fSlow367 * min(fSlow1, fSlow602));
		float 	fSlow604 = (0.01026806084463841f * sinf(fSlow357));
		float 	fSlow605 = (fSlow361 * min(fSlow1, fSlow604));
		float 	fSlow606 = (0.009947183943243459f * sinf(fSlow351));
		float 	fSlow607 = (fSlow355 * min(fSlow1, fSlow606));
		float 	fSlow608 = (0.009645754126781536f * sinf(fSlow345));
		float 	fSlow609 = (fSlow349 * min(fSlow1, fSlow608));
		float 	fSlow610 = (0.009362055475993843f * sinf(fSlow339));
		float 	fSlow611 = (fSlow343 * min(fSlow1, fSlow610));
		float 	fSlow612 = (0.009094568176679734f * sinf(fSlow333));
		float 	fSlow613 = (fSlow337 * min(fSlow1, fSlow612));
		float 	fSlow614 = (0.008841941282883075f * sinf(fSlow327));
		float 	fSlow615 = (fSlow331 * min(fSlow1, fSlow614));
		float 	fSlow616 = (0.008602969896859207f * sinf(fSlow321));
		float 	fSlow617 = (fSlow325 * min(fSlow1, fSlow616));
		float 	fSlow618 = (0.008376575952205019f * sinf(fSlow315));
		float 	fSlow619 = (fSlow319 * min(fSlow1, fSlow618));
		float 	fSlow620 = (0.00816179195343053f * sinf(fSlow309));
		float 	fSlow621 = (fSlow313 * min(fSlow1, fSlow620));
		float 	fSlow622 = (0.007957747154594767f * sinf(fSlow303));
		float 	fSlow623 = (fSlow307 * min(fSlow1, fSlow622));
		float 	fSlow624 = (0.0077636557605802615f * sinf(fSlow297));
		float 	fSlow625 = (fSlow301 * min(fSlow1, fSlow624));
		float 	fSlow626 = (0.007578806813899778f * sinf(fSlow291));
		float 	fSlow627 = (fSlow295 * min(fSlow1, fSlow626));
		float 	fSlow628 = (0.007402555492646295f * sinf(fSlow285));
		float 	fSlow629 = (fSlow289 * min(fSlow1, fSlow628));
		float 	fSlow630 = (0.007234315595086153f * sinf(fSlow279));
		float 	fSlow631 = (fSlow283 * min(fSlow1, fSlow630));
		float 	fSlow632 = (0.007073553026306459f * sinf(fSlow273));
		float 	fSlow633 = (fSlow277 * min(fSlow1, fSlow632));
		float 	fSlow634 = (0.006919780134430233f * sinf(fSlow267));
		float 	fSlow635 = (fSlow271 * min(fSlow1, fSlow634));
		float 	fSlow636 = (0.006772550769867886f * sinf(fSlow261));
		float 	fSlow637 = (fSlow265 * min(fSlow1, fSlow636));
		float 	fSlow638 = (0.006631455962162306f * sinf(fSlow255));
		float 	fSlow639 = (fSlow259 * min(fSlow1, fSlow638));
		float 	fSlow640 = (0.00649612012619981f * sinf(fSlow249));
		float 	fSlow641 = (fSlow253 * min(fSlow1, fSlow640));
		float 	fSlow642 = (0.006366197723675813f * sinf(fSlow243));
		float 	fSlow643 = (fSlow247 * min(fSlow1, fSlow642));
		float 	fSlow644 = (0.006241370317329229f * sinf(fSlow237));
		float 	fSlow645 = (fSlow241 * min(fSlow1, fSlow644));
		float 	fSlow646 = (0.006121343965072897f * sinf(fSlow231));
		float 	fSlow647 = (fSlow235 * min(fSlow1, fSlow646));
		float 	fSlow648 = (0.006005846909128126f * sinf(fSlow225));
		float 	fSlow649 = (fSlow229 * min(fSlow1, fSlow648));
		float 	fSlow650 = (0.00589462752192205f * sinf(fSlow219));
		float 	fSlow651 = (fSlow223 * min(fSlow1, fSlow650));
		float 	fSlow652 = (0.0057874524760689215f * sinf(fSlow213));
		float 	fSlow653 = (fSlow217 * min(fSlow1, fSlow652));
		float 	fSlow654 = (0.005684105110424833f * sinf(fSlow207));
		float 	fSlow655 = (fSlow211 * min(fSlow1, fSlow654));
		float 	fSlow656 = (0.005584383968136679f * sinf(fSlow201));
		float 	fSlow657 = (fSlow205 * min(fSlow1, fSlow656));
		float 	fSlow658 = (0.0054881014859274255f * sinf(fSlow195));
		float 	fSlow659 = (fSlow199 * min(fSlow1, fSlow658));
		float 	fSlow660 = (0.005395082816674419f * sinf(fSlow189));
		float 	fSlow661 = (fSlow193 * min(fSlow1, fSlow660));
		float 	fSlow662 = (0.005305164769729845f * sinf(fSlow183));
		float 	fSlow663 = (fSlow187 * min(fSlow1, fSlow662));
		float 	fSlow664 = (0.005218194855471979f * sinf(fSlow177));
		float 	fSlow665 = (fSlow181 * min(fSlow1, fSlow664));
		float 	fSlow666 = (0.005134030422319205f * sinf(fSlow171));
		float 	fSlow667 = (fSlow175 * min(fSlow1, fSlow666));
		float 	fSlow668 = (0.0050525378759331855f * sinf(fSlow165));
		float 	fSlow669 = (fSlow169 * min(fSlow1, fSlow668));
		float 	fSlow670 = (0.0049735919716217296f * sinf(fSlow159));
		float 	fSlow671 = (fSlow163 * min(fSlow1, fSlow670));
		float 	fSlow672 = (0.004897075172058319f * sinf(fSlow153));
		float 	fSlow673 = (fSlow157 * min(fSlow1, fSlow672));
		float 	fSlow674 = (0.004822877063390768f * sinf(fSlow147));
		float 	fSlow675 = (fSlow151 * min(fSlow1, fSlow674));
		float 	fSlow676 = (0.004750893823638667f * sinf(fSlow141));
		float 	fSlow677 = (fSlow145 * min(fSlow1, fSlow676));
		float 	fSlow678 = (0.004681027737996921f * sinf(fSlow135));
		float 	fSlow679 = (fSlow139 * min(fSlow1, fSlow678));
		float 	fSlow680 = (0.004613186756286821f * sinf(fSlow129));
		float 	fSlow681 = (fSlow133 * min(fSlow1, fSlow680));
		float 	fSlow682 = (0.004547284088339867f * sinf(fSlow123));
		float 	fSlow683 = (fSlow127 * min(fSlow1, fSlow682));
		float 	fSlow684 = (0.004483237833574517f * sinf(fSlow117));
		float 	fSlow685 = (fSlow121 * min(fSlow1, fSlow684));
		float 	fSlow686 = (0.004420970641441538f * sinf(fSlow111));
		float 	fSlow687 = (fSlow115 * min(fSlow1, fSlow686));
		float 	fSlow688 = (0.004360409399777955f * sinf(fSlow105));
		float 	fSlow689 = (fSlow109 * min(fSlow1, fSlow688));
		float 	fSlow690 = (0.0043014849484296035f * sinf(fSlow99));
		float 	fSlow691 = (fSlow103 * min(fSlow1, fSlow690));
		float 	fSlow692 = (0.004244131815783876f * sinf(fSlow93));
		float 	fSlow693 = (fSlow97 * min(fSlow1, fSlow692));
		float 	fSlow694 = (0.004188287976102509f * sinf(fSlow87));
		float 	fSlow695 = (fSlow91 * min(fSlow1, fSlow694));
		float 	fSlow696 = (0.004133894625763516f * sinf(fSlow81));
		float 	fSlow697 = (fSlow85 * min(fSlow1, fSlow696));
		float 	fSlow698 = (0.004080895976715265f * sinf(fSlow75));
		float 	fSlow699 = (fSlow79 * min(fSlow1, fSlow698));
		float 	fSlow700 = (0.004029239065617604f * sinf(fSlow69));
		float 	fSlow701 = (fSlow73 * min(fSlow1, fSlow700));
		float 	fSlow702 = (0.0039788735772973835f * sinf(fSlow63));
		float 	fSlow703 = (fSlow67 * min(fSlow1, fSlow702));
		float 	fSlow704 = (0.003929751681281367f * sinf(fSlow57));
		float 	fSlow705 = (fSlow61 * min(fSlow1, fSlow704));
		float 	fSlow706 = (0.0038818278802901307f * sinf(fSlow51));
		float 	fSlow707 = (fSlow55 * min(fSlow1, fSlow706));
		float 	fSlow708 = (0.003835058869684225f * sinf(fSlow45));
		float 	fSlow709 = (fSlow49 * min(fSlow1, fSlow708));
		float 	fSlow710 = (0.003789403406949889f * sinf(fSlow39));
		float 	fSlow711 = (fSlow43 * min(fSlow1, fSlow710));
		float 	fSlow712 = (0.0037448221903975372f * sinf(fSlow33));
		float 	fSlow713 = (fSlow37 * min(fSlow1, fSlow712));
		float 	fSlow714 = (0.0037012777463231476f * sinf(fSlow27));
		float 	fSlow715 = (fSlow31 * min(fSlow1, fSlow714));
		float 	fSlow716 = (0.003658734323951617f * sinf(fSlow21));
		float 	fSlow717 = (fSlow25 * min(fSlow1, fSlow716));
		float 	fSlow718 = (0.0036171577975430765f * sinf(fSlow15));
		float 	fSlow719 = (fSlow19 * min(fSlow1, fSlow718));
		float 	fSlow720 = (0.0035765155750987717f * sinf(fSlow9));
		float 	fSlow721 = (fSlow13 * min(fSlow1, fSlow720));
		float 	fSlow722 = powf(10,(0.05f * float(fentry2)));
		float 	fSlow723 = (1 - fSlow1);
		float 	fSlow724 = (fSlow7 * min(fSlow723, fSlow2));
		float 	fSlow725 = (fSlow13 * min(fSlow723, fSlow10));
		float 	fSlow726 = (fSlow19 * min(fSlow723, fSlow16));
		float 	fSlow727 = (fSlow25 * min(fSlow723, fSlow22));
		float 	fSlow728 = (fSlow31 * min(fSlow723, fSlow28));
		float 	fSlow729 = (fSlow37 * min(fSlow723, fSlow34));
		float 	fSlow730 = (fSlow43 * min(fSlow723, fSlow40));
		float 	fSlow731 = (fSlow49 * min(fSlow723, fSlow46));
		float 	fSlow732 = (fSlow55 * min(fSlow723, fSlow52));
		float 	fSlow733 = (fSlow61 * min(fSlow723, fSlow58));
		float 	fSlow734 = (fSlow67 * min(fSlow723, fSlow64));
		float 	fSlow735 = (fSlow73 * min(fSlow723, fSlow70));
		float 	fSlow736 = (fSlow79 * min(fSlow723, fSlow76));
		float 	fSlow737 = (fSlow85 * min(fSlow723, fSlow82));
		float 	fSlow738 = (fSlow91 * min(fSlow723, fSlow88));
		float 	fSlow739 = (fSlow97 * min(fSlow723, fSlow94));
		float 	fSlow740 = (fSlow103 * min(fSlow723, fSlow100));
		float 	fSlow741 = (fSlow109 * min(fSlow723, fSlow106));
		float 	fSlow742 = (fSlow115 * min(fSlow723, fSlow112));
		float 	fSlow743 = (fSlow121 * min(fSlow723, fSlow118));
		float 	fSlow744 = (fSlow127 * min(fSlow723, fSlow124));
		float 	fSlow745 = (fSlow133 * min(fSlow723, fSlow130));
		float 	fSlow746 = (fSlow139 * min(fSlow723, fSlow136));
		float 	fSlow747 = (fSlow145 * min(fSlow723, fSlow142));
		float 	fSlow748 = (fSlow151 * min(fSlow723, fSlow148));
		float 	fSlow749 = (fSlow157 * min(fSlow723, fSlow154));
		float 	fSlow750 = (fSlow163 * min(fSlow723, fSlow160));
		float 	fSlow751 = (fSlow169 * min(fSlow723, fSlow166));
		float 	fSlow752 = (fSlow175 * min(fSlow723, fSlow172));
		float 	fSlow753 = (fSlow181 * min(fSlow723, fSlow178));
		float 	fSlow754 = (fSlow187 * min(fSlow723, fSlow184));
		float 	fSlow755 = (fSlow193 * min(fSlow723, fSlow190));
		float 	fSlow756 = (fSlow199 * min(fSlow723, fSlow196));
		float 	fSlow757 = (fSlow205 * min(fSlow723, fSlow202));
		float 	fSlow758 = (fSlow211 * min(fSlow723, fSlow208));
		float 	fSlow759 = (fSlow217 * min(fSlow723, fSlow214));
		float 	fSlow760 = (fSlow223 * min(fSlow723, fSlow220));
		float 	fSlow761 = (fSlow229 * min(fSlow723, fSlow226));
		float 	fSlow762 = (fSlow235 * min(fSlow723, fSlow232));
		float 	fSlow763 = (fSlow241 * min(fSlow723, fSlow238));
		float 	fSlow764 = (fSlow247 * min(fSlow723, fSlow244));
		float 	fSlow765 = (fSlow253 * min(fSlow723, fSlow250));
		float 	fSlow766 = (fSlow259 * min(fSlow723, fSlow256));
		float 	fSlow767 = (fSlow265 * min(fSlow723, fSlow262));
		float 	fSlow768 = (fSlow271 * min(fSlow723, fSlow268));
		float 	fSlow769 = (fSlow277 * min(fSlow723, fSlow274));
		float 	fSlow770 = (fSlow283 * min(fSlow723, fSlow280));
		float 	fSlow771 = (fSlow289 * min(fSlow723, fSlow286));
		float 	fSlow772 = (fSlow295 * min(fSlow723, fSlow292));
		float 	fSlow773 = (fSlow301 * min(fSlow723, fSlow298));
		float 	fSlow774 = (fSlow307 * min(fSlow723, fSlow304));
		float 	fSlow775 = (fSlow313 * min(fSlow723, fSlow310));
		float 	fSlow776 = (fSlow319 * min(fSlow723, fSlow316));
		float 	fSlow777 = (fSlow325 * min(fSlow723, fSlow322));
		float 	fSlow778 = (fSlow331 * min(fSlow723, fSlow328));
		float 	fSlow779 = (fSlow337 * min(fSlow723, fSlow334));
		float 	fSlow780 = (fSlow343 * min(fSlow723, fSlow340));
		float 	fSlow781 = (fSlow349 * min(fSlow723, fSlow346));
		float 	fSlow782 = (fSlow355 * min(fSlow723, fSlow352));
		float 	fSlow783 = (fSlow361 * min(fSlow723, fSlow358));
		float 	fSlow784 = (fSlow367 * min(fSlow723, fSlow364));
		float 	fSlow785 = (fSlow373 * min(fSlow723, fSlow370));
		float 	fSlow786 = (fSlow379 * min(fSlow723, fSlow376));
		float 	fSlow787 = (fSlow385 * min(fSlow723, fSlow382));
		float 	fSlow788 = (fSlow391 * min(fSlow723, fSlow388));
		float 	fSlow789 = (fSlow397 * min(fSlow723, fSlow394));
		float 	fSlow790 = (fSlow403 * min(fSlow723, fSlow400));
		float 	fSlow791 = (fSlow409 * min(fSlow723, fSlow406));
		float 	fSlow792 = (fSlow415 * min(fSlow723, fSlow412));
		float 	fSlow793 = (fSlow421 * min(fSlow723, fSlow418));
		float 	fSlow794 = (fSlow427 * min(fSlow723, fSlow424));
		float 	fSlow795 = (fSlow433 * min(fSlow723, fSlow430));
		float 	fSlow796 = (fSlow439 * min(fSlow723, fSlow436));
		float 	fSlow797 = (fSlow445 * min(fSlow723, fSlow442));
		float 	fSlow798 = (fSlow451 * min(fSlow723, fSlow448));
		float 	fSlow799 = (fSlow457 * min(fSlow723, fSlow454));
		float 	fSlow800 = (fSlow463 * min(fSlow723, fSlow460));
		float 	fSlow801 = (fSlow469 * min(fSlow723, fSlow466));
		float 	fSlow802 = (fSlow475 * min(fSlow723, fSlow472));
		float 	fSlow803 = (fSlow481 * min(fSlow723, fSlow478));
		float 	fSlow804 = (fSlow487 * min(fSlow723, fSlow484));
		float 	fSlow805 = (fSlow493 * min(fSlow723, fSlow490));
		float 	fSlow806 = (fSlow499 * min(fSlow723, fSlow496));
		float 	fSlow807 = (fSlow505 * min(fSlow723, fSlow502));
		float 	fSlow808 = (fSlow511 * min(fSlow723, fSlow508));
		float 	fSlow809 = (fSlow517 * min(fSlow723, fSlow514));
		float 	fSlow810 = (fSlow523 * min(fSlow723, fSlow520));
		float 	fSlow811 = (fSlow529 * min(fSlow723, fSlow526));
		float 	fSlow812 = (fSlow535 * min(fSlow723, fSlow532));
		float 	fSlow813 = (fSlow541 * min(fSlow723, fSlow538));
		float 	fSlow814 = min(fSlow723, fSlow723);
		float 	fSlow815 = (fSlow541 * min(fSlow723, (0 - fSlow544)));
		float 	fSlow816 = (fSlow535 * min(fSlow723, (0 - fSlow546)));
		float 	fSlow817 = (fSlow529 * min(fSlow723, (0 - fSlow548)));
		float 	fSlow818 = (fSlow523 * min(fSlow723, (0 - fSlow550)));
		float 	fSlow819 = (fSlow517 * min(fSlow723, (0 - fSlow552)));
		float 	fSlow820 = (fSlow511 * min(fSlow723, (0 - fSlow554)));
		float 	fSlow821 = (fSlow505 * min(fSlow723, (0 - fSlow556)));
		float 	fSlow822 = (fSlow499 * min(fSlow723, (0 - fSlow558)));
		float 	fSlow823 = (fSlow493 * min(fSlow723, (0 - fSlow560)));
		float 	fSlow824 = (fSlow487 * min(fSlow723, (0 - fSlow562)));
		float 	fSlow825 = (fSlow481 * min(fSlow723, (0 - fSlow564)));
		float 	fSlow826 = (fSlow475 * min(fSlow723, (0 - fSlow566)));
		float 	fSlow827 = (fSlow469 * min(fSlow723, (0 - fSlow568)));
		float 	fSlow828 = (fSlow463 * min(fSlow723, (0 - fSlow570)));
		float 	fSlow829 = (fSlow457 * min(fSlow723, (0 - fSlow572)));
		float 	fSlow830 = (fSlow451 * min(fSlow723, (0 - fSlow574)));
		float 	fSlow831 = (fSlow445 * min(fSlow723, (0 - fSlow576)));
		float 	fSlow832 = (fSlow439 * min(fSlow723, (0 - fSlow578)));
		float 	fSlow833 = (fSlow433 * min(fSlow723, (0 - fSlow580)));
		float 	fSlow834 = (fSlow427 * min(fSlow723, (0 - fSlow582)));
		float 	fSlow835 = (fSlow421 * min(fSlow723, (0 - fSlow584)));
		float 	fSlow836 = (fSlow415 * min(fSlow723, (0 - fSlow586)));
		float 	fSlow837 = (fSlow409 * min(fSlow723, (0 - fSlow588)));
		float 	fSlow838 = (fSlow403 * min(fSlow723, (0 - fSlow590)));
		float 	fSlow839 = (fSlow397 * min(fSlow723, (0 - fSlow592)));
		float 	fSlow840 = (fSlow391 * min(fSlow723, (0 - fSlow594)));
		float 	fSlow841 = (fSlow385 * min(fSlow723, (0 - fSlow596)));
		float 	fSlow842 = (fSlow379 * min(fSlow723, (0 - fSlow598)));
		float 	fSlow843 = (fSlow373 * min(fSlow723, (0 - fSlow600)));
		float 	fSlow844 = (fSlow367 * min(fSlow723, (0 - fSlow602)));
		float 	fSlow845 = (fSlow361 * min(fSlow723, (0 - fSlow604)));
		float 	fSlow846 = (fSlow355 * min(fSlow723, (0 - fSlow606)));
		float 	fSlow847 = (fSlow349 * min(fSlow723, (0 - fSlow608)));
		float 	fSlow848 = (fSlow343 * min(fSlow723, (0 - fSlow610)));
		float 	fSlow849 = (fSlow337 * min(fSlow723, (0 - fSlow612)));
		float 	fSlow850 = (fSlow331 * min(fSlow723, (0 - fSlow614)));
		float 	fSlow851 = (fSlow325 * min(fSlow723, (0 - fSlow616)));
		float 	fSlow852 = (fSlow319 * min(fSlow723, (0 - fSlow618)));
		float 	fSlow853 = (fSlow313 * min(fSlow723, (0 - fSlow620)));
		float 	fSlow854 = (fSlow307 * min(fSlow723, (0 - fSlow622)));
		float 	fSlow855 = (fSlow301 * min(fSlow723, (0 - fSlow624)));
		float 	fSlow856 = (fSlow295 * min(fSlow723, (0 - fSlow626)));
		float 	fSlow857 = (fSlow289 * min(fSlow723, (0 - fSlow628)));
		float 	fSlow858 = (fSlow283 * min(fSlow723, (0 - fSlow630)));
		float 	fSlow859 = (fSlow277 * min(fSlow723, (0 - fSlow632)));
		float 	fSlow860 = (fSlow271 * min(fSlow723, (0 - fSlow634)));
		float 	fSlow861 = (fSlow265 * min(fSlow723, (0 - fSlow636)));
		float 	fSlow862 = (fSlow259 * min(fSlow723, (0 - fSlow638)));
		float 	fSlow863 = (fSlow253 * min(fSlow723, (0 - fSlow640)));
		float 	fSlow864 = (fSlow247 * min(fSlow723, (0 - fSlow642)));
		float 	fSlow865 = (fSlow241 * min(fSlow723, (0 - fSlow644)));
		float 	fSlow866 = (fSlow235 * min(fSlow723, (0 - fSlow646)));
		float 	fSlow867 = (fSlow229 * min(fSlow723, (0 - fSlow648)));
		float 	fSlow868 = (fSlow223 * min(fSlow723, (0 - fSlow650)));
		float 	fSlow869 = (fSlow217 * min(fSlow723, (0 - fSlow652)));
		float 	fSlow870 = (fSlow211 * min(fSlow723, (0 - fSlow654)));
		float 	fSlow871 = (fSlow205 * min(fSlow723, (0 - fSlow656)));
		float 	fSlow872 = (fSlow199 * min(fSlow723, (0 - fSlow658)));
		float 	fSlow873 = (fSlow193 * min(fSlow723, (0 - fSlow660)));
		float 	fSlow874 = (fSlow187 * min(fSlow723, (0 - fSlow662)));
		float 	fSlow875 = (fSlow181 * min(fSlow723, (0 - fSlow664)));
		float 	fSlow876 = (fSlow175 * min(fSlow723, (0 - fSlow666)));
		float 	fSlow877 = (fSlow169 * min(fSlow723, (0 - fSlow668)));
		float 	fSlow878 = (fSlow163 * min(fSlow723, (0 - fSlow670)));
		float 	fSlow879 = (fSlow157 * min(fSlow723, (0 - fSlow672)));
		float 	fSlow880 = (fSlow151 * min(fSlow723, (0 - fSlow674)));
		float 	fSlow881 = (fSlow145 * min(fSlow723, (0 - fSlow676)));
		float 	fSlow882 = (fSlow139 * min(fSlow723, (0 - fSlow678)));
		float 	fSlow883 = (fSlow133 * min(fSlow723, (0 - fSlow680)));
		float 	fSlow884 = (fSlow127 * min(fSlow723, (0 - fSlow682)));
		float 	fSlow885 = (fSlow121 * min(fSlow723, (0 - fSlow684)));
		float 	fSlow886 = (fSlow115 * min(fSlow723, (0 - fSlow686)));
		float 	fSlow887 = (fSlow109 * min(fSlow723, (0 - fSlow688)));
		float 	fSlow888 = (fSlow103 * min(fSlow723, (0 - fSlow690)));
		float 	fSlow889 = (fSlow97 * min(fSlow723, (0 - fSlow692)));
		float 	fSlow890 = (fSlow91 * min(fSlow723, (0 - fSlow694)));
		float 	fSlow891 = (fSlow85 * min(fSlow723, (0 - fSlow696)));
		float 	fSlow892 = (fSlow79 * min(fSlow723, (0 - fSlow698)));
		float 	fSlow893 = (fSlow73 * min(fSlow723, (0 - fSlow700)));
		float 	fSlow894 = (fSlow67 * min(fSlow723, (0 - fSlow702)));
		float 	fSlow895 = (fSlow61 * min(fSlow723, (0 - fSlow704)));
		float 	fSlow896 = (fSlow55 * min(fSlow723, (0 - fSlow706)));
		float 	fSlow897 = (fSlow49 * min(fSlow723, (0 - fSlow708)));
		float 	fSlow898 = (fSlow43 * min(fSlow723, (0 - fSlow710)));
		float 	fSlow899 = (fSlow37 * min(fSlow723, (0 - fSlow712)));
		float 	fSlow900 = (fSlow31 * min(fSlow723, (0 - fSlow714)));
		float 	fSlow901 = (fSlow25 * min(fSlow723, (0 - fSlow716)));
		float 	fSlow902 = (fSlow19 * min(fSlow723, (0 - fSlow718)));
		float 	fSlow903 = (fSlow13 * min(fSlow723, (0 - fSlow720)));
		float 	fSlow904 = powf(10,(0.05f * float(fentry3)));
		float 	fSlow905 = (fConst92 * float(fentry4));
		int 	iSlow906 = int((fSlow905 - 1.99999f));
		int 	iSlow907 = (5 + iSlow906);
		int 	iSlow908 = int((int(iSlow907) & 511));
		int 	iSlow909 = (1 + iSlow906);
		float 	fSlow910 = (iSlow909 - fSlow905);
		float 	fSlow911 = (0 - fSlow910);
		int 	iSlow912 = (2 + iSlow906);
		float 	fSlow913 = (fSlow905 - iSlow912);
		int 	iSlow914 = (3 + iSlow906);
		float 	fSlow915 = (fSlow905 - iSlow914);
		int 	iSlow916 = (4 + iSlow906);
		float 	fSlow917 = (fSlow905 - iSlow916);
		float 	fSlow918 = (fSlow905 - iSlow906);
		float 	fSlow919 = (0.004166666666666667f * ((((fSlow918 * fSlow917) * fSlow915) * fSlow913) * fSlow911));
		float 	fSlow920 = float(fentry5);
		float 	fSlow921 = (1.0f - (0.01f * fSlow920));
		float 	fSlow922 = (0.005f * fSlow920);
		int 	iSlow923 = int((int(iSlow916) & 511));
		float 	fSlow924 = (iSlow906 - fSlow905);
		float 	fSlow925 = (0.020833333333333332f * (((fSlow915 * fSlow913) * fSlow911) * fSlow924));
		int 	iSlow926 = int((int(iSlow914) & 511));
		float 	fSlow927 = (0.041666666666666664f * ((fSlow918 * fSlow913) * fSlow911));
		int 	iSlow928 = int((int(iSlow912) & 511));
		float 	fSlow929 = (0.041666666666666664f * (fSlow911 * fSlow924));
		int 	iSlow930 = int((iSlow906 & 511));
		float 	fSlow931 = (0.004166666666666667f * fSlow910);
		int 	iSlow932 = int((int(iSlow909) & 511));
		float 	fSlow933 = (0.020833333333333332f * fSlow918);
		float 	fSlow934 = (fSlow905 - iSlow907);
		float 	fSlow935 = powf(10,(0.05f * float(fentry6)));
		int index;
		for (index = 0; index <= fullcount - 256; index += 256) {
			// compute by blocks of 256 samples
			const int count = 256;
			FAUSTFLOAT* input0 = &input[0][index];
			FAUSTFLOAT* input1 = &input[1][index];
			FAUSTFLOAT* output0 = &output[0][index];
			FAUSTFLOAT* output1 = &output[1][index];
			// SECTION : 1
			// LOOP 0x7f0668048e10
			// pre processing
			fYec0_idx = (fYec0_idx+fYec0_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec0[(fYec0_idx+i)&511] = ((float)input1[i] - (float)input0[i]);
			}
			// post processing
			fYec0_idx_save = count;
			
			// LOOP 0x7f0668668990
			// pre processing
			fYec3_idx = (fYec3_idx+fYec3_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec3[(fYec3_idx+i)&511] = ((float)input0[i] - (float)input1[i]);
			}
			// post processing
			fYec3_idx_save = count;
			
			// LOOP 0x7f0668682510
			// exec code
			for (int i=0; i<count; i++) {
				fZec0[i] = (fSlow922 * ((float)input0[i] + (float)input1[i]));
			}
			
			// SECTION : 2
			// LOOP 0x7f0668048d00
			// pre processing
			fYec1_idx = (fYec1_idx+fYec1_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec1[(fYec1_idx+i)&1023] = ((fSlow904 * ((fSlow903 * fYec0[(fYec0_idx+i-179)&511]) + ((fSlow902 * fYec0[(fYec0_idx+i-178)&511]) + ((fSlow901 * fYec0[(fYec0_idx+i-177)&511]) + ((fSlow900 * fYec0[(fYec0_idx+i-176)&511]) + ((fSlow899 * fYec0[(fYec0_idx+i-175)&511]) + ((fSlow898 * fYec0[(fYec0_idx+i-174)&511]) + ((fSlow897 * fYec0[(fYec0_idx+i-173)&511]) + ((fSlow896 * fYec0[(fYec0_idx+i-172)&511]) + ((fSlow895 * fYec0[(fYec0_idx+i-171)&511]) + ((fSlow894 * fYec0[(fYec0_idx+i-170)&511]) + ((fSlow893 * fYec0[(fYec0_idx+i-169)&511]) + ((fSlow892 * fYec0[(fYec0_idx+i-168)&511]) + ((fSlow891 * fYec0[(fYec0_idx+i-167)&511]) + ((fSlow890 * fYec0[(fYec0_idx+i-166)&511]) + ((fSlow889 * fYec0[(fYec0_idx+i-165)&511]) + ((fSlow888 * fYec0[(fYec0_idx+i-164)&511]) + ((fSlow887 * fYec0[(fYec0_idx+i-163)&511]) + ((fSlow886 * fYec0[(fYec0_idx+i-162)&511]) + ((fSlow885 * fYec0[(fYec0_idx+i-161)&511]) + ((fSlow884 * fYec0[(fYec0_idx+i-160)&511]) + ((fSlow883 * fYec0[(fYec0_idx+i-159)&511]) + ((fSlow882 * fYec0[(fYec0_idx+i-158)&511]) + ((fSlow881 * fYec0[(fYec0_idx+i-157)&511]) + ((fSlow880 * fYec0[(fYec0_idx+i-156)&511]) + ((fSlow879 * fYec0[(fYec0_idx+i-155)&511]) + ((fSlow878 * fYec0[(fYec0_idx+i-154)&511]) + ((fSlow877 * fYec0[(fYec0_idx+i-153)&511]) + ((fSlow876 * fYec0[(fYec0_idx+i-152)&511]) + ((fSlow875 * fYec0[(fYec0_idx+i-151)&511]) + ((fSlow874 * fYec0[(fYec0_idx+i-150)&511]) + ((fSlow873 * fYec0[(fYec0_idx+i-149)&511]) + ((fSlow872 * fYec0[(fYec0_idx+i-148)&511]) + ((fSlow871 * fYec0[(fYec0_idx+i-147)&511]) + ((fSlow870 * fYec0[(fYec0_idx+i-146)&511]) + ((fSlow869 * fYec0[(fYec0_idx+i-145)&511]) + ((fSlow868 * fYec0[(fYec0_idx+i-144)&511]) + ((fSlow867 * fYec0[(fYec0_idx+i-143)&511]) + ((fSlow866 * fYec0[(fYec0_idx+i-142)&511]) + ((fSlow865 * fYec0[(fYec0_idx+i-141)&511]) + ((fSlow864 * fYec0[(fYec0_idx+i-140)&511]) + ((fSlow863 * fYec0[(fYec0_idx+i-139)&511]) + ((fSlow862 * fYec0[(fYec0_idx+i-138)&511]) + ((fSlow861 * fYec0[(fYec0_idx+i-137)&511]) + ((fSlow860 * fYec0[(fYec0_idx+i-136)&511]) + ((fSlow859 * fYec0[(fYec0_idx+i-135)&511]) + ((fSlow858 * fYec0[(fYec0_idx+i-134)&511]) + ((fSlow857 * fYec0[(fYec0_idx+i-133)&511]) + ((fSlow856 * fYec0[(fYec0_idx+i-132)&511]) + ((fSlow855 * fYec0[(fYec0_idx+i-131)&511]) + ((fSlow854 * fYec0[(fYec0_idx+i-130)&511]) + ((fSlow853 * fYec0[(fYec0_idx+i-129)&511]) + ((fSlow852 * fYec0[(fYec0_idx+i-128)&511]) + ((fSlow851 * fYec0[(fYec0_idx+i-127)&511]) + ((fSlow850 * fYec0[(fYec0_idx+i-126)&511]) + ((fSlow849 * fYec0[(fYec0_idx+i-125)&511]) + ((fSlow848 * fYec0[(fYec0_idx+i-124)&511]) + ((fSlow847 * fYec0[(fYec0_idx+i-123)&511]) + ((fSlow846 * fYec0[(fYec0_idx+i-122)&511]) + ((fSlow845 * fYec0[(fYec0_idx+i-121)&511]) + ((fSlow844 * fYec0[(fYec0_idx+i-120)&511]) + ((fSlow843 * fYec0[(fYec0_idx+i-119)&511]) + ((fSlow842 * fYec0[(fYec0_idx+i-118)&511]) + ((fSlow841 * fYec0[(fYec0_idx+i-117)&511]) + ((fSlow840 * fYec0[(fYec0_idx+i-116)&511]) + ((fSlow839 * fYec0[(fYec0_idx+i-115)&511]) + ((fSlow838 * fYec0[(fYec0_idx+i-114)&511]) + ((fSlow837 * fYec0[(fYec0_idx+i-113)&511]) + ((fSlow836 * fYec0[(fYec0_idx+i-112)&511]) + ((fSlow835 * fYec0[(fYec0_idx+i-111)&511]) + ((fSlow834 * fYec0[(fYec0_idx+i-110)&511]) + ((fSlow833 * fYec0[(fYec0_idx+i-109)&511]) + ((fSlow832 * fYec0[(fYec0_idx+i-108)&511]) + ((fSlow831 * fYec0[(fYec0_idx+i-107)&511]) + ((fSlow830 * fYec0[(fYec0_idx+i-106)&511]) + ((fSlow829 * fYec0[(fYec0_idx+i-105)&511]) + ((fSlow828 * fYec0[(fYec0_idx+i-104)&511]) + ((fSlow827 * fYec0[(fYec0_idx+i-103)&511]) + ((fSlow826 * fYec0[(fYec0_idx+i-102)&511]) + ((fSlow825 * fYec0[(fYec0_idx+i-101)&511]) + ((fSlow824 * fYec0[(fYec0_idx+i-100)&511]) + ((fSlow823 * fYec0[(fYec0_idx+i-99)&511]) + ((fSlow822 * fYec0[(fYec0_idx+i-98)&511]) + ((fSlow821 * fYec0[(fYec0_idx+i-97)&511]) + ((fSlow820 * fYec0[(fYec0_idx+i-96)&511]) + ((fSlow819 * fYec0[(fYec0_idx+i-95)&511]) + ((fSlow818 * fYec0[(fYec0_idx+i-94)&511]) + ((fSlow817 * fYec0[(fYec0_idx+i-93)&511]) + ((fSlow816 * fYec0[(fYec0_idx+i-92)&511]) + ((fSlow815 * fYec0[(fYec0_idx+i-91)&511]) + ((fSlow814 * fYec0[(fYec0_idx+i-90)&511]) + ((fSlow813 * fYec0[(fYec0_idx+i-89)&511]) + ((fSlow812 * fYec0[(fYec0_idx+i-88)&511]) + ((fSlow811 * fYec0[(fYec0_idx+i-87)&511]) + ((fSlow810 * fYec0[(fYec0_idx+i-86)&511]) + ((fSlow809 * fYec0[(fYec0_idx+i-85)&511]) + ((fSlow808 * fYec0[(fYec0_idx+i-84)&511]) + ((fSlow807 * fYec0[(fYec0_idx+i-83)&511]) + ((fSlow806 * fYec0[(fYec0_idx+i-82)&511]) + ((fSlow805 * fYec0[(fYec0_idx+i-81)&511]) + ((fSlow804 * fYec0[(fYec0_idx+i-80)&511]) + ((fSlow803 * fYec0[(fYec0_idx+i-79)&511]) + ((fSlow802 * fYec0[(fYec0_idx+i-78)&511]) + ((fSlow801 * fYec0[(fYec0_idx+i-77)&511]) + ((fSlow800 * fYec0[(fYec0_idx+i-76)&511]) + ((fSlow799 * fYec0[(fYec0_idx+i-75)&511]) + ((fSlow798 * fYec0[(fYec0_idx+i-74)&511]) + ((fSlow797 * fYec0[(fYec0_idx+i-73)&511]) + ((fSlow796 * fYec0[(fYec0_idx+i-72)&511]) + ((fSlow795 * fYec0[(fYec0_idx+i-71)&511]) + ((fSlow794 * fYec0[(fYec0_idx+i-70)&511]) + ((fSlow793 * fYec0[(fYec0_idx+i-69)&511]) + ((fSlow792 * fYec0[(fYec0_idx+i-68)&511]) + ((fSlow791 * fYec0[(fYec0_idx+i-67)&511]) + ((fSlow790 * fYec0[(fYec0_idx+i-66)&511]) + ((fSlow789 * fYec0[(fYec0_idx+i-65)&511]) + ((fSlow788 * fYec0[(fYec0_idx+i-64)&511]) + ((fSlow787 * fYec0[(fYec0_idx+i-63)&511]) + ((fSlow786 * fYec0[(fYec0_idx+i-62)&511]) + ((fSlow785 * fYec0[(fYec0_idx+i-61)&511]) + ((fSlow784 * fYec0[(fYec0_idx+i-60)&511]) + ((fSlow783 * fYec0[(fYec0_idx+i-59)&511]) + ((fSlow782 * fYec0[(fYec0_idx+i-58)&511]) + ((fSlow781 * fYec0[(fYec0_idx+i-57)&511]) + ((fSlow780 * fYec0[(fYec0_idx+i-56)&511]) + ((fSlow779 * fYec0[(fYec0_idx+i-55)&511]) + ((fSlow778 * fYec0[(fYec0_idx+i-54)&511]) + ((fSlow777 * fYec0[(fYec0_idx+i-53)&511]) + ((fSlow776 * fYec0[(fYec0_idx+i-52)&511]) + ((fSlow775 * fYec0[(fYec0_idx+i-51)&511]) + ((fSlow774 * fYec0[(fYec0_idx+i-50)&511]) + ((fSlow773 * fYec0[(fYec0_idx+i-49)&511]) + ((fSlow772 * fYec0[(fYec0_idx+i-48)&511]) + ((fSlow771 * fYec0[(fYec0_idx+i-47)&511]) + ((fSlow770 * fYec0[(fYec0_idx+i-46)&511]) + ((fSlow769 * fYec0[(fYec0_idx+i-45)&511]) + ((fSlow768 * fYec0[(fYec0_idx+i-44)&511]) + ((fSlow767 * fYec0[(fYec0_idx+i-43)&511]) + ((fSlow766 * fYec0[(fYec0_idx+i-42)&511]) + ((fSlow765 * fYec0[(fYec0_idx+i-41)&511]) + ((fSlow764 * fYec0[(fYec0_idx+i-40)&511]) + ((fSlow763 * fYec0[(fYec0_idx+i-39)&511]) + ((fSlow762 * fYec0[(fYec0_idx+i-38)&511]) + ((fSlow761 * fYec0[(fYec0_idx+i-37)&511]) + ((fSlow760 * fYec0[(fYec0_idx+i-36)&511]) + ((fSlow759 * fYec0[(fYec0_idx+i-35)&511]) + ((fSlow758 * fYec0[(fYec0_idx+i-34)&511]) + ((fSlow757 * fYec0[(fYec0_idx+i-33)&511]) + ((fSlow756 * fYec0[(fYec0_idx+i-32)&511]) + ((fSlow755 * fYec0[(fYec0_idx+i-31)&511]) + ((fSlow754 * fYec0[(fYec0_idx+i-30)&511]) + ((fSlow753 * fYec0[(fYec0_idx+i-29)&511]) + ((fSlow752 * fYec0[(fYec0_idx+i-28)&511]) + ((fSlow751 * fYec0[(fYec0_idx+i-27)&511]) + ((fSlow750 * fYec0[(fYec0_idx+i-26)&511]) + ((fSlow749 * fYec0[(fYec0_idx+i-25)&511]) + ((fSlow748 * fYec0[(fYec0_idx+i-24)&511]) + ((fSlow747 * fYec0[(fYec0_idx+i-23)&511]) + ((fSlow746 * fYec0[(fYec0_idx+i-22)&511]) + ((fSlow745 * fYec0[(fYec0_idx+i-21)&511]) + ((fSlow744 * fYec0[(fYec0_idx+i-20)&511]) + ((fSlow743 * fYec0[(fYec0_idx+i-19)&511]) + ((fSlow742 * fYec0[(fYec0_idx+i-18)&511]) + ((fSlow741 * fYec0[(fYec0_idx+i-17)&511]) + ((fSlow740 * fYec0[(fYec0_idx+i-16)&511]) + ((fSlow739 * fYec0[(fYec0_idx+i-15)&511]) + ((fSlow738 * fYec0[(fYec0_idx+i-14)&511]) + ((fSlow737 * fYec0[(fYec0_idx+i-13)&511]) + ((fSlow736 * fYec0[(fYec0_idx+i-12)&511]) + ((fSlow735 * fYec0[(fYec0_idx+i-11)&511]) + ((fSlow734 * fYec0[(fYec0_idx+i-10)&511]) + ((fSlow733 * fYec0[(fYec0_idx+i-9)&511]) + ((fSlow732 * fYec0[(fYec0_idx+i-8)&511]) + ((fSlow731 * fYec0[(fYec0_idx+i-7)&511]) + ((fSlow730 * fYec0[(fYec0_idx+i-6)&511]) + ((fSlow729 * fYec0[(fYec0_idx+i-5)&511]) + ((fSlow728 * fYec0[(fYec0_idx+i-4)&511]) + ((fSlow727 * fYec0[(fYec0_idx+i-3)&511]) + ((fSlow726 * fYec0[(fYec0_idx+i-2)&511]) + ((fSlow725 * fYec0[(fYec0_idx+i-1)&511]) + (fSlow724 * fYec0[(fYec0_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * fYec0[(fYec0_idx+i-179)&511]) + ((fSlow719 * fYec0[(fYec0_idx+i-178)&511]) + ((fSlow717 * fYec0[(fYec0_idx+i-177)&511]) + ((fSlow715 * fYec0[(fYec0_idx+i-176)&511]) + ((fSlow713 * fYec0[(fYec0_idx+i-175)&511]) + ((fSlow711 * fYec0[(fYec0_idx+i-174)&511]) + ((fSlow709 * fYec0[(fYec0_idx+i-173)&511]) + ((fSlow707 * fYec0[(fYec0_idx+i-172)&511]) + ((fSlow705 * fYec0[(fYec0_idx+i-171)&511]) + ((fSlow703 * fYec0[(fYec0_idx+i-170)&511]) + ((fSlow701 * fYec0[(fYec0_idx+i-169)&511]) + ((fSlow699 * fYec0[(fYec0_idx+i-168)&511]) + ((fSlow697 * fYec0[(fYec0_idx+i-167)&511]) + ((fSlow695 * fYec0[(fYec0_idx+i-166)&511]) + ((fSlow693 * fYec0[(fYec0_idx+i-165)&511]) + ((fSlow691 * fYec0[(fYec0_idx+i-164)&511]) + ((fSlow689 * fYec0[(fYec0_idx+i-163)&511]) + ((fSlow687 * fYec0[(fYec0_idx+i-162)&511]) + ((fSlow685 * fYec0[(fYec0_idx+i-161)&511]) + ((fSlow683 * fYec0[(fYec0_idx+i-160)&511]) + ((fSlow681 * fYec0[(fYec0_idx+i-159)&511]) + ((fSlow679 * fYec0[(fYec0_idx+i-158)&511]) + ((fSlow677 * fYec0[(fYec0_idx+i-157)&511]) + ((fSlow675 * fYec0[(fYec0_idx+i-156)&511]) + ((fSlow673 * fYec0[(fYec0_idx+i-155)&511]) + ((fSlow671 * fYec0[(fYec0_idx+i-154)&511]) + ((fSlow669 * fYec0[(fYec0_idx+i-153)&511]) + ((fSlow667 * fYec0[(fYec0_idx+i-152)&511]) + ((fSlow665 * fYec0[(fYec0_idx+i-151)&511]) + ((fSlow663 * fYec0[(fYec0_idx+i-150)&511]) + ((fSlow661 * fYec0[(fYec0_idx+i-149)&511]) + ((fSlow659 * fYec0[(fYec0_idx+i-148)&511]) + ((fSlow657 * fYec0[(fYec0_idx+i-147)&511]) + ((fSlow655 * fYec0[(fYec0_idx+i-146)&511]) + ((fSlow653 * fYec0[(fYec0_idx+i-145)&511]) + ((fSlow651 * fYec0[(fYec0_idx+i-144)&511]) + ((fSlow649 * fYec0[(fYec0_idx+i-143)&511]) + ((fSlow647 * fYec0[(fYec0_idx+i-142)&511]) + ((fSlow645 * fYec0[(fYec0_idx+i-141)&511]) + ((fSlow643 * fYec0[(fYec0_idx+i-140)&511]) + ((fSlow641 * fYec0[(fYec0_idx+i-139)&511]) + ((fSlow639 * fYec0[(fYec0_idx+i-138)&511]) + ((fSlow637 * fYec0[(fYec0_idx+i-137)&511]) + ((fSlow635 * fYec0[(fYec0_idx+i-136)&511]) + ((fSlow633 * fYec0[(fYec0_idx+i-135)&511]) + ((fSlow631 * fYec0[(fYec0_idx+i-134)&511]) + ((fSlow629 * fYec0[(fYec0_idx+i-133)&511]) + ((fSlow627 * fYec0[(fYec0_idx+i-132)&511]) + ((fSlow625 * fYec0[(fYec0_idx+i-131)&511]) + ((fSlow623 * fYec0[(fYec0_idx+i-130)&511]) + ((fSlow621 * fYec0[(fYec0_idx+i-129)&511]) + ((fSlow619 * fYec0[(fYec0_idx+i-128)&511]) + ((fSlow617 * fYec0[(fYec0_idx+i-127)&511]) + ((fSlow615 * fYec0[(fYec0_idx+i-126)&511]) + ((fSlow613 * fYec0[(fYec0_idx+i-125)&511]) + ((fSlow611 * fYec0[(fYec0_idx+i-124)&511]) + ((fSlow609 * fYec0[(fYec0_idx+i-123)&511]) + ((fSlow607 * fYec0[(fYec0_idx+i-122)&511]) + ((fSlow605 * fYec0[(fYec0_idx+i-121)&511]) + ((fSlow603 * fYec0[(fYec0_idx+i-120)&511]) + ((fSlow601 * fYec0[(fYec0_idx+i-119)&511]) + ((fSlow599 * fYec0[(fYec0_idx+i-118)&511]) + ((fSlow597 * fYec0[(fYec0_idx+i-117)&511]) + ((fSlow595 * fYec0[(fYec0_idx+i-116)&511]) + ((fSlow593 * fYec0[(fYec0_idx+i-115)&511]) + ((fSlow591 * fYec0[(fYec0_idx+i-114)&511]) + ((fSlow589 * fYec0[(fYec0_idx+i-113)&511]) + ((fSlow587 * fYec0[(fYec0_idx+i-112)&511]) + ((fSlow585 * fYec0[(fYec0_idx+i-111)&511]) + ((fSlow583 * fYec0[(fYec0_idx+i-110)&511]) + ((fSlow581 * fYec0[(fYec0_idx+i-109)&511]) + ((fSlow579 * fYec0[(fYec0_idx+i-108)&511]) + ((fSlow577 * fYec0[(fYec0_idx+i-107)&511]) + ((fSlow575 * fYec0[(fYec0_idx+i-106)&511]) + ((fSlow573 * fYec0[(fYec0_idx+i-105)&511]) + ((fSlow571 * fYec0[(fYec0_idx+i-104)&511]) + ((fSlow569 * fYec0[(fYec0_idx+i-103)&511]) + ((fSlow567 * fYec0[(fYec0_idx+i-102)&511]) + ((fSlow565 * fYec0[(fYec0_idx+i-101)&511]) + ((fSlow563 * fYec0[(fYec0_idx+i-100)&511]) + ((fSlow561 * fYec0[(fYec0_idx+i-99)&511]) + ((fSlow559 * fYec0[(fYec0_idx+i-98)&511]) + ((fSlow557 * fYec0[(fYec0_idx+i-97)&511]) + ((fSlow555 * fYec0[(fYec0_idx+i-96)&511]) + ((fSlow553 * fYec0[(fYec0_idx+i-95)&511]) + ((fSlow551 * fYec0[(fYec0_idx+i-94)&511]) + ((fSlow549 * fYec0[(fYec0_idx+i-93)&511]) + ((fSlow547 * fYec0[(fYec0_idx+i-92)&511]) + ((fSlow545 * fYec0[(fYec0_idx+i-91)&511]) + ((fSlow543 * fYec0[(fYec0_idx+i-90)&511]) + ((fSlow542 * fYec0[(fYec0_idx+i-89)&511]) + ((fSlow536 * fYec0[(fYec0_idx+i-88)&511]) + ((fSlow530 * fYec0[(fYec0_idx+i-87)&511]) + ((fSlow524 * fYec0[(fYec0_idx+i-86)&511]) + ((fSlow518 * fYec0[(fYec0_idx+i-85)&511]) + ((fSlow512 * fYec0[(fYec0_idx+i-84)&511]) + ((fSlow506 * fYec0[(fYec0_idx+i-83)&511]) + ((fSlow500 * fYec0[(fYec0_idx+i-82)&511]) + ((fSlow494 * fYec0[(fYec0_idx+i-81)&511]) + ((fSlow488 * fYec0[(fYec0_idx+i-80)&511]) + ((fSlow482 * fYec0[(fYec0_idx+i-79)&511]) + ((fSlow476 * fYec0[(fYec0_idx+i-78)&511]) + ((fSlow470 * fYec0[(fYec0_idx+i-77)&511]) + ((fSlow464 * fYec0[(fYec0_idx+i-76)&511]) + ((fSlow458 * fYec0[(fYec0_idx+i-75)&511]) + ((fSlow452 * fYec0[(fYec0_idx+i-74)&511]) + ((fSlow446 * fYec0[(fYec0_idx+i-73)&511]) + ((fSlow440 * fYec0[(fYec0_idx+i-72)&511]) + ((fSlow434 * fYec0[(fYec0_idx+i-71)&511]) + ((fSlow428 * fYec0[(fYec0_idx+i-70)&511]) + ((fSlow422 * fYec0[(fYec0_idx+i-69)&511]) + ((fSlow416 * fYec0[(fYec0_idx+i-68)&511]) + ((fSlow410 * fYec0[(fYec0_idx+i-67)&511]) + ((fSlow404 * fYec0[(fYec0_idx+i-66)&511]) + ((fSlow398 * fYec0[(fYec0_idx+i-65)&511]) + ((fSlow392 * fYec0[(fYec0_idx+i-64)&511]) + ((fSlow386 * fYec0[(fYec0_idx+i-63)&511]) + ((fSlow380 * fYec0[(fYec0_idx+i-62)&511]) + ((fSlow374 * fYec0[(fYec0_idx+i-61)&511]) + ((fSlow368 * fYec0[(fYec0_idx+i-60)&511]) + ((fSlow362 * fYec0[(fYec0_idx+i-59)&511]) + ((fSlow356 * fYec0[(fYec0_idx+i-58)&511]) + ((fSlow350 * fYec0[(fYec0_idx+i-57)&511]) + ((fSlow344 * fYec0[(fYec0_idx+i-56)&511]) + ((fSlow338 * fYec0[(fYec0_idx+i-55)&511]) + ((fSlow332 * fYec0[(fYec0_idx+i-54)&511]) + ((fSlow326 * fYec0[(fYec0_idx+i-53)&511]) + ((fSlow320 * fYec0[(fYec0_idx+i-52)&511]) + ((fSlow314 * fYec0[(fYec0_idx+i-51)&511]) + ((fSlow308 * fYec0[(fYec0_idx+i-50)&511]) + ((fSlow302 * fYec0[(fYec0_idx+i-49)&511]) + ((fSlow296 * fYec0[(fYec0_idx+i-48)&511]) + ((fSlow290 * fYec0[(fYec0_idx+i-47)&511]) + ((fSlow284 * fYec0[(fYec0_idx+i-46)&511]) + ((fSlow278 * fYec0[(fYec0_idx+i-45)&511]) + ((fSlow272 * fYec0[(fYec0_idx+i-44)&511]) + ((fSlow266 * fYec0[(fYec0_idx+i-43)&511]) + ((fSlow260 * fYec0[(fYec0_idx+i-42)&511]) + ((fSlow254 * fYec0[(fYec0_idx+i-41)&511]) + ((fSlow248 * fYec0[(fYec0_idx+i-40)&511]) + ((fSlow242 * fYec0[(fYec0_idx+i-39)&511]) + ((fSlow236 * fYec0[(fYec0_idx+i-38)&511]) + ((fSlow230 * fYec0[(fYec0_idx+i-37)&511]) + ((fSlow224 * fYec0[(fYec0_idx+i-36)&511]) + ((fSlow218 * fYec0[(fYec0_idx+i-35)&511]) + ((fSlow212 * fYec0[(fYec0_idx+i-34)&511]) + ((fSlow206 * fYec0[(fYec0_idx+i-33)&511]) + ((fSlow200 * fYec0[(fYec0_idx+i-32)&511]) + ((fSlow194 * fYec0[(fYec0_idx+i-31)&511]) + ((fSlow188 * fYec0[(fYec0_idx+i-30)&511]) + ((fSlow182 * fYec0[(fYec0_idx+i-29)&511]) + ((fSlow176 * fYec0[(fYec0_idx+i-28)&511]) + ((fSlow170 * fYec0[(fYec0_idx+i-27)&511]) + ((fSlow164 * fYec0[(fYec0_idx+i-26)&511]) + ((fSlow158 * fYec0[(fYec0_idx+i-25)&511]) + ((fSlow152 * fYec0[(fYec0_idx+i-24)&511]) + ((fSlow146 * fYec0[(fYec0_idx+i-23)&511]) + ((fSlow140 * fYec0[(fYec0_idx+i-22)&511]) + ((fSlow134 * fYec0[(fYec0_idx+i-21)&511]) + ((fSlow128 * fYec0[(fYec0_idx+i-20)&511]) + ((fSlow122 * fYec0[(fYec0_idx+i-19)&511]) + ((fSlow116 * fYec0[(fYec0_idx+i-18)&511]) + ((fSlow110 * fYec0[(fYec0_idx+i-17)&511]) + ((fSlow104 * fYec0[(fYec0_idx+i-16)&511]) + ((fSlow98 * fYec0[(fYec0_idx+i-15)&511]) + ((fSlow92 * fYec0[(fYec0_idx+i-14)&511]) + ((fSlow86 * fYec0[(fYec0_idx+i-13)&511]) + ((fSlow80 * fYec0[(fYec0_idx+i-12)&511]) + ((fSlow74 * fYec0[(fYec0_idx+i-11)&511]) + ((fSlow68 * fYec0[(fYec0_idx+i-10)&511]) + ((fSlow62 * fYec0[(fYec0_idx+i-9)&511]) + ((fSlow56 * fYec0[(fYec0_idx+i-8)&511]) + ((fSlow50 * fYec0[(fYec0_idx+i-7)&511]) + ((fSlow44 * fYec0[(fYec0_idx+i-6)&511]) + ((fSlow38 * fYec0[(fYec0_idx+i-5)&511]) + ((fSlow32 * fYec0[(fYec0_idx+i-4)&511]) + ((fSlow26 * fYec0[(fYec0_idx+i-3)&511]) + ((fSlow20 * fYec0[(fYec0_idx+i-2)&511]) + ((fSlow14 * fYec0[(fYec0_idx+i-1)&511]) + (fSlow8 * fYec0[(fYec0_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec1_idx_save = count;
			
			// LOOP 0x7f06686688b0
			// pre processing
			fYec4_idx = (fYec4_idx+fYec4_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec4[(fYec4_idx+i)&1023] = ((fSlow904 * ((fSlow903 * fYec3[(fYec3_idx+i-179)&511]) + ((fSlow902 * fYec3[(fYec3_idx+i-178)&511]) + ((fSlow901 * fYec3[(fYec3_idx+i-177)&511]) + ((fSlow900 * fYec3[(fYec3_idx+i-176)&511]) + ((fSlow899 * fYec3[(fYec3_idx+i-175)&511]) + ((fSlow898 * fYec3[(fYec3_idx+i-174)&511]) + ((fSlow897 * fYec3[(fYec3_idx+i-173)&511]) + ((fSlow896 * fYec3[(fYec3_idx+i-172)&511]) + ((fSlow895 * fYec3[(fYec3_idx+i-171)&511]) + ((fSlow894 * fYec3[(fYec3_idx+i-170)&511]) + ((fSlow893 * fYec3[(fYec3_idx+i-169)&511]) + ((fSlow892 * fYec3[(fYec3_idx+i-168)&511]) + ((fSlow891 * fYec3[(fYec3_idx+i-167)&511]) + ((fSlow890 * fYec3[(fYec3_idx+i-166)&511]) + ((fSlow889 * fYec3[(fYec3_idx+i-165)&511]) + ((fSlow888 * fYec3[(fYec3_idx+i-164)&511]) + ((fSlow887 * fYec3[(fYec3_idx+i-163)&511]) + ((fSlow886 * fYec3[(fYec3_idx+i-162)&511]) + ((fSlow885 * fYec3[(fYec3_idx+i-161)&511]) + ((fSlow884 * fYec3[(fYec3_idx+i-160)&511]) + ((fSlow883 * fYec3[(fYec3_idx+i-159)&511]) + ((fSlow882 * fYec3[(fYec3_idx+i-158)&511]) + ((fSlow881 * fYec3[(fYec3_idx+i-157)&511]) + ((fSlow880 * fYec3[(fYec3_idx+i-156)&511]) + ((fSlow879 * fYec3[(fYec3_idx+i-155)&511]) + ((fSlow878 * fYec3[(fYec3_idx+i-154)&511]) + ((fSlow877 * fYec3[(fYec3_idx+i-153)&511]) + ((fSlow876 * fYec3[(fYec3_idx+i-152)&511]) + ((fSlow875 * fYec3[(fYec3_idx+i-151)&511]) + ((fSlow874 * fYec3[(fYec3_idx+i-150)&511]) + ((fSlow873 * fYec3[(fYec3_idx+i-149)&511]) + ((fSlow872 * fYec3[(fYec3_idx+i-148)&511]) + ((fSlow871 * fYec3[(fYec3_idx+i-147)&511]) + ((fSlow870 * fYec3[(fYec3_idx+i-146)&511]) + ((fSlow869 * fYec3[(fYec3_idx+i-145)&511]) + ((fSlow868 * fYec3[(fYec3_idx+i-144)&511]) + ((fSlow867 * fYec3[(fYec3_idx+i-143)&511]) + ((fSlow866 * fYec3[(fYec3_idx+i-142)&511]) + ((fSlow865 * fYec3[(fYec3_idx+i-141)&511]) + ((fSlow864 * fYec3[(fYec3_idx+i-140)&511]) + ((fSlow863 * fYec3[(fYec3_idx+i-139)&511]) + ((fSlow862 * fYec3[(fYec3_idx+i-138)&511]) + ((fSlow861 * fYec3[(fYec3_idx+i-137)&511]) + ((fSlow860 * fYec3[(fYec3_idx+i-136)&511]) + ((fSlow859 * fYec3[(fYec3_idx+i-135)&511]) + ((fSlow858 * fYec3[(fYec3_idx+i-134)&511]) + ((fSlow857 * fYec3[(fYec3_idx+i-133)&511]) + ((fSlow856 * fYec3[(fYec3_idx+i-132)&511]) + ((fSlow855 * fYec3[(fYec3_idx+i-131)&511]) + ((fSlow854 * fYec3[(fYec3_idx+i-130)&511]) + ((fSlow853 * fYec3[(fYec3_idx+i-129)&511]) + ((fSlow852 * fYec3[(fYec3_idx+i-128)&511]) + ((fSlow851 * fYec3[(fYec3_idx+i-127)&511]) + ((fSlow850 * fYec3[(fYec3_idx+i-126)&511]) + ((fSlow849 * fYec3[(fYec3_idx+i-125)&511]) + ((fSlow848 * fYec3[(fYec3_idx+i-124)&511]) + ((fSlow847 * fYec3[(fYec3_idx+i-123)&511]) + ((fSlow846 * fYec3[(fYec3_idx+i-122)&511]) + ((fSlow845 * fYec3[(fYec3_idx+i-121)&511]) + ((fSlow844 * fYec3[(fYec3_idx+i-120)&511]) + ((fSlow843 * fYec3[(fYec3_idx+i-119)&511]) + ((fSlow842 * fYec3[(fYec3_idx+i-118)&511]) + ((fSlow841 * fYec3[(fYec3_idx+i-117)&511]) + ((fSlow840 * fYec3[(fYec3_idx+i-116)&511]) + ((fSlow839 * fYec3[(fYec3_idx+i-115)&511]) + ((fSlow838 * fYec3[(fYec3_idx+i-114)&511]) + ((fSlow837 * fYec3[(fYec3_idx+i-113)&511]) + ((fSlow836 * fYec3[(fYec3_idx+i-112)&511]) + ((fSlow835 * fYec3[(fYec3_idx+i-111)&511]) + ((fSlow834 * fYec3[(fYec3_idx+i-110)&511]) + ((fSlow833 * fYec3[(fYec3_idx+i-109)&511]) + ((fSlow832 * fYec3[(fYec3_idx+i-108)&511]) + ((fSlow831 * fYec3[(fYec3_idx+i-107)&511]) + ((fSlow830 * fYec3[(fYec3_idx+i-106)&511]) + ((fSlow829 * fYec3[(fYec3_idx+i-105)&511]) + ((fSlow828 * fYec3[(fYec3_idx+i-104)&511]) + ((fSlow827 * fYec3[(fYec3_idx+i-103)&511]) + ((fSlow826 * fYec3[(fYec3_idx+i-102)&511]) + ((fSlow825 * fYec3[(fYec3_idx+i-101)&511]) + ((fSlow824 * fYec3[(fYec3_idx+i-100)&511]) + ((fSlow823 * fYec3[(fYec3_idx+i-99)&511]) + ((fSlow822 * fYec3[(fYec3_idx+i-98)&511]) + ((fSlow821 * fYec3[(fYec3_idx+i-97)&511]) + ((fSlow820 * fYec3[(fYec3_idx+i-96)&511]) + ((fSlow819 * fYec3[(fYec3_idx+i-95)&511]) + ((fSlow818 * fYec3[(fYec3_idx+i-94)&511]) + ((fSlow817 * fYec3[(fYec3_idx+i-93)&511]) + ((fSlow816 * fYec3[(fYec3_idx+i-92)&511]) + ((fSlow815 * fYec3[(fYec3_idx+i-91)&511]) + ((fSlow814 * fYec3[(fYec3_idx+i-90)&511]) + ((fSlow813 * fYec3[(fYec3_idx+i-89)&511]) + ((fSlow812 * fYec3[(fYec3_idx+i-88)&511]) + ((fSlow811 * fYec3[(fYec3_idx+i-87)&511]) + ((fSlow810 * fYec3[(fYec3_idx+i-86)&511]) + ((fSlow809 * fYec3[(fYec3_idx+i-85)&511]) + ((fSlow808 * fYec3[(fYec3_idx+i-84)&511]) + ((fSlow807 * fYec3[(fYec3_idx+i-83)&511]) + ((fSlow806 * fYec3[(fYec3_idx+i-82)&511]) + ((fSlow805 * fYec3[(fYec3_idx+i-81)&511]) + ((fSlow804 * fYec3[(fYec3_idx+i-80)&511]) + ((fSlow803 * fYec3[(fYec3_idx+i-79)&511]) + ((fSlow802 * fYec3[(fYec3_idx+i-78)&511]) + ((fSlow801 * fYec3[(fYec3_idx+i-77)&511]) + ((fSlow800 * fYec3[(fYec3_idx+i-76)&511]) + ((fSlow799 * fYec3[(fYec3_idx+i-75)&511]) + ((fSlow798 * fYec3[(fYec3_idx+i-74)&511]) + ((fSlow797 * fYec3[(fYec3_idx+i-73)&511]) + ((fSlow796 * fYec3[(fYec3_idx+i-72)&511]) + ((fSlow795 * fYec3[(fYec3_idx+i-71)&511]) + ((fSlow794 * fYec3[(fYec3_idx+i-70)&511]) + ((fSlow793 * fYec3[(fYec3_idx+i-69)&511]) + ((fSlow792 * fYec3[(fYec3_idx+i-68)&511]) + ((fSlow791 * fYec3[(fYec3_idx+i-67)&511]) + ((fSlow790 * fYec3[(fYec3_idx+i-66)&511]) + ((fSlow789 * fYec3[(fYec3_idx+i-65)&511]) + ((fSlow788 * fYec3[(fYec3_idx+i-64)&511]) + ((fSlow787 * fYec3[(fYec3_idx+i-63)&511]) + ((fSlow786 * fYec3[(fYec3_idx+i-62)&511]) + ((fSlow785 * fYec3[(fYec3_idx+i-61)&511]) + ((fSlow784 * fYec3[(fYec3_idx+i-60)&511]) + ((fSlow783 * fYec3[(fYec3_idx+i-59)&511]) + ((fSlow782 * fYec3[(fYec3_idx+i-58)&511]) + ((fSlow781 * fYec3[(fYec3_idx+i-57)&511]) + ((fSlow780 * fYec3[(fYec3_idx+i-56)&511]) + ((fSlow779 * fYec3[(fYec3_idx+i-55)&511]) + ((fSlow778 * fYec3[(fYec3_idx+i-54)&511]) + ((fSlow777 * fYec3[(fYec3_idx+i-53)&511]) + ((fSlow776 * fYec3[(fYec3_idx+i-52)&511]) + ((fSlow775 * fYec3[(fYec3_idx+i-51)&511]) + ((fSlow774 * fYec3[(fYec3_idx+i-50)&511]) + ((fSlow773 * fYec3[(fYec3_idx+i-49)&511]) + ((fSlow772 * fYec3[(fYec3_idx+i-48)&511]) + ((fSlow771 * fYec3[(fYec3_idx+i-47)&511]) + ((fSlow770 * fYec3[(fYec3_idx+i-46)&511]) + ((fSlow769 * fYec3[(fYec3_idx+i-45)&511]) + ((fSlow768 * fYec3[(fYec3_idx+i-44)&511]) + ((fSlow767 * fYec3[(fYec3_idx+i-43)&511]) + ((fSlow766 * fYec3[(fYec3_idx+i-42)&511]) + ((fSlow765 * fYec3[(fYec3_idx+i-41)&511]) + ((fSlow764 * fYec3[(fYec3_idx+i-40)&511]) + ((fSlow763 * fYec3[(fYec3_idx+i-39)&511]) + ((fSlow762 * fYec3[(fYec3_idx+i-38)&511]) + ((fSlow761 * fYec3[(fYec3_idx+i-37)&511]) + ((fSlow760 * fYec3[(fYec3_idx+i-36)&511]) + ((fSlow759 * fYec3[(fYec3_idx+i-35)&511]) + ((fSlow758 * fYec3[(fYec3_idx+i-34)&511]) + ((fSlow757 * fYec3[(fYec3_idx+i-33)&511]) + ((fSlow756 * fYec3[(fYec3_idx+i-32)&511]) + ((fSlow755 * fYec3[(fYec3_idx+i-31)&511]) + ((fSlow754 * fYec3[(fYec3_idx+i-30)&511]) + ((fSlow753 * fYec3[(fYec3_idx+i-29)&511]) + ((fSlow752 * fYec3[(fYec3_idx+i-28)&511]) + ((fSlow751 * fYec3[(fYec3_idx+i-27)&511]) + ((fSlow750 * fYec3[(fYec3_idx+i-26)&511]) + ((fSlow749 * fYec3[(fYec3_idx+i-25)&511]) + ((fSlow748 * fYec3[(fYec3_idx+i-24)&511]) + ((fSlow747 * fYec3[(fYec3_idx+i-23)&511]) + ((fSlow746 * fYec3[(fYec3_idx+i-22)&511]) + ((fSlow745 * fYec3[(fYec3_idx+i-21)&511]) + ((fSlow744 * fYec3[(fYec3_idx+i-20)&511]) + ((fSlow743 * fYec3[(fYec3_idx+i-19)&511]) + ((fSlow742 * fYec3[(fYec3_idx+i-18)&511]) + ((fSlow741 * fYec3[(fYec3_idx+i-17)&511]) + ((fSlow740 * fYec3[(fYec3_idx+i-16)&511]) + ((fSlow739 * fYec3[(fYec3_idx+i-15)&511]) + ((fSlow738 * fYec3[(fYec3_idx+i-14)&511]) + ((fSlow737 * fYec3[(fYec3_idx+i-13)&511]) + ((fSlow736 * fYec3[(fYec3_idx+i-12)&511]) + ((fSlow735 * fYec3[(fYec3_idx+i-11)&511]) + ((fSlow734 * fYec3[(fYec3_idx+i-10)&511]) + ((fSlow733 * fYec3[(fYec3_idx+i-9)&511]) + ((fSlow732 * fYec3[(fYec3_idx+i-8)&511]) + ((fSlow731 * fYec3[(fYec3_idx+i-7)&511]) + ((fSlow730 * fYec3[(fYec3_idx+i-6)&511]) + ((fSlow729 * fYec3[(fYec3_idx+i-5)&511]) + ((fSlow728 * fYec3[(fYec3_idx+i-4)&511]) + ((fSlow727 * fYec3[(fYec3_idx+i-3)&511]) + ((fSlow726 * fYec3[(fYec3_idx+i-2)&511]) + ((fSlow725 * fYec3[(fYec3_idx+i-1)&511]) + (fSlow724 * fYec3[(fYec3_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * fYec3[(fYec3_idx+i-179)&511]) + ((fSlow719 * fYec3[(fYec3_idx+i-178)&511]) + ((fSlow717 * fYec3[(fYec3_idx+i-177)&511]) + ((fSlow715 * fYec3[(fYec3_idx+i-176)&511]) + ((fSlow713 * fYec3[(fYec3_idx+i-175)&511]) + ((fSlow711 * fYec3[(fYec3_idx+i-174)&511]) + ((fSlow709 * fYec3[(fYec3_idx+i-173)&511]) + ((fSlow707 * fYec3[(fYec3_idx+i-172)&511]) + ((fSlow705 * fYec3[(fYec3_idx+i-171)&511]) + ((fSlow703 * fYec3[(fYec3_idx+i-170)&511]) + ((fSlow701 * fYec3[(fYec3_idx+i-169)&511]) + ((fSlow699 * fYec3[(fYec3_idx+i-168)&511]) + ((fSlow697 * fYec3[(fYec3_idx+i-167)&511]) + ((fSlow695 * fYec3[(fYec3_idx+i-166)&511]) + ((fSlow693 * fYec3[(fYec3_idx+i-165)&511]) + ((fSlow691 * fYec3[(fYec3_idx+i-164)&511]) + ((fSlow689 * fYec3[(fYec3_idx+i-163)&511]) + ((fSlow687 * fYec3[(fYec3_idx+i-162)&511]) + ((fSlow685 * fYec3[(fYec3_idx+i-161)&511]) + ((fSlow683 * fYec3[(fYec3_idx+i-160)&511]) + ((fSlow681 * fYec3[(fYec3_idx+i-159)&511]) + ((fSlow679 * fYec3[(fYec3_idx+i-158)&511]) + ((fSlow677 * fYec3[(fYec3_idx+i-157)&511]) + ((fSlow675 * fYec3[(fYec3_idx+i-156)&511]) + ((fSlow673 * fYec3[(fYec3_idx+i-155)&511]) + ((fSlow671 * fYec3[(fYec3_idx+i-154)&511]) + ((fSlow669 * fYec3[(fYec3_idx+i-153)&511]) + ((fSlow667 * fYec3[(fYec3_idx+i-152)&511]) + ((fSlow665 * fYec3[(fYec3_idx+i-151)&511]) + ((fSlow663 * fYec3[(fYec3_idx+i-150)&511]) + ((fSlow661 * fYec3[(fYec3_idx+i-149)&511]) + ((fSlow659 * fYec3[(fYec3_idx+i-148)&511]) + ((fSlow657 * fYec3[(fYec3_idx+i-147)&511]) + ((fSlow655 * fYec3[(fYec3_idx+i-146)&511]) + ((fSlow653 * fYec3[(fYec3_idx+i-145)&511]) + ((fSlow651 * fYec3[(fYec3_idx+i-144)&511]) + ((fSlow649 * fYec3[(fYec3_idx+i-143)&511]) + ((fSlow647 * fYec3[(fYec3_idx+i-142)&511]) + ((fSlow645 * fYec3[(fYec3_idx+i-141)&511]) + ((fSlow643 * fYec3[(fYec3_idx+i-140)&511]) + ((fSlow641 * fYec3[(fYec3_idx+i-139)&511]) + ((fSlow639 * fYec3[(fYec3_idx+i-138)&511]) + ((fSlow637 * fYec3[(fYec3_idx+i-137)&511]) + ((fSlow635 * fYec3[(fYec3_idx+i-136)&511]) + ((fSlow633 * fYec3[(fYec3_idx+i-135)&511]) + ((fSlow631 * fYec3[(fYec3_idx+i-134)&511]) + ((fSlow629 * fYec3[(fYec3_idx+i-133)&511]) + ((fSlow627 * fYec3[(fYec3_idx+i-132)&511]) + ((fSlow625 * fYec3[(fYec3_idx+i-131)&511]) + ((fSlow623 * fYec3[(fYec3_idx+i-130)&511]) + ((fSlow621 * fYec3[(fYec3_idx+i-129)&511]) + ((fSlow619 * fYec3[(fYec3_idx+i-128)&511]) + ((fSlow617 * fYec3[(fYec3_idx+i-127)&511]) + ((fSlow615 * fYec3[(fYec3_idx+i-126)&511]) + ((fSlow613 * fYec3[(fYec3_idx+i-125)&511]) + ((fSlow611 * fYec3[(fYec3_idx+i-124)&511]) + ((fSlow609 * fYec3[(fYec3_idx+i-123)&511]) + ((fSlow607 * fYec3[(fYec3_idx+i-122)&511]) + ((fSlow605 * fYec3[(fYec3_idx+i-121)&511]) + ((fSlow603 * fYec3[(fYec3_idx+i-120)&511]) + ((fSlow601 * fYec3[(fYec3_idx+i-119)&511]) + ((fSlow599 * fYec3[(fYec3_idx+i-118)&511]) + ((fSlow597 * fYec3[(fYec3_idx+i-117)&511]) + ((fSlow595 * fYec3[(fYec3_idx+i-116)&511]) + ((fSlow593 * fYec3[(fYec3_idx+i-115)&511]) + ((fSlow591 * fYec3[(fYec3_idx+i-114)&511]) + ((fSlow589 * fYec3[(fYec3_idx+i-113)&511]) + ((fSlow587 * fYec3[(fYec3_idx+i-112)&511]) + ((fSlow585 * fYec3[(fYec3_idx+i-111)&511]) + ((fSlow583 * fYec3[(fYec3_idx+i-110)&511]) + ((fSlow581 * fYec3[(fYec3_idx+i-109)&511]) + ((fSlow579 * fYec3[(fYec3_idx+i-108)&511]) + ((fSlow577 * fYec3[(fYec3_idx+i-107)&511]) + ((fSlow575 * fYec3[(fYec3_idx+i-106)&511]) + ((fSlow573 * fYec3[(fYec3_idx+i-105)&511]) + ((fSlow571 * fYec3[(fYec3_idx+i-104)&511]) + ((fSlow569 * fYec3[(fYec3_idx+i-103)&511]) + ((fSlow567 * fYec3[(fYec3_idx+i-102)&511]) + ((fSlow565 * fYec3[(fYec3_idx+i-101)&511]) + ((fSlow563 * fYec3[(fYec3_idx+i-100)&511]) + ((fSlow561 * fYec3[(fYec3_idx+i-99)&511]) + ((fSlow559 * fYec3[(fYec3_idx+i-98)&511]) + ((fSlow557 * fYec3[(fYec3_idx+i-97)&511]) + ((fSlow555 * fYec3[(fYec3_idx+i-96)&511]) + ((fSlow553 * fYec3[(fYec3_idx+i-95)&511]) + ((fSlow551 * fYec3[(fYec3_idx+i-94)&511]) + ((fSlow549 * fYec3[(fYec3_idx+i-93)&511]) + ((fSlow547 * fYec3[(fYec3_idx+i-92)&511]) + ((fSlow545 * fYec3[(fYec3_idx+i-91)&511]) + ((fSlow543 * fYec3[(fYec3_idx+i-90)&511]) + ((fSlow542 * fYec3[(fYec3_idx+i-89)&511]) + ((fSlow536 * fYec3[(fYec3_idx+i-88)&511]) + ((fSlow530 * fYec3[(fYec3_idx+i-87)&511]) + ((fSlow524 * fYec3[(fYec3_idx+i-86)&511]) + ((fSlow518 * fYec3[(fYec3_idx+i-85)&511]) + ((fSlow512 * fYec3[(fYec3_idx+i-84)&511]) + ((fSlow506 * fYec3[(fYec3_idx+i-83)&511]) + ((fSlow500 * fYec3[(fYec3_idx+i-82)&511]) + ((fSlow494 * fYec3[(fYec3_idx+i-81)&511]) + ((fSlow488 * fYec3[(fYec3_idx+i-80)&511]) + ((fSlow482 * fYec3[(fYec3_idx+i-79)&511]) + ((fSlow476 * fYec3[(fYec3_idx+i-78)&511]) + ((fSlow470 * fYec3[(fYec3_idx+i-77)&511]) + ((fSlow464 * fYec3[(fYec3_idx+i-76)&511]) + ((fSlow458 * fYec3[(fYec3_idx+i-75)&511]) + ((fSlow452 * fYec3[(fYec3_idx+i-74)&511]) + ((fSlow446 * fYec3[(fYec3_idx+i-73)&511]) + ((fSlow440 * fYec3[(fYec3_idx+i-72)&511]) + ((fSlow434 * fYec3[(fYec3_idx+i-71)&511]) + ((fSlow428 * fYec3[(fYec3_idx+i-70)&511]) + ((fSlow422 * fYec3[(fYec3_idx+i-69)&511]) + ((fSlow416 * fYec3[(fYec3_idx+i-68)&511]) + ((fSlow410 * fYec3[(fYec3_idx+i-67)&511]) + ((fSlow404 * fYec3[(fYec3_idx+i-66)&511]) + ((fSlow398 * fYec3[(fYec3_idx+i-65)&511]) + ((fSlow392 * fYec3[(fYec3_idx+i-64)&511]) + ((fSlow386 * fYec3[(fYec3_idx+i-63)&511]) + ((fSlow380 * fYec3[(fYec3_idx+i-62)&511]) + ((fSlow374 * fYec3[(fYec3_idx+i-61)&511]) + ((fSlow368 * fYec3[(fYec3_idx+i-60)&511]) + ((fSlow362 * fYec3[(fYec3_idx+i-59)&511]) + ((fSlow356 * fYec3[(fYec3_idx+i-58)&511]) + ((fSlow350 * fYec3[(fYec3_idx+i-57)&511]) + ((fSlow344 * fYec3[(fYec3_idx+i-56)&511]) + ((fSlow338 * fYec3[(fYec3_idx+i-55)&511]) + ((fSlow332 * fYec3[(fYec3_idx+i-54)&511]) + ((fSlow326 * fYec3[(fYec3_idx+i-53)&511]) + ((fSlow320 * fYec3[(fYec3_idx+i-52)&511]) + ((fSlow314 * fYec3[(fYec3_idx+i-51)&511]) + ((fSlow308 * fYec3[(fYec3_idx+i-50)&511]) + ((fSlow302 * fYec3[(fYec3_idx+i-49)&511]) + ((fSlow296 * fYec3[(fYec3_idx+i-48)&511]) + ((fSlow290 * fYec3[(fYec3_idx+i-47)&511]) + ((fSlow284 * fYec3[(fYec3_idx+i-46)&511]) + ((fSlow278 * fYec3[(fYec3_idx+i-45)&511]) + ((fSlow272 * fYec3[(fYec3_idx+i-44)&511]) + ((fSlow266 * fYec3[(fYec3_idx+i-43)&511]) + ((fSlow260 * fYec3[(fYec3_idx+i-42)&511]) + ((fSlow254 * fYec3[(fYec3_idx+i-41)&511]) + ((fSlow248 * fYec3[(fYec3_idx+i-40)&511]) + ((fSlow242 * fYec3[(fYec3_idx+i-39)&511]) + ((fSlow236 * fYec3[(fYec3_idx+i-38)&511]) + ((fSlow230 * fYec3[(fYec3_idx+i-37)&511]) + ((fSlow224 * fYec3[(fYec3_idx+i-36)&511]) + ((fSlow218 * fYec3[(fYec3_idx+i-35)&511]) + ((fSlow212 * fYec3[(fYec3_idx+i-34)&511]) + ((fSlow206 * fYec3[(fYec3_idx+i-33)&511]) + ((fSlow200 * fYec3[(fYec3_idx+i-32)&511]) + ((fSlow194 * fYec3[(fYec3_idx+i-31)&511]) + ((fSlow188 * fYec3[(fYec3_idx+i-30)&511]) + ((fSlow182 * fYec3[(fYec3_idx+i-29)&511]) + ((fSlow176 * fYec3[(fYec3_idx+i-28)&511]) + ((fSlow170 * fYec3[(fYec3_idx+i-27)&511]) + ((fSlow164 * fYec3[(fYec3_idx+i-26)&511]) + ((fSlow158 * fYec3[(fYec3_idx+i-25)&511]) + ((fSlow152 * fYec3[(fYec3_idx+i-24)&511]) + ((fSlow146 * fYec3[(fYec3_idx+i-23)&511]) + ((fSlow140 * fYec3[(fYec3_idx+i-22)&511]) + ((fSlow134 * fYec3[(fYec3_idx+i-21)&511]) + ((fSlow128 * fYec3[(fYec3_idx+i-20)&511]) + ((fSlow122 * fYec3[(fYec3_idx+i-19)&511]) + ((fSlow116 * fYec3[(fYec3_idx+i-18)&511]) + ((fSlow110 * fYec3[(fYec3_idx+i-17)&511]) + ((fSlow104 * fYec3[(fYec3_idx+i-16)&511]) + ((fSlow98 * fYec3[(fYec3_idx+i-15)&511]) + ((fSlow92 * fYec3[(fYec3_idx+i-14)&511]) + ((fSlow86 * fYec3[(fYec3_idx+i-13)&511]) + ((fSlow80 * fYec3[(fYec3_idx+i-12)&511]) + ((fSlow74 * fYec3[(fYec3_idx+i-11)&511]) + ((fSlow68 * fYec3[(fYec3_idx+i-10)&511]) + ((fSlow62 * fYec3[(fYec3_idx+i-9)&511]) + ((fSlow56 * fYec3[(fYec3_idx+i-8)&511]) + ((fSlow50 * fYec3[(fYec3_idx+i-7)&511]) + ((fSlow44 * fYec3[(fYec3_idx+i-6)&511]) + ((fSlow38 * fYec3[(fYec3_idx+i-5)&511]) + ((fSlow32 * fYec3[(fYec3_idx+i-4)&511]) + ((fSlow26 * fYec3[(fYec3_idx+i-3)&511]) + ((fSlow20 * fYec3[(fYec3_idx+i-2)&511]) + ((fSlow14 * fYec3[(fYec3_idx+i-1)&511]) + (fSlow8 * fYec3[(fYec3_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec4_idx_save = count;
			
			// LOOP 0x7f0668681ca0
			// pre processing
			fYec2_idx = (fYec2_idx+fYec2_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec2[(fYec2_idx+i)&511] = (fZec0[i] + (fSlow921 * (float)input0[i]));
			}
			// post processing
			fYec2_idx_save = count;
			
			// LOOP 0x7f0668929ce0
			// pre processing
			fYec5_idx = (fYec5_idx+fYec5_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec5[(fYec5_idx+i)&511] = (fZec0[i] + (fSlow921 * (float)input1[i]));
			}
			// post processing
			fYec5_idx_save = count;
			
			// SECTION : 3
			// LOOP 0x7f06680488e0
			// exec code
			for (int i=0; i<count; i++) {
				output0[i] = (FAUSTFLOAT)(fSlow935 * ((fSlow934 * ((fSlow917 * ((fSlow915 * ((fSlow913 * ((fSlow933 * fYec1[(fYec1_idx+i-iSlow932)&1023]) + (fSlow931 * fYec1[(fYec1_idx+i-iSlow930)&1023]))) + (fSlow929 * fYec1[(fYec1_idx+i-iSlow928)&1023]))) + (fSlow927 * fYec1[(fYec1_idx+i-iSlow926)&1023]))) + (fSlow925 * fYec1[(fYec1_idx+i-iSlow923)&1023]))) + (((0.08333333333333333f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-14f * fYec2[(fYec2_idx+i-91)&511])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-90)&511])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900866e-15f * fYec2[(fYec2_idx+i-89)&511])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-15f * (0 - (1.000000000000003f * fYec2[(fYec2_idx+i-88)&511]))))))))))) + ((0.008333333333333333f * (0 - (1.999999999999997f * (0 - (6.217248937900886e-15f * fYec2[(fYec2_idx+i-93)&511]))))) + (0.041666666666666664f * (0 - (2.999999999999997f * (0 - (3.108624468950438e-15f * (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-92)&511]))))))))) + (fSlow919 * fYec1[(fYec1_idx+i-iSlow908)&1023]))));
			}
			
			// LOOP 0x7f0668671ba0
			// exec code
			for (int i=0; i<count; i++) {
				output1[i] = (FAUSTFLOAT)(fSlow935 * ((fSlow934 * ((fSlow917 * ((fSlow915 * ((fSlow913 * ((fSlow933 * fYec4[(fYec4_idx+i-iSlow932)&1023]) + (fSlow931 * fYec4[(fYec4_idx+i-iSlow930)&1023]))) + (fSlow929 * fYec4[(fYec4_idx+i-iSlow928)&1023]))) + (fSlow927 * fYec4[(fYec4_idx+i-iSlow926)&1023]))) + (fSlow925 * fYec4[(fYec4_idx+i-iSlow923)&1023]))) + (((0.08333333333333333f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-14f * fYec5[(fYec5_idx+i-91)&511])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-90)&511])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900866e-15f * fYec5[(fYec5_idx+i-89)&511])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-15f * (0 - (1.000000000000003f * fYec5[(fYec5_idx+i-88)&511]))))))))))) + ((0.008333333333333333f * (0 - (1.999999999999997f * (0 - (6.217248937900886e-15f * fYec5[(fYec5_idx+i-93)&511]))))) + (0.041666666666666664f * (0 - (2.999999999999997f * (0 - (3.108624468950438e-15f * (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-92)&511]))))))))) + (fSlow919 * fYec4[(fYec4_idx+i-iSlow908)&1023]))));
			}
			
		}
		if (index < fullcount) {
			// compute the remaining samples if any
			int count = fullcount-index;
			FAUSTFLOAT* input0 = &input[0][index];
			FAUSTFLOAT* input1 = &input[1][index];
			FAUSTFLOAT* output0 = &output[0][index];
			FAUSTFLOAT* output1 = &output[1][index];
			// SECTION : 1
			// LOOP 0x7f0668048e10
			// pre processing
			fYec0_idx = (fYec0_idx+fYec0_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec0[(fYec0_idx+i)&511] = ((float)input1[i] - (float)input0[i]);
			}
			// post processing
			fYec0_idx_save = count;
			
			// LOOP 0x7f0668668990
			// pre processing
			fYec3_idx = (fYec3_idx+fYec3_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec3[(fYec3_idx+i)&511] = ((float)input0[i] - (float)input1[i]);
			}
			// post processing
			fYec3_idx_save = count;
			
			// LOOP 0x7f0668682510
			// exec code
			for (int i=0; i<count; i++) {
				fZec0[i] = (fSlow922 * ((float)input0[i] + (float)input1[i]));
			}
			
			// SECTION : 2
			// LOOP 0x7f0668048d00
			// pre processing
			fYec1_idx = (fYec1_idx+fYec1_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec1[(fYec1_idx+i)&1023] = ((fSlow904 * ((fSlow903 * fYec0[(fYec0_idx+i-179)&511]) + ((fSlow902 * fYec0[(fYec0_idx+i-178)&511]) + ((fSlow901 * fYec0[(fYec0_idx+i-177)&511]) + ((fSlow900 * fYec0[(fYec0_idx+i-176)&511]) + ((fSlow899 * fYec0[(fYec0_idx+i-175)&511]) + ((fSlow898 * fYec0[(fYec0_idx+i-174)&511]) + ((fSlow897 * fYec0[(fYec0_idx+i-173)&511]) + ((fSlow896 * fYec0[(fYec0_idx+i-172)&511]) + ((fSlow895 * fYec0[(fYec0_idx+i-171)&511]) + ((fSlow894 * fYec0[(fYec0_idx+i-170)&511]) + ((fSlow893 * fYec0[(fYec0_idx+i-169)&511]) + ((fSlow892 * fYec0[(fYec0_idx+i-168)&511]) + ((fSlow891 * fYec0[(fYec0_idx+i-167)&511]) + ((fSlow890 * fYec0[(fYec0_idx+i-166)&511]) + ((fSlow889 * fYec0[(fYec0_idx+i-165)&511]) + ((fSlow888 * fYec0[(fYec0_idx+i-164)&511]) + ((fSlow887 * fYec0[(fYec0_idx+i-163)&511]) + ((fSlow886 * fYec0[(fYec0_idx+i-162)&511]) + ((fSlow885 * fYec0[(fYec0_idx+i-161)&511]) + ((fSlow884 * fYec0[(fYec0_idx+i-160)&511]) + ((fSlow883 * fYec0[(fYec0_idx+i-159)&511]) + ((fSlow882 * fYec0[(fYec0_idx+i-158)&511]) + ((fSlow881 * fYec0[(fYec0_idx+i-157)&511]) + ((fSlow880 * fYec0[(fYec0_idx+i-156)&511]) + ((fSlow879 * fYec0[(fYec0_idx+i-155)&511]) + ((fSlow878 * fYec0[(fYec0_idx+i-154)&511]) + ((fSlow877 * fYec0[(fYec0_idx+i-153)&511]) + ((fSlow876 * fYec0[(fYec0_idx+i-152)&511]) + ((fSlow875 * fYec0[(fYec0_idx+i-151)&511]) + ((fSlow874 * fYec0[(fYec0_idx+i-150)&511]) + ((fSlow873 * fYec0[(fYec0_idx+i-149)&511]) + ((fSlow872 * fYec0[(fYec0_idx+i-148)&511]) + ((fSlow871 * fYec0[(fYec0_idx+i-147)&511]) + ((fSlow870 * fYec0[(fYec0_idx+i-146)&511]) + ((fSlow869 * fYec0[(fYec0_idx+i-145)&511]) + ((fSlow868 * fYec0[(fYec0_idx+i-144)&511]) + ((fSlow867 * fYec0[(fYec0_idx+i-143)&511]) + ((fSlow866 * fYec0[(fYec0_idx+i-142)&511]) + ((fSlow865 * fYec0[(fYec0_idx+i-141)&511]) + ((fSlow864 * fYec0[(fYec0_idx+i-140)&511]) + ((fSlow863 * fYec0[(fYec0_idx+i-139)&511]) + ((fSlow862 * fYec0[(fYec0_idx+i-138)&511]) + ((fSlow861 * fYec0[(fYec0_idx+i-137)&511]) + ((fSlow860 * fYec0[(fYec0_idx+i-136)&511]) + ((fSlow859 * fYec0[(fYec0_idx+i-135)&511]) + ((fSlow858 * fYec0[(fYec0_idx+i-134)&511]) + ((fSlow857 * fYec0[(fYec0_idx+i-133)&511]) + ((fSlow856 * fYec0[(fYec0_idx+i-132)&511]) + ((fSlow855 * fYec0[(fYec0_idx+i-131)&511]) + ((fSlow854 * fYec0[(fYec0_idx+i-130)&511]) + ((fSlow853 * fYec0[(fYec0_idx+i-129)&511]) + ((fSlow852 * fYec0[(fYec0_idx+i-128)&511]) + ((fSlow851 * fYec0[(fYec0_idx+i-127)&511]) + ((fSlow850 * fYec0[(fYec0_idx+i-126)&511]) + ((fSlow849 * fYec0[(fYec0_idx+i-125)&511]) + ((fSlow848 * fYec0[(fYec0_idx+i-124)&511]) + ((fSlow847 * fYec0[(fYec0_idx+i-123)&511]) + ((fSlow846 * fYec0[(fYec0_idx+i-122)&511]) + ((fSlow845 * fYec0[(fYec0_idx+i-121)&511]) + ((fSlow844 * fYec0[(fYec0_idx+i-120)&511]) + ((fSlow843 * fYec0[(fYec0_idx+i-119)&511]) + ((fSlow842 * fYec0[(fYec0_idx+i-118)&511]) + ((fSlow841 * fYec0[(fYec0_idx+i-117)&511]) + ((fSlow840 * fYec0[(fYec0_idx+i-116)&511]) + ((fSlow839 * fYec0[(fYec0_idx+i-115)&511]) + ((fSlow838 * fYec0[(fYec0_idx+i-114)&511]) + ((fSlow837 * fYec0[(fYec0_idx+i-113)&511]) + ((fSlow836 * fYec0[(fYec0_idx+i-112)&511]) + ((fSlow835 * fYec0[(fYec0_idx+i-111)&511]) + ((fSlow834 * fYec0[(fYec0_idx+i-110)&511]) + ((fSlow833 * fYec0[(fYec0_idx+i-109)&511]) + ((fSlow832 * fYec0[(fYec0_idx+i-108)&511]) + ((fSlow831 * fYec0[(fYec0_idx+i-107)&511]) + ((fSlow830 * fYec0[(fYec0_idx+i-106)&511]) + ((fSlow829 * fYec0[(fYec0_idx+i-105)&511]) + ((fSlow828 * fYec0[(fYec0_idx+i-104)&511]) + ((fSlow827 * fYec0[(fYec0_idx+i-103)&511]) + ((fSlow826 * fYec0[(fYec0_idx+i-102)&511]) + ((fSlow825 * fYec0[(fYec0_idx+i-101)&511]) + ((fSlow824 * fYec0[(fYec0_idx+i-100)&511]) + ((fSlow823 * fYec0[(fYec0_idx+i-99)&511]) + ((fSlow822 * fYec0[(fYec0_idx+i-98)&511]) + ((fSlow821 * fYec0[(fYec0_idx+i-97)&511]) + ((fSlow820 * fYec0[(fYec0_idx+i-96)&511]) + ((fSlow819 * fYec0[(fYec0_idx+i-95)&511]) + ((fSlow818 * fYec0[(fYec0_idx+i-94)&511]) + ((fSlow817 * fYec0[(fYec0_idx+i-93)&511]) + ((fSlow816 * fYec0[(fYec0_idx+i-92)&511]) + ((fSlow815 * fYec0[(fYec0_idx+i-91)&511]) + ((fSlow814 * fYec0[(fYec0_idx+i-90)&511]) + ((fSlow813 * fYec0[(fYec0_idx+i-89)&511]) + ((fSlow812 * fYec0[(fYec0_idx+i-88)&511]) + ((fSlow811 * fYec0[(fYec0_idx+i-87)&511]) + ((fSlow810 * fYec0[(fYec0_idx+i-86)&511]) + ((fSlow809 * fYec0[(fYec0_idx+i-85)&511]) + ((fSlow808 * fYec0[(fYec0_idx+i-84)&511]) + ((fSlow807 * fYec0[(fYec0_idx+i-83)&511]) + ((fSlow806 * fYec0[(fYec0_idx+i-82)&511]) + ((fSlow805 * fYec0[(fYec0_idx+i-81)&511]) + ((fSlow804 * fYec0[(fYec0_idx+i-80)&511]) + ((fSlow803 * fYec0[(fYec0_idx+i-79)&511]) + ((fSlow802 * fYec0[(fYec0_idx+i-78)&511]) + ((fSlow801 * fYec0[(fYec0_idx+i-77)&511]) + ((fSlow800 * fYec0[(fYec0_idx+i-76)&511]) + ((fSlow799 * fYec0[(fYec0_idx+i-75)&511]) + ((fSlow798 * fYec0[(fYec0_idx+i-74)&511]) + ((fSlow797 * fYec0[(fYec0_idx+i-73)&511]) + ((fSlow796 * fYec0[(fYec0_idx+i-72)&511]) + ((fSlow795 * fYec0[(fYec0_idx+i-71)&511]) + ((fSlow794 * fYec0[(fYec0_idx+i-70)&511]) + ((fSlow793 * fYec0[(fYec0_idx+i-69)&511]) + ((fSlow792 * fYec0[(fYec0_idx+i-68)&511]) + ((fSlow791 * fYec0[(fYec0_idx+i-67)&511]) + ((fSlow790 * fYec0[(fYec0_idx+i-66)&511]) + ((fSlow789 * fYec0[(fYec0_idx+i-65)&511]) + ((fSlow788 * fYec0[(fYec0_idx+i-64)&511]) + ((fSlow787 * fYec0[(fYec0_idx+i-63)&511]) + ((fSlow786 * fYec0[(fYec0_idx+i-62)&511]) + ((fSlow785 * fYec0[(fYec0_idx+i-61)&511]) + ((fSlow784 * fYec0[(fYec0_idx+i-60)&511]) + ((fSlow783 * fYec0[(fYec0_idx+i-59)&511]) + ((fSlow782 * fYec0[(fYec0_idx+i-58)&511]) + ((fSlow781 * fYec0[(fYec0_idx+i-57)&511]) + ((fSlow780 * fYec0[(fYec0_idx+i-56)&511]) + ((fSlow779 * fYec0[(fYec0_idx+i-55)&511]) + ((fSlow778 * fYec0[(fYec0_idx+i-54)&511]) + ((fSlow777 * fYec0[(fYec0_idx+i-53)&511]) + ((fSlow776 * fYec0[(fYec0_idx+i-52)&511]) + ((fSlow775 * fYec0[(fYec0_idx+i-51)&511]) + ((fSlow774 * fYec0[(fYec0_idx+i-50)&511]) + ((fSlow773 * fYec0[(fYec0_idx+i-49)&511]) + ((fSlow772 * fYec0[(fYec0_idx+i-48)&511]) + ((fSlow771 * fYec0[(fYec0_idx+i-47)&511]) + ((fSlow770 * fYec0[(fYec0_idx+i-46)&511]) + ((fSlow769 * fYec0[(fYec0_idx+i-45)&511]) + ((fSlow768 * fYec0[(fYec0_idx+i-44)&511]) + ((fSlow767 * fYec0[(fYec0_idx+i-43)&511]) + ((fSlow766 * fYec0[(fYec0_idx+i-42)&511]) + ((fSlow765 * fYec0[(fYec0_idx+i-41)&511]) + ((fSlow764 * fYec0[(fYec0_idx+i-40)&511]) + ((fSlow763 * fYec0[(fYec0_idx+i-39)&511]) + ((fSlow762 * fYec0[(fYec0_idx+i-38)&511]) + ((fSlow761 * fYec0[(fYec0_idx+i-37)&511]) + ((fSlow760 * fYec0[(fYec0_idx+i-36)&511]) + ((fSlow759 * fYec0[(fYec0_idx+i-35)&511]) + ((fSlow758 * fYec0[(fYec0_idx+i-34)&511]) + ((fSlow757 * fYec0[(fYec0_idx+i-33)&511]) + ((fSlow756 * fYec0[(fYec0_idx+i-32)&511]) + ((fSlow755 * fYec0[(fYec0_idx+i-31)&511]) + ((fSlow754 * fYec0[(fYec0_idx+i-30)&511]) + ((fSlow753 * fYec0[(fYec0_idx+i-29)&511]) + ((fSlow752 * fYec0[(fYec0_idx+i-28)&511]) + ((fSlow751 * fYec0[(fYec0_idx+i-27)&511]) + ((fSlow750 * fYec0[(fYec0_idx+i-26)&511]) + ((fSlow749 * fYec0[(fYec0_idx+i-25)&511]) + ((fSlow748 * fYec0[(fYec0_idx+i-24)&511]) + ((fSlow747 * fYec0[(fYec0_idx+i-23)&511]) + ((fSlow746 * fYec0[(fYec0_idx+i-22)&511]) + ((fSlow745 * fYec0[(fYec0_idx+i-21)&511]) + ((fSlow744 * fYec0[(fYec0_idx+i-20)&511]) + ((fSlow743 * fYec0[(fYec0_idx+i-19)&511]) + ((fSlow742 * fYec0[(fYec0_idx+i-18)&511]) + ((fSlow741 * fYec0[(fYec0_idx+i-17)&511]) + ((fSlow740 * fYec0[(fYec0_idx+i-16)&511]) + ((fSlow739 * fYec0[(fYec0_idx+i-15)&511]) + ((fSlow738 * fYec0[(fYec0_idx+i-14)&511]) + ((fSlow737 * fYec0[(fYec0_idx+i-13)&511]) + ((fSlow736 * fYec0[(fYec0_idx+i-12)&511]) + ((fSlow735 * fYec0[(fYec0_idx+i-11)&511]) + ((fSlow734 * fYec0[(fYec0_idx+i-10)&511]) + ((fSlow733 * fYec0[(fYec0_idx+i-9)&511]) + ((fSlow732 * fYec0[(fYec0_idx+i-8)&511]) + ((fSlow731 * fYec0[(fYec0_idx+i-7)&511]) + ((fSlow730 * fYec0[(fYec0_idx+i-6)&511]) + ((fSlow729 * fYec0[(fYec0_idx+i-5)&511]) + ((fSlow728 * fYec0[(fYec0_idx+i-4)&511]) + ((fSlow727 * fYec0[(fYec0_idx+i-3)&511]) + ((fSlow726 * fYec0[(fYec0_idx+i-2)&511]) + ((fSlow725 * fYec0[(fYec0_idx+i-1)&511]) + (fSlow724 * fYec0[(fYec0_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * fYec0[(fYec0_idx+i-179)&511]) + ((fSlow719 * fYec0[(fYec0_idx+i-178)&511]) + ((fSlow717 * fYec0[(fYec0_idx+i-177)&511]) + ((fSlow715 * fYec0[(fYec0_idx+i-176)&511]) + ((fSlow713 * fYec0[(fYec0_idx+i-175)&511]) + ((fSlow711 * fYec0[(fYec0_idx+i-174)&511]) + ((fSlow709 * fYec0[(fYec0_idx+i-173)&511]) + ((fSlow707 * fYec0[(fYec0_idx+i-172)&511]) + ((fSlow705 * fYec0[(fYec0_idx+i-171)&511]) + ((fSlow703 * fYec0[(fYec0_idx+i-170)&511]) + ((fSlow701 * fYec0[(fYec0_idx+i-169)&511]) + ((fSlow699 * fYec0[(fYec0_idx+i-168)&511]) + ((fSlow697 * fYec0[(fYec0_idx+i-167)&511]) + ((fSlow695 * fYec0[(fYec0_idx+i-166)&511]) + ((fSlow693 * fYec0[(fYec0_idx+i-165)&511]) + ((fSlow691 * fYec0[(fYec0_idx+i-164)&511]) + ((fSlow689 * fYec0[(fYec0_idx+i-163)&511]) + ((fSlow687 * fYec0[(fYec0_idx+i-162)&511]) + ((fSlow685 * fYec0[(fYec0_idx+i-161)&511]) + ((fSlow683 * fYec0[(fYec0_idx+i-160)&511]) + ((fSlow681 * fYec0[(fYec0_idx+i-159)&511]) + ((fSlow679 * fYec0[(fYec0_idx+i-158)&511]) + ((fSlow677 * fYec0[(fYec0_idx+i-157)&511]) + ((fSlow675 * fYec0[(fYec0_idx+i-156)&511]) + ((fSlow673 * fYec0[(fYec0_idx+i-155)&511]) + ((fSlow671 * fYec0[(fYec0_idx+i-154)&511]) + ((fSlow669 * fYec0[(fYec0_idx+i-153)&511]) + ((fSlow667 * fYec0[(fYec0_idx+i-152)&511]) + ((fSlow665 * fYec0[(fYec0_idx+i-151)&511]) + ((fSlow663 * fYec0[(fYec0_idx+i-150)&511]) + ((fSlow661 * fYec0[(fYec0_idx+i-149)&511]) + ((fSlow659 * fYec0[(fYec0_idx+i-148)&511]) + ((fSlow657 * fYec0[(fYec0_idx+i-147)&511]) + ((fSlow655 * fYec0[(fYec0_idx+i-146)&511]) + ((fSlow653 * fYec0[(fYec0_idx+i-145)&511]) + ((fSlow651 * fYec0[(fYec0_idx+i-144)&511]) + ((fSlow649 * fYec0[(fYec0_idx+i-143)&511]) + ((fSlow647 * fYec0[(fYec0_idx+i-142)&511]) + ((fSlow645 * fYec0[(fYec0_idx+i-141)&511]) + ((fSlow643 * fYec0[(fYec0_idx+i-140)&511]) + ((fSlow641 * fYec0[(fYec0_idx+i-139)&511]) + ((fSlow639 * fYec0[(fYec0_idx+i-138)&511]) + ((fSlow637 * fYec0[(fYec0_idx+i-137)&511]) + ((fSlow635 * fYec0[(fYec0_idx+i-136)&511]) + ((fSlow633 * fYec0[(fYec0_idx+i-135)&511]) + ((fSlow631 * fYec0[(fYec0_idx+i-134)&511]) + ((fSlow629 * fYec0[(fYec0_idx+i-133)&511]) + ((fSlow627 * fYec0[(fYec0_idx+i-132)&511]) + ((fSlow625 * fYec0[(fYec0_idx+i-131)&511]) + ((fSlow623 * fYec0[(fYec0_idx+i-130)&511]) + ((fSlow621 * fYec0[(fYec0_idx+i-129)&511]) + ((fSlow619 * fYec0[(fYec0_idx+i-128)&511]) + ((fSlow617 * fYec0[(fYec0_idx+i-127)&511]) + ((fSlow615 * fYec0[(fYec0_idx+i-126)&511]) + ((fSlow613 * fYec0[(fYec0_idx+i-125)&511]) + ((fSlow611 * fYec0[(fYec0_idx+i-124)&511]) + ((fSlow609 * fYec0[(fYec0_idx+i-123)&511]) + ((fSlow607 * fYec0[(fYec0_idx+i-122)&511]) + ((fSlow605 * fYec0[(fYec0_idx+i-121)&511]) + ((fSlow603 * fYec0[(fYec0_idx+i-120)&511]) + ((fSlow601 * fYec0[(fYec0_idx+i-119)&511]) + ((fSlow599 * fYec0[(fYec0_idx+i-118)&511]) + ((fSlow597 * fYec0[(fYec0_idx+i-117)&511]) + ((fSlow595 * fYec0[(fYec0_idx+i-116)&511]) + ((fSlow593 * fYec0[(fYec0_idx+i-115)&511]) + ((fSlow591 * fYec0[(fYec0_idx+i-114)&511]) + ((fSlow589 * fYec0[(fYec0_idx+i-113)&511]) + ((fSlow587 * fYec0[(fYec0_idx+i-112)&511]) + ((fSlow585 * fYec0[(fYec0_idx+i-111)&511]) + ((fSlow583 * fYec0[(fYec0_idx+i-110)&511]) + ((fSlow581 * fYec0[(fYec0_idx+i-109)&511]) + ((fSlow579 * fYec0[(fYec0_idx+i-108)&511]) + ((fSlow577 * fYec0[(fYec0_idx+i-107)&511]) + ((fSlow575 * fYec0[(fYec0_idx+i-106)&511]) + ((fSlow573 * fYec0[(fYec0_idx+i-105)&511]) + ((fSlow571 * fYec0[(fYec0_idx+i-104)&511]) + ((fSlow569 * fYec0[(fYec0_idx+i-103)&511]) + ((fSlow567 * fYec0[(fYec0_idx+i-102)&511]) + ((fSlow565 * fYec0[(fYec0_idx+i-101)&511]) + ((fSlow563 * fYec0[(fYec0_idx+i-100)&511]) + ((fSlow561 * fYec0[(fYec0_idx+i-99)&511]) + ((fSlow559 * fYec0[(fYec0_idx+i-98)&511]) + ((fSlow557 * fYec0[(fYec0_idx+i-97)&511]) + ((fSlow555 * fYec0[(fYec0_idx+i-96)&511]) + ((fSlow553 * fYec0[(fYec0_idx+i-95)&511]) + ((fSlow551 * fYec0[(fYec0_idx+i-94)&511]) + ((fSlow549 * fYec0[(fYec0_idx+i-93)&511]) + ((fSlow547 * fYec0[(fYec0_idx+i-92)&511]) + ((fSlow545 * fYec0[(fYec0_idx+i-91)&511]) + ((fSlow543 * fYec0[(fYec0_idx+i-90)&511]) + ((fSlow542 * fYec0[(fYec0_idx+i-89)&511]) + ((fSlow536 * fYec0[(fYec0_idx+i-88)&511]) + ((fSlow530 * fYec0[(fYec0_idx+i-87)&511]) + ((fSlow524 * fYec0[(fYec0_idx+i-86)&511]) + ((fSlow518 * fYec0[(fYec0_idx+i-85)&511]) + ((fSlow512 * fYec0[(fYec0_idx+i-84)&511]) + ((fSlow506 * fYec0[(fYec0_idx+i-83)&511]) + ((fSlow500 * fYec0[(fYec0_idx+i-82)&511]) + ((fSlow494 * fYec0[(fYec0_idx+i-81)&511]) + ((fSlow488 * fYec0[(fYec0_idx+i-80)&511]) + ((fSlow482 * fYec0[(fYec0_idx+i-79)&511]) + ((fSlow476 * fYec0[(fYec0_idx+i-78)&511]) + ((fSlow470 * fYec0[(fYec0_idx+i-77)&511]) + ((fSlow464 * fYec0[(fYec0_idx+i-76)&511]) + ((fSlow458 * fYec0[(fYec0_idx+i-75)&511]) + ((fSlow452 * fYec0[(fYec0_idx+i-74)&511]) + ((fSlow446 * fYec0[(fYec0_idx+i-73)&511]) + ((fSlow440 * fYec0[(fYec0_idx+i-72)&511]) + ((fSlow434 * fYec0[(fYec0_idx+i-71)&511]) + ((fSlow428 * fYec0[(fYec0_idx+i-70)&511]) + ((fSlow422 * fYec0[(fYec0_idx+i-69)&511]) + ((fSlow416 * fYec0[(fYec0_idx+i-68)&511]) + ((fSlow410 * fYec0[(fYec0_idx+i-67)&511]) + ((fSlow404 * fYec0[(fYec0_idx+i-66)&511]) + ((fSlow398 * fYec0[(fYec0_idx+i-65)&511]) + ((fSlow392 * fYec0[(fYec0_idx+i-64)&511]) + ((fSlow386 * fYec0[(fYec0_idx+i-63)&511]) + ((fSlow380 * fYec0[(fYec0_idx+i-62)&511]) + ((fSlow374 * fYec0[(fYec0_idx+i-61)&511]) + ((fSlow368 * fYec0[(fYec0_idx+i-60)&511]) + ((fSlow362 * fYec0[(fYec0_idx+i-59)&511]) + ((fSlow356 * fYec0[(fYec0_idx+i-58)&511]) + ((fSlow350 * fYec0[(fYec0_idx+i-57)&511]) + ((fSlow344 * fYec0[(fYec0_idx+i-56)&511]) + ((fSlow338 * fYec0[(fYec0_idx+i-55)&511]) + ((fSlow332 * fYec0[(fYec0_idx+i-54)&511]) + ((fSlow326 * fYec0[(fYec0_idx+i-53)&511]) + ((fSlow320 * fYec0[(fYec0_idx+i-52)&511]) + ((fSlow314 * fYec0[(fYec0_idx+i-51)&511]) + ((fSlow308 * fYec0[(fYec0_idx+i-50)&511]) + ((fSlow302 * fYec0[(fYec0_idx+i-49)&511]) + ((fSlow296 * fYec0[(fYec0_idx+i-48)&511]) + ((fSlow290 * fYec0[(fYec0_idx+i-47)&511]) + ((fSlow284 * fYec0[(fYec0_idx+i-46)&511]) + ((fSlow278 * fYec0[(fYec0_idx+i-45)&511]) + ((fSlow272 * fYec0[(fYec0_idx+i-44)&511]) + ((fSlow266 * fYec0[(fYec0_idx+i-43)&511]) + ((fSlow260 * fYec0[(fYec0_idx+i-42)&511]) + ((fSlow254 * fYec0[(fYec0_idx+i-41)&511]) + ((fSlow248 * fYec0[(fYec0_idx+i-40)&511]) + ((fSlow242 * fYec0[(fYec0_idx+i-39)&511]) + ((fSlow236 * fYec0[(fYec0_idx+i-38)&511]) + ((fSlow230 * fYec0[(fYec0_idx+i-37)&511]) + ((fSlow224 * fYec0[(fYec0_idx+i-36)&511]) + ((fSlow218 * fYec0[(fYec0_idx+i-35)&511]) + ((fSlow212 * fYec0[(fYec0_idx+i-34)&511]) + ((fSlow206 * fYec0[(fYec0_idx+i-33)&511]) + ((fSlow200 * fYec0[(fYec0_idx+i-32)&511]) + ((fSlow194 * fYec0[(fYec0_idx+i-31)&511]) + ((fSlow188 * fYec0[(fYec0_idx+i-30)&511]) + ((fSlow182 * fYec0[(fYec0_idx+i-29)&511]) + ((fSlow176 * fYec0[(fYec0_idx+i-28)&511]) + ((fSlow170 * fYec0[(fYec0_idx+i-27)&511]) + ((fSlow164 * fYec0[(fYec0_idx+i-26)&511]) + ((fSlow158 * fYec0[(fYec0_idx+i-25)&511]) + ((fSlow152 * fYec0[(fYec0_idx+i-24)&511]) + ((fSlow146 * fYec0[(fYec0_idx+i-23)&511]) + ((fSlow140 * fYec0[(fYec0_idx+i-22)&511]) + ((fSlow134 * fYec0[(fYec0_idx+i-21)&511]) + ((fSlow128 * fYec0[(fYec0_idx+i-20)&511]) + ((fSlow122 * fYec0[(fYec0_idx+i-19)&511]) + ((fSlow116 * fYec0[(fYec0_idx+i-18)&511]) + ((fSlow110 * fYec0[(fYec0_idx+i-17)&511]) + ((fSlow104 * fYec0[(fYec0_idx+i-16)&511]) + ((fSlow98 * fYec0[(fYec0_idx+i-15)&511]) + ((fSlow92 * fYec0[(fYec0_idx+i-14)&511]) + ((fSlow86 * fYec0[(fYec0_idx+i-13)&511]) + ((fSlow80 * fYec0[(fYec0_idx+i-12)&511]) + ((fSlow74 * fYec0[(fYec0_idx+i-11)&511]) + ((fSlow68 * fYec0[(fYec0_idx+i-10)&511]) + ((fSlow62 * fYec0[(fYec0_idx+i-9)&511]) + ((fSlow56 * fYec0[(fYec0_idx+i-8)&511]) + ((fSlow50 * fYec0[(fYec0_idx+i-7)&511]) + ((fSlow44 * fYec0[(fYec0_idx+i-6)&511]) + ((fSlow38 * fYec0[(fYec0_idx+i-5)&511]) + ((fSlow32 * fYec0[(fYec0_idx+i-4)&511]) + ((fSlow26 * fYec0[(fYec0_idx+i-3)&511]) + ((fSlow20 * fYec0[(fYec0_idx+i-2)&511]) + ((fSlow14 * fYec0[(fYec0_idx+i-1)&511]) + (fSlow8 * fYec0[(fYec0_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec1_idx_save = count;
			
			// LOOP 0x7f06686688b0
			// pre processing
			fYec4_idx = (fYec4_idx+fYec4_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec4[(fYec4_idx+i)&1023] = ((fSlow904 * ((fSlow903 * fYec3[(fYec3_idx+i-179)&511]) + ((fSlow902 * fYec3[(fYec3_idx+i-178)&511]) + ((fSlow901 * fYec3[(fYec3_idx+i-177)&511]) + ((fSlow900 * fYec3[(fYec3_idx+i-176)&511]) + ((fSlow899 * fYec3[(fYec3_idx+i-175)&511]) + ((fSlow898 * fYec3[(fYec3_idx+i-174)&511]) + ((fSlow897 * fYec3[(fYec3_idx+i-173)&511]) + ((fSlow896 * fYec3[(fYec3_idx+i-172)&511]) + ((fSlow895 * fYec3[(fYec3_idx+i-171)&511]) + ((fSlow894 * fYec3[(fYec3_idx+i-170)&511]) + ((fSlow893 * fYec3[(fYec3_idx+i-169)&511]) + ((fSlow892 * fYec3[(fYec3_idx+i-168)&511]) + ((fSlow891 * fYec3[(fYec3_idx+i-167)&511]) + ((fSlow890 * fYec3[(fYec3_idx+i-166)&511]) + ((fSlow889 * fYec3[(fYec3_idx+i-165)&511]) + ((fSlow888 * fYec3[(fYec3_idx+i-164)&511]) + ((fSlow887 * fYec3[(fYec3_idx+i-163)&511]) + ((fSlow886 * fYec3[(fYec3_idx+i-162)&511]) + ((fSlow885 * fYec3[(fYec3_idx+i-161)&511]) + ((fSlow884 * fYec3[(fYec3_idx+i-160)&511]) + ((fSlow883 * fYec3[(fYec3_idx+i-159)&511]) + ((fSlow882 * fYec3[(fYec3_idx+i-158)&511]) + ((fSlow881 * fYec3[(fYec3_idx+i-157)&511]) + ((fSlow880 * fYec3[(fYec3_idx+i-156)&511]) + ((fSlow879 * fYec3[(fYec3_idx+i-155)&511]) + ((fSlow878 * fYec3[(fYec3_idx+i-154)&511]) + ((fSlow877 * fYec3[(fYec3_idx+i-153)&511]) + ((fSlow876 * fYec3[(fYec3_idx+i-152)&511]) + ((fSlow875 * fYec3[(fYec3_idx+i-151)&511]) + ((fSlow874 * fYec3[(fYec3_idx+i-150)&511]) + ((fSlow873 * fYec3[(fYec3_idx+i-149)&511]) + ((fSlow872 * fYec3[(fYec3_idx+i-148)&511]) + ((fSlow871 * fYec3[(fYec3_idx+i-147)&511]) + ((fSlow870 * fYec3[(fYec3_idx+i-146)&511]) + ((fSlow869 * fYec3[(fYec3_idx+i-145)&511]) + ((fSlow868 * fYec3[(fYec3_idx+i-144)&511]) + ((fSlow867 * fYec3[(fYec3_idx+i-143)&511]) + ((fSlow866 * fYec3[(fYec3_idx+i-142)&511]) + ((fSlow865 * fYec3[(fYec3_idx+i-141)&511]) + ((fSlow864 * fYec3[(fYec3_idx+i-140)&511]) + ((fSlow863 * fYec3[(fYec3_idx+i-139)&511]) + ((fSlow862 * fYec3[(fYec3_idx+i-138)&511]) + ((fSlow861 * fYec3[(fYec3_idx+i-137)&511]) + ((fSlow860 * fYec3[(fYec3_idx+i-136)&511]) + ((fSlow859 * fYec3[(fYec3_idx+i-135)&511]) + ((fSlow858 * fYec3[(fYec3_idx+i-134)&511]) + ((fSlow857 * fYec3[(fYec3_idx+i-133)&511]) + ((fSlow856 * fYec3[(fYec3_idx+i-132)&511]) + ((fSlow855 * fYec3[(fYec3_idx+i-131)&511]) + ((fSlow854 * fYec3[(fYec3_idx+i-130)&511]) + ((fSlow853 * fYec3[(fYec3_idx+i-129)&511]) + ((fSlow852 * fYec3[(fYec3_idx+i-128)&511]) + ((fSlow851 * fYec3[(fYec3_idx+i-127)&511]) + ((fSlow850 * fYec3[(fYec3_idx+i-126)&511]) + ((fSlow849 * fYec3[(fYec3_idx+i-125)&511]) + ((fSlow848 * fYec3[(fYec3_idx+i-124)&511]) + ((fSlow847 * fYec3[(fYec3_idx+i-123)&511]) + ((fSlow846 * fYec3[(fYec3_idx+i-122)&511]) + ((fSlow845 * fYec3[(fYec3_idx+i-121)&511]) + ((fSlow844 * fYec3[(fYec3_idx+i-120)&511]) + ((fSlow843 * fYec3[(fYec3_idx+i-119)&511]) + ((fSlow842 * fYec3[(fYec3_idx+i-118)&511]) + ((fSlow841 * fYec3[(fYec3_idx+i-117)&511]) + ((fSlow840 * fYec3[(fYec3_idx+i-116)&511]) + ((fSlow839 * fYec3[(fYec3_idx+i-115)&511]) + ((fSlow838 * fYec3[(fYec3_idx+i-114)&511]) + ((fSlow837 * fYec3[(fYec3_idx+i-113)&511]) + ((fSlow836 * fYec3[(fYec3_idx+i-112)&511]) + ((fSlow835 * fYec3[(fYec3_idx+i-111)&511]) + ((fSlow834 * fYec3[(fYec3_idx+i-110)&511]) + ((fSlow833 * fYec3[(fYec3_idx+i-109)&511]) + ((fSlow832 * fYec3[(fYec3_idx+i-108)&511]) + ((fSlow831 * fYec3[(fYec3_idx+i-107)&511]) + ((fSlow830 * fYec3[(fYec3_idx+i-106)&511]) + ((fSlow829 * fYec3[(fYec3_idx+i-105)&511]) + ((fSlow828 * fYec3[(fYec3_idx+i-104)&511]) + ((fSlow827 * fYec3[(fYec3_idx+i-103)&511]) + ((fSlow826 * fYec3[(fYec3_idx+i-102)&511]) + ((fSlow825 * fYec3[(fYec3_idx+i-101)&511]) + ((fSlow824 * fYec3[(fYec3_idx+i-100)&511]) + ((fSlow823 * fYec3[(fYec3_idx+i-99)&511]) + ((fSlow822 * fYec3[(fYec3_idx+i-98)&511]) + ((fSlow821 * fYec3[(fYec3_idx+i-97)&511]) + ((fSlow820 * fYec3[(fYec3_idx+i-96)&511]) + ((fSlow819 * fYec3[(fYec3_idx+i-95)&511]) + ((fSlow818 * fYec3[(fYec3_idx+i-94)&511]) + ((fSlow817 * fYec3[(fYec3_idx+i-93)&511]) + ((fSlow816 * fYec3[(fYec3_idx+i-92)&511]) + ((fSlow815 * fYec3[(fYec3_idx+i-91)&511]) + ((fSlow814 * fYec3[(fYec3_idx+i-90)&511]) + ((fSlow813 * fYec3[(fYec3_idx+i-89)&511]) + ((fSlow812 * fYec3[(fYec3_idx+i-88)&511]) + ((fSlow811 * fYec3[(fYec3_idx+i-87)&511]) + ((fSlow810 * fYec3[(fYec3_idx+i-86)&511]) + ((fSlow809 * fYec3[(fYec3_idx+i-85)&511]) + ((fSlow808 * fYec3[(fYec3_idx+i-84)&511]) + ((fSlow807 * fYec3[(fYec3_idx+i-83)&511]) + ((fSlow806 * fYec3[(fYec3_idx+i-82)&511]) + ((fSlow805 * fYec3[(fYec3_idx+i-81)&511]) + ((fSlow804 * fYec3[(fYec3_idx+i-80)&511]) + ((fSlow803 * fYec3[(fYec3_idx+i-79)&511]) + ((fSlow802 * fYec3[(fYec3_idx+i-78)&511]) + ((fSlow801 * fYec3[(fYec3_idx+i-77)&511]) + ((fSlow800 * fYec3[(fYec3_idx+i-76)&511]) + ((fSlow799 * fYec3[(fYec3_idx+i-75)&511]) + ((fSlow798 * fYec3[(fYec3_idx+i-74)&511]) + ((fSlow797 * fYec3[(fYec3_idx+i-73)&511]) + ((fSlow796 * fYec3[(fYec3_idx+i-72)&511]) + ((fSlow795 * fYec3[(fYec3_idx+i-71)&511]) + ((fSlow794 * fYec3[(fYec3_idx+i-70)&511]) + ((fSlow793 * fYec3[(fYec3_idx+i-69)&511]) + ((fSlow792 * fYec3[(fYec3_idx+i-68)&511]) + ((fSlow791 * fYec3[(fYec3_idx+i-67)&511]) + ((fSlow790 * fYec3[(fYec3_idx+i-66)&511]) + ((fSlow789 * fYec3[(fYec3_idx+i-65)&511]) + ((fSlow788 * fYec3[(fYec3_idx+i-64)&511]) + ((fSlow787 * fYec3[(fYec3_idx+i-63)&511]) + ((fSlow786 * fYec3[(fYec3_idx+i-62)&511]) + ((fSlow785 * fYec3[(fYec3_idx+i-61)&511]) + ((fSlow784 * fYec3[(fYec3_idx+i-60)&511]) + ((fSlow783 * fYec3[(fYec3_idx+i-59)&511]) + ((fSlow782 * fYec3[(fYec3_idx+i-58)&511]) + ((fSlow781 * fYec3[(fYec3_idx+i-57)&511]) + ((fSlow780 * fYec3[(fYec3_idx+i-56)&511]) + ((fSlow779 * fYec3[(fYec3_idx+i-55)&511]) + ((fSlow778 * fYec3[(fYec3_idx+i-54)&511]) + ((fSlow777 * fYec3[(fYec3_idx+i-53)&511]) + ((fSlow776 * fYec3[(fYec3_idx+i-52)&511]) + ((fSlow775 * fYec3[(fYec3_idx+i-51)&511]) + ((fSlow774 * fYec3[(fYec3_idx+i-50)&511]) + ((fSlow773 * fYec3[(fYec3_idx+i-49)&511]) + ((fSlow772 * fYec3[(fYec3_idx+i-48)&511]) + ((fSlow771 * fYec3[(fYec3_idx+i-47)&511]) + ((fSlow770 * fYec3[(fYec3_idx+i-46)&511]) + ((fSlow769 * fYec3[(fYec3_idx+i-45)&511]) + ((fSlow768 * fYec3[(fYec3_idx+i-44)&511]) + ((fSlow767 * fYec3[(fYec3_idx+i-43)&511]) + ((fSlow766 * fYec3[(fYec3_idx+i-42)&511]) + ((fSlow765 * fYec3[(fYec3_idx+i-41)&511]) + ((fSlow764 * fYec3[(fYec3_idx+i-40)&511]) + ((fSlow763 * fYec3[(fYec3_idx+i-39)&511]) + ((fSlow762 * fYec3[(fYec3_idx+i-38)&511]) + ((fSlow761 * fYec3[(fYec3_idx+i-37)&511]) + ((fSlow760 * fYec3[(fYec3_idx+i-36)&511]) + ((fSlow759 * fYec3[(fYec3_idx+i-35)&511]) + ((fSlow758 * fYec3[(fYec3_idx+i-34)&511]) + ((fSlow757 * fYec3[(fYec3_idx+i-33)&511]) + ((fSlow756 * fYec3[(fYec3_idx+i-32)&511]) + ((fSlow755 * fYec3[(fYec3_idx+i-31)&511]) + ((fSlow754 * fYec3[(fYec3_idx+i-30)&511]) + ((fSlow753 * fYec3[(fYec3_idx+i-29)&511]) + ((fSlow752 * fYec3[(fYec3_idx+i-28)&511]) + ((fSlow751 * fYec3[(fYec3_idx+i-27)&511]) + ((fSlow750 * fYec3[(fYec3_idx+i-26)&511]) + ((fSlow749 * fYec3[(fYec3_idx+i-25)&511]) + ((fSlow748 * fYec3[(fYec3_idx+i-24)&511]) + ((fSlow747 * fYec3[(fYec3_idx+i-23)&511]) + ((fSlow746 * fYec3[(fYec3_idx+i-22)&511]) + ((fSlow745 * fYec3[(fYec3_idx+i-21)&511]) + ((fSlow744 * fYec3[(fYec3_idx+i-20)&511]) + ((fSlow743 * fYec3[(fYec3_idx+i-19)&511]) + ((fSlow742 * fYec3[(fYec3_idx+i-18)&511]) + ((fSlow741 * fYec3[(fYec3_idx+i-17)&511]) + ((fSlow740 * fYec3[(fYec3_idx+i-16)&511]) + ((fSlow739 * fYec3[(fYec3_idx+i-15)&511]) + ((fSlow738 * fYec3[(fYec3_idx+i-14)&511]) + ((fSlow737 * fYec3[(fYec3_idx+i-13)&511]) + ((fSlow736 * fYec3[(fYec3_idx+i-12)&511]) + ((fSlow735 * fYec3[(fYec3_idx+i-11)&511]) + ((fSlow734 * fYec3[(fYec3_idx+i-10)&511]) + ((fSlow733 * fYec3[(fYec3_idx+i-9)&511]) + ((fSlow732 * fYec3[(fYec3_idx+i-8)&511]) + ((fSlow731 * fYec3[(fYec3_idx+i-7)&511]) + ((fSlow730 * fYec3[(fYec3_idx+i-6)&511]) + ((fSlow729 * fYec3[(fYec3_idx+i-5)&511]) + ((fSlow728 * fYec3[(fYec3_idx+i-4)&511]) + ((fSlow727 * fYec3[(fYec3_idx+i-3)&511]) + ((fSlow726 * fYec3[(fYec3_idx+i-2)&511]) + ((fSlow725 * fYec3[(fYec3_idx+i-1)&511]) + (fSlow724 * fYec3[(fYec3_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * fYec3[(fYec3_idx+i-179)&511]) + ((fSlow719 * fYec3[(fYec3_idx+i-178)&511]) + ((fSlow717 * fYec3[(fYec3_idx+i-177)&511]) + ((fSlow715 * fYec3[(fYec3_idx+i-176)&511]) + ((fSlow713 * fYec3[(fYec3_idx+i-175)&511]) + ((fSlow711 * fYec3[(fYec3_idx+i-174)&511]) + ((fSlow709 * fYec3[(fYec3_idx+i-173)&511]) + ((fSlow707 * fYec3[(fYec3_idx+i-172)&511]) + ((fSlow705 * fYec3[(fYec3_idx+i-171)&511]) + ((fSlow703 * fYec3[(fYec3_idx+i-170)&511]) + ((fSlow701 * fYec3[(fYec3_idx+i-169)&511]) + ((fSlow699 * fYec3[(fYec3_idx+i-168)&511]) + ((fSlow697 * fYec3[(fYec3_idx+i-167)&511]) + ((fSlow695 * fYec3[(fYec3_idx+i-166)&511]) + ((fSlow693 * fYec3[(fYec3_idx+i-165)&511]) + ((fSlow691 * fYec3[(fYec3_idx+i-164)&511]) + ((fSlow689 * fYec3[(fYec3_idx+i-163)&511]) + ((fSlow687 * fYec3[(fYec3_idx+i-162)&511]) + ((fSlow685 * fYec3[(fYec3_idx+i-161)&511]) + ((fSlow683 * fYec3[(fYec3_idx+i-160)&511]) + ((fSlow681 * fYec3[(fYec3_idx+i-159)&511]) + ((fSlow679 * fYec3[(fYec3_idx+i-158)&511]) + ((fSlow677 * fYec3[(fYec3_idx+i-157)&511]) + ((fSlow675 * fYec3[(fYec3_idx+i-156)&511]) + ((fSlow673 * fYec3[(fYec3_idx+i-155)&511]) + ((fSlow671 * fYec3[(fYec3_idx+i-154)&511]) + ((fSlow669 * fYec3[(fYec3_idx+i-153)&511]) + ((fSlow667 * fYec3[(fYec3_idx+i-152)&511]) + ((fSlow665 * fYec3[(fYec3_idx+i-151)&511]) + ((fSlow663 * fYec3[(fYec3_idx+i-150)&511]) + ((fSlow661 * fYec3[(fYec3_idx+i-149)&511]) + ((fSlow659 * fYec3[(fYec3_idx+i-148)&511]) + ((fSlow657 * fYec3[(fYec3_idx+i-147)&511]) + ((fSlow655 * fYec3[(fYec3_idx+i-146)&511]) + ((fSlow653 * fYec3[(fYec3_idx+i-145)&511]) + ((fSlow651 * fYec3[(fYec3_idx+i-144)&511]) + ((fSlow649 * fYec3[(fYec3_idx+i-143)&511]) + ((fSlow647 * fYec3[(fYec3_idx+i-142)&511]) + ((fSlow645 * fYec3[(fYec3_idx+i-141)&511]) + ((fSlow643 * fYec3[(fYec3_idx+i-140)&511]) + ((fSlow641 * fYec3[(fYec3_idx+i-139)&511]) + ((fSlow639 * fYec3[(fYec3_idx+i-138)&511]) + ((fSlow637 * fYec3[(fYec3_idx+i-137)&511]) + ((fSlow635 * fYec3[(fYec3_idx+i-136)&511]) + ((fSlow633 * fYec3[(fYec3_idx+i-135)&511]) + ((fSlow631 * fYec3[(fYec3_idx+i-134)&511]) + ((fSlow629 * fYec3[(fYec3_idx+i-133)&511]) + ((fSlow627 * fYec3[(fYec3_idx+i-132)&511]) + ((fSlow625 * fYec3[(fYec3_idx+i-131)&511]) + ((fSlow623 * fYec3[(fYec3_idx+i-130)&511]) + ((fSlow621 * fYec3[(fYec3_idx+i-129)&511]) + ((fSlow619 * fYec3[(fYec3_idx+i-128)&511]) + ((fSlow617 * fYec3[(fYec3_idx+i-127)&511]) + ((fSlow615 * fYec3[(fYec3_idx+i-126)&511]) + ((fSlow613 * fYec3[(fYec3_idx+i-125)&511]) + ((fSlow611 * fYec3[(fYec3_idx+i-124)&511]) + ((fSlow609 * fYec3[(fYec3_idx+i-123)&511]) + ((fSlow607 * fYec3[(fYec3_idx+i-122)&511]) + ((fSlow605 * fYec3[(fYec3_idx+i-121)&511]) + ((fSlow603 * fYec3[(fYec3_idx+i-120)&511]) + ((fSlow601 * fYec3[(fYec3_idx+i-119)&511]) + ((fSlow599 * fYec3[(fYec3_idx+i-118)&511]) + ((fSlow597 * fYec3[(fYec3_idx+i-117)&511]) + ((fSlow595 * fYec3[(fYec3_idx+i-116)&511]) + ((fSlow593 * fYec3[(fYec3_idx+i-115)&511]) + ((fSlow591 * fYec3[(fYec3_idx+i-114)&511]) + ((fSlow589 * fYec3[(fYec3_idx+i-113)&511]) + ((fSlow587 * fYec3[(fYec3_idx+i-112)&511]) + ((fSlow585 * fYec3[(fYec3_idx+i-111)&511]) + ((fSlow583 * fYec3[(fYec3_idx+i-110)&511]) + ((fSlow581 * fYec3[(fYec3_idx+i-109)&511]) + ((fSlow579 * fYec3[(fYec3_idx+i-108)&511]) + ((fSlow577 * fYec3[(fYec3_idx+i-107)&511]) + ((fSlow575 * fYec3[(fYec3_idx+i-106)&511]) + ((fSlow573 * fYec3[(fYec3_idx+i-105)&511]) + ((fSlow571 * fYec3[(fYec3_idx+i-104)&511]) + ((fSlow569 * fYec3[(fYec3_idx+i-103)&511]) + ((fSlow567 * fYec3[(fYec3_idx+i-102)&511]) + ((fSlow565 * fYec3[(fYec3_idx+i-101)&511]) + ((fSlow563 * fYec3[(fYec3_idx+i-100)&511]) + ((fSlow561 * fYec3[(fYec3_idx+i-99)&511]) + ((fSlow559 * fYec3[(fYec3_idx+i-98)&511]) + ((fSlow557 * fYec3[(fYec3_idx+i-97)&511]) + ((fSlow555 * fYec3[(fYec3_idx+i-96)&511]) + ((fSlow553 * fYec3[(fYec3_idx+i-95)&511]) + ((fSlow551 * fYec3[(fYec3_idx+i-94)&511]) + ((fSlow549 * fYec3[(fYec3_idx+i-93)&511]) + ((fSlow547 * fYec3[(fYec3_idx+i-92)&511]) + ((fSlow545 * fYec3[(fYec3_idx+i-91)&511]) + ((fSlow543 * fYec3[(fYec3_idx+i-90)&511]) + ((fSlow542 * fYec3[(fYec3_idx+i-89)&511]) + ((fSlow536 * fYec3[(fYec3_idx+i-88)&511]) + ((fSlow530 * fYec3[(fYec3_idx+i-87)&511]) + ((fSlow524 * fYec3[(fYec3_idx+i-86)&511]) + ((fSlow518 * fYec3[(fYec3_idx+i-85)&511]) + ((fSlow512 * fYec3[(fYec3_idx+i-84)&511]) + ((fSlow506 * fYec3[(fYec3_idx+i-83)&511]) + ((fSlow500 * fYec3[(fYec3_idx+i-82)&511]) + ((fSlow494 * fYec3[(fYec3_idx+i-81)&511]) + ((fSlow488 * fYec3[(fYec3_idx+i-80)&511]) + ((fSlow482 * fYec3[(fYec3_idx+i-79)&511]) + ((fSlow476 * fYec3[(fYec3_idx+i-78)&511]) + ((fSlow470 * fYec3[(fYec3_idx+i-77)&511]) + ((fSlow464 * fYec3[(fYec3_idx+i-76)&511]) + ((fSlow458 * fYec3[(fYec3_idx+i-75)&511]) + ((fSlow452 * fYec3[(fYec3_idx+i-74)&511]) + ((fSlow446 * fYec3[(fYec3_idx+i-73)&511]) + ((fSlow440 * fYec3[(fYec3_idx+i-72)&511]) + ((fSlow434 * fYec3[(fYec3_idx+i-71)&511]) + ((fSlow428 * fYec3[(fYec3_idx+i-70)&511]) + ((fSlow422 * fYec3[(fYec3_idx+i-69)&511]) + ((fSlow416 * fYec3[(fYec3_idx+i-68)&511]) + ((fSlow410 * fYec3[(fYec3_idx+i-67)&511]) + ((fSlow404 * fYec3[(fYec3_idx+i-66)&511]) + ((fSlow398 * fYec3[(fYec3_idx+i-65)&511]) + ((fSlow392 * fYec3[(fYec3_idx+i-64)&511]) + ((fSlow386 * fYec3[(fYec3_idx+i-63)&511]) + ((fSlow380 * fYec3[(fYec3_idx+i-62)&511]) + ((fSlow374 * fYec3[(fYec3_idx+i-61)&511]) + ((fSlow368 * fYec3[(fYec3_idx+i-60)&511]) + ((fSlow362 * fYec3[(fYec3_idx+i-59)&511]) + ((fSlow356 * fYec3[(fYec3_idx+i-58)&511]) + ((fSlow350 * fYec3[(fYec3_idx+i-57)&511]) + ((fSlow344 * fYec3[(fYec3_idx+i-56)&511]) + ((fSlow338 * fYec3[(fYec3_idx+i-55)&511]) + ((fSlow332 * fYec3[(fYec3_idx+i-54)&511]) + ((fSlow326 * fYec3[(fYec3_idx+i-53)&511]) + ((fSlow320 * fYec3[(fYec3_idx+i-52)&511]) + ((fSlow314 * fYec3[(fYec3_idx+i-51)&511]) + ((fSlow308 * fYec3[(fYec3_idx+i-50)&511]) + ((fSlow302 * fYec3[(fYec3_idx+i-49)&511]) + ((fSlow296 * fYec3[(fYec3_idx+i-48)&511]) + ((fSlow290 * fYec3[(fYec3_idx+i-47)&511]) + ((fSlow284 * fYec3[(fYec3_idx+i-46)&511]) + ((fSlow278 * fYec3[(fYec3_idx+i-45)&511]) + ((fSlow272 * fYec3[(fYec3_idx+i-44)&511]) + ((fSlow266 * fYec3[(fYec3_idx+i-43)&511]) + ((fSlow260 * fYec3[(fYec3_idx+i-42)&511]) + ((fSlow254 * fYec3[(fYec3_idx+i-41)&511]) + ((fSlow248 * fYec3[(fYec3_idx+i-40)&511]) + ((fSlow242 * fYec3[(fYec3_idx+i-39)&511]) + ((fSlow236 * fYec3[(fYec3_idx+i-38)&511]) + ((fSlow230 * fYec3[(fYec3_idx+i-37)&511]) + ((fSlow224 * fYec3[(fYec3_idx+i-36)&511]) + ((fSlow218 * fYec3[(fYec3_idx+i-35)&511]) + ((fSlow212 * fYec3[(fYec3_idx+i-34)&511]) + ((fSlow206 * fYec3[(fYec3_idx+i-33)&511]) + ((fSlow200 * fYec3[(fYec3_idx+i-32)&511]) + ((fSlow194 * fYec3[(fYec3_idx+i-31)&511]) + ((fSlow188 * fYec3[(fYec3_idx+i-30)&511]) + ((fSlow182 * fYec3[(fYec3_idx+i-29)&511]) + ((fSlow176 * fYec3[(fYec3_idx+i-28)&511]) + ((fSlow170 * fYec3[(fYec3_idx+i-27)&511]) + ((fSlow164 * fYec3[(fYec3_idx+i-26)&511]) + ((fSlow158 * fYec3[(fYec3_idx+i-25)&511]) + ((fSlow152 * fYec3[(fYec3_idx+i-24)&511]) + ((fSlow146 * fYec3[(fYec3_idx+i-23)&511]) + ((fSlow140 * fYec3[(fYec3_idx+i-22)&511]) + ((fSlow134 * fYec3[(fYec3_idx+i-21)&511]) + ((fSlow128 * fYec3[(fYec3_idx+i-20)&511]) + ((fSlow122 * fYec3[(fYec3_idx+i-19)&511]) + ((fSlow116 * fYec3[(fYec3_idx+i-18)&511]) + ((fSlow110 * fYec3[(fYec3_idx+i-17)&511]) + ((fSlow104 * fYec3[(fYec3_idx+i-16)&511]) + ((fSlow98 * fYec3[(fYec3_idx+i-15)&511]) + ((fSlow92 * fYec3[(fYec3_idx+i-14)&511]) + ((fSlow86 * fYec3[(fYec3_idx+i-13)&511]) + ((fSlow80 * fYec3[(fYec3_idx+i-12)&511]) + ((fSlow74 * fYec3[(fYec3_idx+i-11)&511]) + ((fSlow68 * fYec3[(fYec3_idx+i-10)&511]) + ((fSlow62 * fYec3[(fYec3_idx+i-9)&511]) + ((fSlow56 * fYec3[(fYec3_idx+i-8)&511]) + ((fSlow50 * fYec3[(fYec3_idx+i-7)&511]) + ((fSlow44 * fYec3[(fYec3_idx+i-6)&511]) + ((fSlow38 * fYec3[(fYec3_idx+i-5)&511]) + ((fSlow32 * fYec3[(fYec3_idx+i-4)&511]) + ((fSlow26 * fYec3[(fYec3_idx+i-3)&511]) + ((fSlow20 * fYec3[(fYec3_idx+i-2)&511]) + ((fSlow14 * fYec3[(fYec3_idx+i-1)&511]) + (fSlow8 * fYec3[(fYec3_idx+i) & 511]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec4_idx_save = count;
			
			// LOOP 0x7f0668681ca0
			// pre processing
			fYec2_idx = (fYec2_idx+fYec2_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec2[(fYec2_idx+i)&511] = (fZec0[i] + (fSlow921 * (float)input0[i]));
			}
			// post processing
			fYec2_idx_save = count;
			
			// LOOP 0x7f0668929ce0
			// pre processing
			fYec5_idx = (fYec5_idx+fYec5_idx_save)&511;
			// exec code
			for (int i=0; i<count; i++) {
				fYec5[(fYec5_idx+i)&511] = (fZec0[i] + (fSlow921 * (float)input1[i]));
			}
			// post processing
			fYec5_idx_save = count;
			
			// SECTION : 3
			// LOOP 0x7f06680488e0
			// exec code
			for (int i=0; i<count; i++) {
				output0[i] = (FAUSTFLOAT)(fSlow935 * ((fSlow934 * ((fSlow917 * ((fSlow915 * ((fSlow913 * ((fSlow933 * fYec1[(fYec1_idx+i-iSlow932)&1023]) + (fSlow931 * fYec1[(fYec1_idx+i-iSlow930)&1023]))) + (fSlow929 * fYec1[(fYec1_idx+i-iSlow928)&1023]))) + (fSlow927 * fYec1[(fYec1_idx+i-iSlow926)&1023]))) + (fSlow925 * fYec1[(fYec1_idx+i-iSlow923)&1023]))) + (((0.08333333333333333f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-14f * fYec2[(fYec2_idx+i-91)&511])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-90)&511])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900866e-15f * fYec2[(fYec2_idx+i-89)&511])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-15f * (0 - (1.000000000000003f * fYec2[(fYec2_idx+i-88)&511]))))))))))) + ((0.008333333333333333f * (0 - (1.999999999999997f * (0 - (6.217248937900886e-15f * fYec2[(fYec2_idx+i-93)&511]))))) + (0.041666666666666664f * (0 - (2.999999999999997f * (0 - (3.108624468950438e-15f * (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-92)&511]))))))))) + (fSlow919 * fYec1[(fYec1_idx+i-iSlow908)&1023]))));
			}
			
			// LOOP 0x7f0668671ba0
			// exec code
			for (int i=0; i<count; i++) {
				output1[i] = (FAUSTFLOAT)(fSlow935 * ((fSlow934 * ((fSlow917 * ((fSlow915 * ((fSlow913 * ((fSlow933 * fYec4[(fYec4_idx+i-iSlow932)&1023]) + (fSlow931 * fYec4[(fYec4_idx+i-iSlow930)&1023]))) + (fSlow929 * fYec4[(fYec4_idx+i-iSlow928)&1023]))) + (fSlow927 * fYec4[(fYec4_idx+i-iSlow926)&1023]))) + (fSlow925 * fYec4[(fYec4_idx+i-iSlow923)&1023]))) + (((0.08333333333333333f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-14f * fYec5[(fYec5_idx+i-91)&511])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-90)&511])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900866e-15f * fYec5[(fYec5_idx+i-89)&511])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-15f * (0 - (1.000000000000003f * fYec5[(fYec5_idx+i-88)&511]))))))))))) + ((0.008333333333333333f * (0 - (1.999999999999997f * (0 - (6.217248937900886e-15f * fYec5[(fYec5_idx+i-93)&511]))))) + (0.041666666666666664f * (0 - (2.999999999999997f * (0 - (3.108624468950438e-15f * (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-92)&511]))))))))) + (fSlow919 * fYec4[(fYec4_idx+i-iSlow908)&1023]))));
			}
			
		}
	}
};



/***************************END USER SECTION ***************************/

/*******************BEGIN ARCHITECTURE SECTION (part 2/2)***************/
					
mydsp		DSP;
std::list<GUI*>	GUI::fGuiList;

//-------------------------------------------------------------------------
// 									MAIN
//-------------------------------------------------------------------------
int main(int argc, char *argv[])
{
	char appname[256];
	char rcfilename[256];
	char* home = getenv("HOME");
	
	snprintf(appname, 255, "%s", basename(argv[0]));
	snprintf(rcfilename, 255, "%s/.%src", home, appname);

	GUI* interface 	= new GTKUI (appname, &argc, &argv);
	FUI* finterface	= new FUI();
	DSP.buildUserInterface(interface);
	DSP.buildUserInterface(finterface);

#ifdef HTTPCTRL
	httpdUI* httpdinterface = new httpdUI(appname, argc, argv);
	DSP.buildUserInterface(httpdinterface);
	std::cout << "HTTPD is on" << std::endl;
#endif

#ifdef OSCCTRL
	GUI* oscinterface = new OSCUI(appname, argc, argv);
	DSP.buildUserInterface(oscinterface);
#endif

	jackaudio audio;
	audio.init(appname, &DSP);
	finterface->recallState(rcfilename);	
	audio.start();
	
#ifdef HTTPCTRL
	httpdinterface->run();
#endif

#ifdef OSCCTRL
	oscinterface->run();
#endif
	interface->run();
	
	audio.stop();
	finterface->saveState(rcfilename);
  	return 0;
}

		
/********************END ARCHITECTURE SECTION (part 2/2)****************/

